import * as t from 'io-ts';
import { FactoryEventNames } from '../../../constants';
import { ExtractSchemaTypes } from '../../../schemas';
export declare const PauseReadModelSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
        readModelName: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.pauseReadModel>;
        payload: t.TypeC<{
            version: t.StringC;
            deploymentId: t.StringC;
            userId: t.StringC;
            eventListener: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ deploymentId, readModelName }: {
        deploymentId: string;
        readModelName: string;
    } & {} & {}) => {
        params: {
            deploymentId: string;
            readModelName: string;
        };
        body: {};
        query: {};
    };
};
export declare type PauseReadModel = ExtractSchemaTypes<typeof PauseReadModelSchema>;
export declare const ResetReadModelSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
        readModelName: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.resetReadModel>;
        payload: t.TypeC<{
            version: t.StringC;
            deploymentId: t.StringC;
            userId: t.StringC;
            eventListener: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ deploymentId, readModelName }: {
        deploymentId: string;
        readModelName: string;
    } & {} & {}) => {
        params: {
            deploymentId: string;
            readModelName: string;
        };
        body: {};
        query: {};
    };
};
export declare type ResetReadModel = ExtractSchemaTypes<typeof ResetReadModelSchema>;
export declare const ResumeReadModelSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
        readModelName: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.resumeReadModel>;
        payload: t.TypeC<{
            version: t.StringC;
            deploymentId: t.StringC;
            userId: t.StringC;
            eventListener: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ deploymentId, readModelName }: {
        deploymentId: string;
        readModelName: string;
    } & {} & {}) => {
        params: {
            deploymentId: string;
            readModelName: string;
        };
        body: {};
        query: {};
    };
};
export declare type ResumeReadModel = ExtractSchemaTypes<typeof ResumeReadModelSchema>;
export declare const ListReadModelsSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "GET";
    Mode: "ASYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.listReadModels>;
        payload: t.TypeC<{
            version: t.StringC;
            deploymentId: t.StringC;
            userId: t.StringC;
        }>;
    }>;
    Result: t.ArrayC<t.TypeC<{
        name: t.StringC;
        status: t.UnionC<[t.StringC, t.NullC]>;
        successEvent: t.UnionC<[t.RecordC<t.StringC, t.AnyC>, t.NullC]>;
        failedEvent: t.UnionC<[t.RecordC<t.StringC, t.AnyC>, t.NullC]>;
        errors: t.ArrayC<t.TypeC<{
            name: t.StringC;
            message: t.StringC;
            stack: t.StringC;
        }>>;
    }>>;
    ArgumentsTransformer: ({ deploymentId }: {
        deploymentId: string;
    } & {} & {}) => {
        params: {
            deploymentId: string;
        };
        body: {};
        query: {};
    };
};
export declare type ListReadModels = ExtractSchemaTypes<typeof ListReadModelsSchema>;
export declare const CreateReadModelSchema: {
    Namespace: unknown;
    Description: unknown;
    Path: unknown;
    Method: never;
    Mode: never;
    Params: unknown;
    Body: unknown;
    Query: unknown;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.createReadModel>;
        payload: t.TypeC<{
            version: t.StringC;
            deploymentId: t.StringC;
            user: t.TypeC<{
                userId: t.StringC;
                password: t.StringC;
                secretName: t.StringC;
                secretArn: t.StringC;
            }>;
            readModelsClusterArn: t.StringC;
            postgresAdminSecretArn: t.StringC;
            readModelsClusterEndpoint: t.StringC;
            readModelsClusterPort: t.NumberC;
            postgresAdminUsername: t.StringC;
            postgresAdminPassword: t.StringC;
        }>;
    }>;
    Result: t.TypeC<{
        readModelDatabaseName: t.StringC;
    }>;
    ArgumentsTransformer: unknown;
};
export declare type CreateReadModel = ExtractSchemaTypes<typeof CreateReadModelSchema>;
export declare const DropReadModelSchema: {
    Namespace: unknown;
    Description: unknown;
    Path: unknown;
    Method: never;
    Mode: never;
    Params: unknown;
    Body: unknown;
    Query: unknown;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.dropReadModel>;
        payload: t.TypeC<{
            version: t.StringC;
            deploymentId: t.StringC;
            user: t.TypeC<{
                userId: t.StringC;
                password: t.StringC;
                secretName: t.StringC;
                secretArn: t.StringC;
            }>;
            readModelsClusterArn: t.StringC;
            postgresAdminSecretArn: t.StringC;
            readModelsClusterEndpoint: t.StringC;
            readModelsClusterPort: t.NumberC;
            postgresAdminUsername: t.StringC;
            postgresAdminPassword: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: unknown;
};
export declare type DropReadModel = ExtractSchemaTypes<typeof DropReadModelSchema>;
