import * as t from 'io-ts';
import { InstallerEventNames } from '../../../constants';
import { ExtractSchemaTypes } from '../../../schemas';
export declare const DisableTracingSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.disableTracing>;
        payload: t.TypeC<{
            deploymentId: t.StringC;
            userId: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ deploymentId }: {
        deploymentId: string;
    } & {} & {}) => {
        params: {
            deploymentId: string;
        };
        body: {};
        query: {};
    };
};
export declare type DisableTracing = ExtractSchemaTypes<typeof DisableTracingSchema>;
export declare const EnableTracingSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.enableTracing>;
        payload: t.TypeC<{
            deploymentId: t.StringC;
            userId: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ deploymentId }: {
        deploymentId: string;
    } & {} & {}) => {
        params: {
            deploymentId: string;
        };
        body: {};
        query: {};
    };
};
export declare type EnableTracing = ExtractSchemaTypes<typeof EnableTracingSchema>;
export declare const GetSummariesSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "GET";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.IntersectionC<[t.TypeC<{
        startTime: t.StringC;
        endTime: t.StringC;
    }>, t.PartialC<{
        filterExpression: t.StringC;
    }>]>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.getSummaries>;
        payload: t.IntersectionC<[t.TypeC<{
            deploymentId: t.StringC;
            userId: t.StringC;
            startTime: t.NumberC;
            endTime: t.NumberC;
        }>, t.PartialC<{
            filterExpression: t.StringC;
        }>]>;
    }>;
    Result: t.ArrayC<t.IntersectionC<[t.PartialC<{
        id: t.StringC;
        responseTime: t.NumberC;
        http: t.PartialC<{
            httpURL: t.StringC;
            httpStatus: t.NumberC;
            httpMethod: t.StringC;
            userAgent: t.StringC;
            clientIp: t.StringC;
        }>;
    }>, t.RecordC<t.StringC, t.AnyC>]>>;
    ArgumentsTransformer: ({ deploymentId, startTime, endTime, filterExpression }: {
        deploymentId: string;
    } & {} & {
        startTime: string;
        endTime: string;
    } & {
        filterExpression?: string | undefined;
    }) => {
        params: {
            deploymentId: string;
        };
        body: {};
        query: {
            startTime: string;
            endTime: string;
            filterExpression: string | undefined;
        };
    };
};
export declare type GetSummaries = ExtractSchemaTypes<typeof GetSummariesSchema>;
export declare const GetTracingDetailsSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "GET";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{
        traceIds: t.ArrayC<t.StringC>;
    }>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.getTracingDetails>;
        payload: t.TypeC<{
            deploymentId: t.StringC;
            userId: t.StringC;
            traceIds: t.ArrayC<t.StringC>;
        }>;
    }>;
    Result: t.ArrayC<t.RecordC<t.StringC, t.AnyC>>;
    ArgumentsTransformer: ({ deploymentId, traceIds }: {
        deploymentId: string;
    } & {} & {
        traceIds: string[];
    }) => {
        params: {
            deploymentId: string;
        };
        body: {};
        query: {
            traceIds: string[];
        };
    };
};
export declare type GetTracingDetails = ExtractSchemaTypes<typeof GetTracingDetailsSchema>;
export declare const GetTracingStatusSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "GET";
    Mode: "SYNC";
    Params: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.getTracingStatus>;
        payload: t.TypeC<{
            deploymentId: t.StringC;
            userId: t.StringC;
        }>;
    }>;
    Result: t.UnionC<[t.LiteralC<"enabled">, t.LiteralC<"disabled">]>;
    ArgumentsTransformer: ({ deploymentId }: {
        deploymentId: string;
    } & {} & {}) => {
        params: {
            deploymentId: string;
        };
        body: {};
        query: {};
    };
};
export declare type GetTracingStatus = ExtractSchemaTypes<typeof GetTracingStatusSchema>;
