import * as t from 'io-ts';
import { FactoryEventNames, InstallerEventNames } from '../../constants';
import { ExtractSchemaTypes } from '../../schemas';
export declare const CreateEventStoreSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "POST";
    Mode: "ASYNC";
    Params: t.TypeC<{}>;
    Body: t.TypeC<{
        version: t.StringC;
    }>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.createEventStore>;
        payload: t.TypeC<{
            version: t.StringC;
            user: t.TypeC<{
                userId: t.StringC;
                password: t.StringC;
                secretName: t.StringC;
                secretArn: t.StringC;
            }>;
            eventStoreClusterArn: t.StringC;
            postgresAdminSecretArn: t.StringC;
            eventStoreClusterEndpoint: t.StringC;
            eventStoreClusterPort: t.NumberC;
            postgresAdminUsername: t.StringC;
            postgresAdminPassword: t.StringC;
        }>;
    }>;
    Result: t.TypeC<{
        eventStoreId: t.StringC;
    }>;
    ArgumentsTransformer: ({ version }: {} & {
        version: string;
    } & {}) => {
        params: {};
        body: {
            version: string;
        };
        query: {};
    };
};
export declare type CreateEventStore = ExtractSchemaTypes<typeof CreateEventStoreSchema>;
export declare const DropEventStoreSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "DELETE";
    Mode: "ASYNC";
    Params: t.TypeC<{
        eventStoreId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.dropEventStore>;
        payload: t.TypeC<{
            version: t.StringC;
            user: t.TypeC<{
                userId: t.StringC;
                password: t.StringC;
                secretName: t.StringC;
                secretArn: t.StringC;
            }>;
            eventStoreId: t.StringC;
            eventStoreClusterArn: t.StringC;
            postgresAdminSecretArn: t.StringC;
            eventStoreClusterEndpoint: t.StringC;
            eventStoreClusterPort: t.NumberC;
            postgresAdminUsername: t.StringC;
            postgresAdminPassword: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ eventStoreId }: {
        eventStoreId: string;
    } & {} & {}) => {
        params: {
            eventStoreId: string;
        };
        body: {};
        query: {};
    };
};
export declare type DropEventStore = ExtractSchemaTypes<typeof DropEventStoreSchema>;
export declare const GetEventStoreSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "GET";
    Mode: "ASYNC";
    Params: t.TypeC<{
        eventStoreId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.getEventStore>;
        payload: t.TypeC<{
            user: t.TypeC<{
                userId: t.StringC;
                password: t.StringC;
                secretName: t.StringC;
                secretArn: t.StringC;
            }>;
            eventStoreId: t.StringC;
            eventStoreClusterArn: t.StringC;
            postgresAdminSecretArn: t.StringC;
            eventStoreClusterEndpoint: t.StringC;
            eventStoreClusterPort: t.NumberC;
            postgresAdminUsername: t.StringC;
            postgresAdminPassword: t.StringC;
        }>;
    }>;
    Result: t.TypeC<{
        eventStoreClusterArn: t.StringC;
        eventStoreSecretArn: t.StringC;
        eventStoreDatabaseName: t.StringC;
        version: t.StringC;
        eventStoreId: t.StringC;
        linkedDeployments: t.ArrayC<t.StringC>;
        region: t.StringC;
        accessKeyId: t.StringC;
        secretAccessKey: t.StringC;
        sessionToken: t.StringC;
    }>;
    ArgumentsTransformer: ({ eventStoreId }: {
        eventStoreId: string;
    } & {} & {}) => {
        params: {
            eventStoreId: string;
        };
        body: {};
        query: {};
    };
};
export declare type GetEventStore = ExtractSchemaTypes<typeof GetEventStoreSchema>;
export declare const ListEventStoresSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "GET";
    Mode: "ASYNC";
    Params: t.TypeC<{}>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<InstallerEventNames.listEventStores>;
        payload: t.TypeC<{
            user: t.TypeC<{
                userId: t.StringC;
                password: t.StringC;
                secretName: t.StringC;
                secretArn: t.StringC;
            }>;
            eventStoreClusterArn: t.StringC;
            postgresAdminSecretArn: t.StringC;
            eventStoreClusterEndpoint: t.StringC;
            eventStoreClusterPort: t.NumberC;
            postgresAdminUsername: t.StringC;
            postgresAdminPassword: t.StringC;
        }>;
    }>;
    Result: t.ArrayC<t.TypeC<{
        version: t.StringC;
        eventStoreId: t.StringC;
        linkedDeployments: t.ArrayC<t.StringC>;
        eventStoreDatabaseName: t.StringC;
        events: t.UnionC<[t.NumberC, t.NullC]>;
        secrets: t.UnionC<[t.NumberC, t.NullC]>;
        modifiedAt: t.UnionC<[t.NumberC, t.NullC]>;
        createdAt: t.UnionC<[t.NumberC, t.NullC]>;
        isFrozen: t.UnionC<[t.BooleanC, t.NullC]>;
    }>>;
    ArgumentsTransformer: (args?: {} & {} & {}) => {
        params: {};
        body: {};
        query: {};
    };
};
export declare type ListEventStores = ExtractSchemaTypes<typeof ListEventStoresSchema>;
export declare const CloneEventStoreSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "ASYNC";
    Params: t.TypeC<{
        eventStoreId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.cloneEventStore>;
        payload: t.TypeC<{
            version: t.StringC;
            user: t.TypeC<{
                userId: t.StringC;
                password: t.StringC;
                secretName: t.StringC;
                secretArn: t.StringC;
            }>;
            eventStoreClusterArn: t.StringC;
            postgresAdminSecretArn: t.StringC;
            eventStoreId: t.StringC;
            eventStoreClusterEndpoint: t.StringC;
            eventStoreClusterPort: t.NumberC;
            postgresAdminUsername: t.StringC;
            postgresAdminPassword: t.StringC;
        }>;
    }>;
    Result: t.TypeC<{
        eventStoreId: t.StringC;
        eventStoreDatabaseName: t.StringC;
    }>;
    ArgumentsTransformer: ({ eventStoreId }: {
        eventStoreId: string;
    } & {} & {}) => {
        params: {
            eventStoreId: string;
        };
        body: {};
        query: {};
    };
};
export declare type CloneEventStore = ExtractSchemaTypes<typeof CloneEventStoreSchema>;
export declare const ClearEventStoreSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "ASYNC";
    Params: t.TypeC<{
        eventStoreId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.clearEventStore>;
        payload: t.TypeC<{
            version: t.StringC;
            user: t.TypeC<{
                userId: t.StringC;
                password: t.StringC;
                secretName: t.StringC;
                secretArn: t.StringC;
            }>;
            eventStoreId: t.StringC;
            eventStoreClusterArn: t.StringC;
            postgresAdminSecretArn: t.StringC;
            eventStoreClusterEndpoint: t.StringC;
            eventStoreClusterPort: t.NumberC;
            postgresAdminUsername: t.StringC;
            postgresAdminPassword: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ eventStoreId }: {
        eventStoreId: string;
    } & {} & {}) => {
        params: {
            eventStoreId: string;
        };
        body: {};
        query: {};
    };
};
export declare type ClearEventStore = ExtractSchemaTypes<typeof ClearEventStoreSchema>;
export declare const FreezeEventStoreSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "ASYNC";
    Params: t.TypeC<{
        eventStoreId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.freezeEventStore>;
        payload: t.TypeC<{
            version: t.StringC;
            user: t.TypeC<{
                userId: t.StringC;
                password: t.StringC;
                secretName: t.StringC;
                secretArn: t.StringC;
            }>;
            eventStoreId: t.StringC;
            eventStoreClusterArn: t.StringC;
            postgresAdminSecretArn: t.StringC;
            eventStoreClusterEndpoint: t.StringC;
            eventStoreClusterPort: t.NumberC;
            postgresAdminUsername: t.StringC;
            postgresAdminPassword: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ eventStoreId }: {
        eventStoreId: string;
    } & {} & {}) => {
        params: {
            eventStoreId: string;
        };
        body: {};
        query: {};
    };
};
export declare type FreezeEventStore = ExtractSchemaTypes<typeof FreezeEventStoreSchema>;
export declare const UnfreezeEventStoreSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "ASYNC";
    Params: t.TypeC<{
        eventStoreId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.unfreezeEventStore>;
        payload: t.TypeC<{
            version: t.StringC;
            user: t.TypeC<{
                userId: t.StringC;
                password: t.StringC;
                secretName: t.StringC;
                secretArn: t.StringC;
            }>;
            eventStoreId: t.StringC;
            eventStoreClusterArn: t.StringC;
            postgresAdminSecretArn: t.StringC;
            eventStoreClusterEndpoint: t.StringC;
            eventStoreClusterPort: t.NumberC;
            postgresAdminUsername: t.StringC;
            postgresAdminPassword: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ eventStoreId }: {
        eventStoreId: string;
    } & {} & {}) => {
        params: {
            eventStoreId: string;
        };
        body: {};
        query: {};
    };
};
export declare type UnfreezeEventStore = ExtractSchemaTypes<typeof UnfreezeEventStoreSchema>;
export declare const LinkDeploymentSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "ASYNC";
    Params: t.TypeC<{
        eventStoreId: t.StringC;
    }>;
    Body: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.linkDeployment>;
        payload: t.TypeC<{
            version: t.StringC;
            user: t.TypeC<{
                userId: t.StringC;
                password: t.StringC;
                secretName: t.StringC;
                secretArn: t.StringC;
            }>;
            eventStoreClusterArn: t.StringC;
            postgresAdminSecretArn: t.StringC;
            eventStoreId: t.StringC;
            deploymentId: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ eventStoreId, deploymentId }: {
        eventStoreId: string;
    } & {
        deploymentId: string;
    } & {}) => {
        params: {
            eventStoreId: string;
        };
        body: {
            deploymentId: string;
        };
        query: {};
    };
};
export declare type LinkDeployment = ExtractSchemaTypes<typeof LinkDeploymentSchema>;
export declare const UnlinkDeploymentSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "ASYNC";
    Params: t.TypeC<{
        eventStoreId: t.StringC;
    }>;
    Body: t.TypeC<{
        deploymentId: t.StringC;
    }>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.unlinkDeployment>;
        payload: t.TypeC<{
            version: t.StringC;
            user: t.TypeC<{
                userId: t.StringC;
                password: t.StringC;
                secretName: t.StringC;
                secretArn: t.StringC;
            }>;
            eventStoreClusterArn: t.StringC;
            postgresAdminSecretArn: t.StringC;
            eventStoreId: t.StringC;
            deploymentId: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ eventStoreId, deploymentId }: {
        eventStoreId: string;
    } & {
        deploymentId: string;
    } & {}) => {
        params: {
            eventStoreId: string;
        };
        body: {
            deploymentId: string;
        };
        query: {};
    };
};
export declare type UnlinkDeployment = ExtractSchemaTypes<typeof UnlinkDeploymentSchema>;
export declare const ImportEventStoreSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "ASYNC";
    Params: t.TypeC<{
        eventStoreId: t.StringC;
    }>;
    Body: t.TypeC<{
        partIndex: t.NumberC;
    }>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.importEventStore>;
        payload: t.TypeC<{
            version: t.StringC;
            user: t.TypeC<{
                userId: t.StringC;
                password: t.StringC;
                secretName: t.StringC;
                secretArn: t.StringC;
            }>;
            eventStoreId: t.StringC;
            eventStoreDatabaseName: t.StringC;
            eventStoreClusterEndpoint: t.StringC;
            eventStoreClusterPort: t.NumberC;
            bucketName: t.StringC;
            partIndex: t.NumberC;
            accessKeyId: t.StringC;
            secretAccessKey: t.StringC;
            sessionToken: t.StringC;
        }>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ eventStoreId, partIndex }: {
        eventStoreId: string;
    } & {
        partIndex: number;
    } & {}) => {
        params: {
            eventStoreId: string;
        };
        body: {
            partIndex: number;
        };
        query: {};
    };
};
export declare type ImportEventStore = ExtractSchemaTypes<typeof ImportEventStoreSchema>;
export declare const ExportEventStoreSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "PATCH";
    Mode: "ASYNC";
    Params: t.TypeC<{
        eventStoreId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.PartialC<{
        cursor: t.StringC;
    }>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.exportEventStore>;
        payload: t.IntersectionC<[t.TypeC<{
            version: t.StringC;
            user: t.TypeC<{
                userId: t.StringC;
                password: t.StringC;
                secretName: t.StringC;
                secretArn: t.StringC;
            }>;
            eventStoreId: t.StringC;
            eventStoreDatabaseName: t.StringC;
            eventStoreClusterEndpoint: t.StringC;
            eventStoreClusterPort: t.NumberC;
            bucketName: t.StringC;
            importExportStepFunctionArn: t.StringC;
        }>, t.PartialC<{
            cursor: t.StringC;
        }>]>;
    }>;
    Result: t.VoidC;
    ArgumentsTransformer: ({ eventStoreId, cursor }: {
        eventStoreId: string;
    } & {} & {
        cursor?: string | undefined;
    }) => {
        params: {
            eventStoreId: string;
        };
        body: {};
        query: {
            cursor: string | undefined;
        };
    };
};
export declare type ExportEventStore = ExtractSchemaTypes<typeof ExportEventStoreSchema>;
export declare const GetImportUrlsSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "GET";
    Mode: "SYNC";
    Params: t.TypeC<{
        eventStoreId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{
        eventsPartCount: t.StringC;
        secretsPartCount: t.StringC;
    }>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.getImportUrls>;
        payload: t.TypeC<{
            version: t.StringC;
            userId: t.StringC;
            eventStoreId: t.StringC;
            bucketName: t.StringC;
            eventsPartCount: t.NumberC;
            secretsPartCount: t.NumberC;
        }>;
    }>;
    Result: t.TypeC<{
        eventsImportUrls: t.ArrayC<t.StringC>;
        secretsImportUrls: t.ArrayC<t.StringC>;
    }>;
    ArgumentsTransformer: any;
};
export declare type GetImportUrls = ExtractSchemaTypes<typeof GetImportUrlsSchema>;
export declare const GetExportUrlsSchema: {
    Namespace: string;
    Description: string;
    Path: string;
    Method: "GET";
    Mode: "SYNC";
    Params: t.TypeC<{
        eventStoreId: t.StringC;
    }>;
    Body: t.TypeC<{}>;
    Query: t.TypeC<{}>;
    Event: t.TypeC<{
        name: t.LiteralC<FactoryEventNames.getExportUrls>;
        payload: t.TypeC<{
            version: t.StringC;
            userId: t.StringC;
            eventStoreId: t.StringC;
            bucketName: t.StringC;
        }>;
    }>;
    Result: t.TypeC<{
        eventsExportUrl: t.StringC;
        secretsExportUrl: t.StringC;
        statusFileUrl: t.StringC;
    }>;
    ArgumentsTransformer: ({ eventStoreId }: {
        eventStoreId: string;
    } & {} & {}) => {
        params: {
            eventStoreId: string;
        };
        body: {};
        query: {};
    };
};
export declare type GetExportUrls = ExtractSchemaTypes<typeof GetExportUrlsSchema>;
