'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var nanoid = require('nanoid');
var PathReporter = require('io-ts/lib/PathReporter');
var Either = require('fp-ts/lib/Either');
var t = require('io-ts');
var semver = require('semver');
var queryString = require('query-string');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

function _interopNamespace(e) {
    if (e && e.__esModule) return e;
    var n = Object.create(null);
    if (e) {
        Object.keys(e).forEach(function (k) {
            if (k !== 'default') {
                var d = Object.getOwnPropertyDescriptor(e, k);
                Object.defineProperty(n, k, d.get ? d : {
                    enumerable: true,
                    get: function () { return e[k]; }
                });
            }
        });
    }
    n["default"] = e;
    return Object.freeze(n);
}

var t__namespace = /*#__PURE__*/_interopNamespace(t);
var semver__default = /*#__PURE__*/_interopDefaultLegacy(semver);

var STAGE_TAG_NAME = 'resolve-stage';
var VERSION_TAG_NAME = 'resolve-version';
var RESOURCE_TAG_NAME = 'resolve-resource';
var MANAGER_TAG_NAME = 'resolve-manager';
var DOMAIN_TYPE_TAG_NAME = 'resolve-domain-type';
var DOMAIN_CUSTOM_NAME_TAG_NAME = 'resolve-domain-custom-name';
var DOMAIN_NAME_TAG_NAME = 'resolve-domain-name';
var CERTIFICATE_ID_TAG_NAME = 'resolve-certificate-id';
var USER_ID_TAG_NAME = 'resolve-user-id';
var DOMAIN_USERS_TAG_NAME = 'resolve-users';
var EVENT_STORE_ID_TAG_NAME = 'resolve-event-store-id';
var LINKED_DEPLOYMENTS_TAG_NAME = 'resolve-linked-deployments';
var DEPLOYMENT_ID_TAG_NAME = 'resolve-deployment-id';
var APPLICATION_NAME_TAG_NAME = 'resolve-application-name';
var RDS_CLUSTER_NAME_TAG_NAME = 'resolve-rds-cluster-name';
var DEPLOYMENT_TAG_TAG_NAME = 'resolve-deployment-tag';
var CREATED_AT_TAG_NAME = 'resolve-created-at';
var EDGE_REGION = 'us-east-1';
var EVENT_STORE_DATABASE_NAME = 'event-store';
var READ_MODELS_DATABASE_NAME = 'read-models';
var SYSTEM_DATABASE_NAME = 'system';
var CONNECTIONS_TABLE_NAME = 'connections';
var SUBSCRIPTIONS_TABLE_NAME = 'subscriptions';
var PATTERNS_TABLE_NAME = 'patterns';
var NOTIFICATIONS_TABLE_NAME = 'notifications';
var SUBSCRIBERS_TABLE_NAME = 'subscribers';
var BATCHES_TABLE_NAME = 'batches';
var SERIAL_SQL_TYPE = 'serial';
var LONG_INTEGER_SQL_TYPE = 'bigint';
var JSON_SQL_TYPE = 'jsonb';
var STRING_SQL_TYPE = 'VARCHAR(100)';
var TEXT_SQL_TYPE = 'TEXT';
var HEADER_EXECUTION_MODE = 'x-resolve-execution-mode';
exports.DomainCustomNames = void 0;
(function (DomainCustomNames) {
    DomainCustomNames["DEPLOYMENTS"] = "deployments";
    DomainCustomNames["SYSTEM"] = "system";
    DomainCustomNames["STATIC"] = "static";
    DomainCustomNames["UPLOADER"] = "uploader";
})(exports.DomainCustomNames || (exports.DomainCustomNames = {}));
exports.FactoryEventNames = void 0;
(function (FactoryEventNames) {
    /* EventStore */
    FactoryEventNames["createEventStore"] = "createEventStore";
    FactoryEventNames["dropEventStore"] = "dropEventStore";
    FactoryEventNames["describeEventStore"] = "describeEventStore";
    FactoryEventNames["cloneEventStore"] = "cloneEventStore";
    FactoryEventNames["linkDeployment"] = "linkDeployment";
    FactoryEventNames["unlinkDeployment"] = "unlinkDeployment";
    FactoryEventNames["clearEventStore"] = "clearEventStore";
    FactoryEventNames["freezeEventStore"] = "freezeEventStore";
    FactoryEventNames["unfreezeEventStore"] = "unfreezeEventStore";
    FactoryEventNames["importEventStore"] = "importEventStore";
    FactoryEventNames["exportEventStore"] = "exportEventStore";
    FactoryEventNames["getImportUrls"] = "getImportUrls";
    FactoryEventNames["getExportUrls"] = "getExportUrls";
    FactoryEventNames["uploadEventsToS3"] = "uploadEventsToS3";
    /* ReadModel */
    FactoryEventNames["createReadModel"] = "createReadModel";
    FactoryEventNames["dropReadModel"] = "dropReadModel";
    FactoryEventNames["listReadModels"] = "listReadModels";
    FactoryEventNames["pauseReadModel"] = "pauseReadModel";
    FactoryEventNames["resetReadModel"] = "resetReadModel";
    FactoryEventNames["resumeReadModel"] = "resumeReadModel";
    /* Saga */
    FactoryEventNames["listSagas"] = "listSagas";
    FactoryEventNames["pauseSaga"] = "pauseSaga";
    FactoryEventNames["resetSaga"] = "resetSaga";
    FactoryEventNames["resumeSaga"] = "resumeSaga";
    FactoryEventNames["listSagaProperties"] = "listSagaProperties";
    FactoryEventNames["setSagaProperty"] = "setSagaProperty";
    FactoryEventNames["deleteSagaProperty"] = "deleteSagaProperty";
    FactoryEventNames["getSagaProperty"] = "getSagaProperty";
    /* Lifecycle */
    FactoryEventNames["bootstrapDeployment"] = "bootstrapDeployment";
    FactoryEventNames["shutdownDeployment"] = "shutdownDeployment";
    FactoryEventNames["dropEventSubscribers"] = "dropEventSubscribers";
})(exports.FactoryEventNames || (exports.FactoryEventNames = {}));
exports.BuilderEventNames = void 0;
(function (BuilderEventNames) {
    BuilderEventNames["buildCode"] = "buildCode";
    BuilderEventNames["deployStatic"] = "deployStatic";
})(exports.BuilderEventNames || (exports.BuilderEventNames = {}));
exports.InstallerEventNames = void 0;
(function (InstallerEventNames) {
    InstallerEventNames["heartbeat"] = "heartbeat";
    InstallerEventNames["authLogin"] = "authLogin";
    InstallerEventNames["authLogout"] = "authLogout";
    InstallerEventNames["authRefreshToken"] = "authRefreshToken";
    InstallerEventNames["authWhoAmI"] = "authWhoAmI";
    InstallerEventNames["installStageResources"] = "installStageResources";
    InstallerEventNames["uninstallStageResources"] = "uninstallStageResources";
    InstallerEventNames["installVersionResources"] = "installVersionResources";
    InstallerEventNames["uninstallVersionResources"] = "uninstallVersionResources";
    InstallerEventNames["uninstallVersionAssetsFolder"] = "uninstallVersionAssetsFolder";
    InstallerEventNames["installAssetsBucket"] = "installAssetsBucket";
    InstallerEventNames["uninstallAssetsBucket"] = "uninstallAssetsBucket";
    InstallerEventNames["getAssetsStageBucketUploadSignedUrls"] = "getAssetsStageBucketUploadSignedUrls";
    InstallerEventNames["getAssetsVersionBucketUploadSignedUrls"] = "getAssetsVersionBucketUploadSignedUrls";
    InstallerEventNames["describe"] = "describe";
    InstallerEventNames["describeExecution"] = "describeExecution";
    InstallerEventNames["ensureCertificate"] = "ensureCertificate";
    InstallerEventNames["dropCertificate"] = "dropCertificate";
    InstallerEventNames["getCertificateById"] = "getCertificateById";
    InstallerEventNames["listCertificates"] = "listCertificates";
    InstallerEventNames["getCertificateByDomainName"] = "getCertificateByDomainName";
    InstallerEventNames["createStaticDomain"] = "createStaticDomain";
    InstallerEventNames["createProxyDomain"] = "createProxyDomain";
    InstallerEventNames["createUploaderDomain"] = "createUploaderDomain";
    InstallerEventNames["dropDomain"] = "dropDomain";
    InstallerEventNames["setDomainUsers"] = "setDomainUsers";
    InstallerEventNames["addDomainUser"] = "addDomainUser";
    InstallerEventNames["removeDomainUser"] = "removeDomainUser";
    InstallerEventNames["releaseDomain"] = "releaseDomain";
    InstallerEventNames["getDomain"] = "getDomain";
    InstallerEventNames["listDomains"] = "listDomains";
    InstallerEventNames["verifyDomain"] = "verifyDomain";
    InstallerEventNames["getVerificationCode"] = "getVerificationCode";
    InstallerEventNames["createUser"] = "createUser";
    InstallerEventNames["dropUser"] = "dropUser";
    InstallerEventNames["getUser"] = "getUser";
    InstallerEventNames["getUserIdByEmail"] = "getUserIdByEmail";
    InstallerEventNames["listUsers"] = "listUsers";
    InstallerEventNames["attachClientAppUrls"] = "attachClientAppUrls";
    InstallerEventNames["detachClientAppUrls"] = "detachClientAppUrls";
    InstallerEventNames["executeFactory"] = "executeFactory";
    InstallerEventNames["setVirtualHost"] = "setVirtualHost";
    InstallerEventNames["unsetVirtualHost"] = "unsetVirtualHost";
    InstallerEventNames["listVirtualHosts"] = "listVirtualHosts";
    InstallerEventNames["getClientAppConfig"] = "getClientAppConfig";
    InstallerEventNames["enableLogs"] = "enableLogs";
    InstallerEventNames["disableLogs"] = "disableLogs";
    InstallerEventNames["getLogs"] = "getLogs";
    InstallerEventNames["removeLogs"] = "removeLogs";
    InstallerEventNames["updateEnvironmentVariables"] = "updateEnvironmentVariables";
    InstallerEventNames["listEnvironmentVariables"] = "listEnvironmentVariables";
    InstallerEventNames["enableTracing"] = "enableTracing";
    InstallerEventNames["disableTracing"] = "disableTracing";
    InstallerEventNames["getTracingDetails"] = "getTracingDetails";
    InstallerEventNames["getSummaries"] = "getSummaries";
    InstallerEventNames["getTracingStatus"] = "getTracingStatus";
    InstallerEventNames["describeDeployment"] = "describeDeployment";
    InstallerEventNames["listDeployments"] = "listDeployments";
    InstallerEventNames["createDeployment"] = "createDeployment";
    InstallerEventNames["getDeploymentUploadSignedUrl"] = "getDeploymentUploadSignedUrl";
    InstallerEventNames["buildDeployment"] = "buildDeployment";
    InstallerEventNames["dropDeployment"] = "dropDeployment";
    InstallerEventNames["getDeploymentByApplicationName"] = "getDeploymentByApplicationName";
    InstallerEventNames["getDeploymentByTag"] = "getDeploymentByTag";
    InstallerEventNames["setDeploymentDomain"] = "setDeploymentDomain";
    InstallerEventNames["unsetDeploymentDomain"] = "unsetDeploymentDomain";
    InstallerEventNames["listEventStores"] = "listEventStores";
    InstallerEventNames["ensureRdsUser"] = "ensureRdsUser";
    InstallerEventNames["listVersions"] = "listVersions";
    InstallerEventNames["createDnsRecord"] = "createDnsRecord";
    InstallerEventNames["deleteDnsRecord"] = "deleteDnsRecord";
    InstallerEventNames["listDnsRecords"] = "listDnsRecords";
    InstallerEventNames["listHostedZones"] = "listHostedZones";
    InstallerEventNames["getEventStore"] = "getEventStore";
    InstallerEventNames["setDeploymentTag"] = "setDeploymentTag";
    InstallerEventNames["unsetDeploymentTag"] = "unsetDeploymentTag";
    InstallerEventNames["describeRDSClusters"] = "describeRDSClusters";
    InstallerEventNames["addNotificationsWebhook"] = "addNotificationsWebhook";
    InstallerEventNames["deleteNotificationsWebhook"] = "deleteNotificationsWebhook";
    InstallerEventNames["listNotificationsWebhooks"] = "listNotificationsWebhooks";
    InstallerEventNames["ensureRuntime"] = "ensureRuntime";
    InstallerEventNames["switchApplicationsRuntime"] = "switchApplicationsRuntime";
    InstallerEventNames["findRuntime"] = "findRuntime";
})(exports.InstallerEventNames || (exports.InstallerEventNames = {}));

var generateExecutionId = nanoid.customAlphabet('0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz-_', 16);
var getFirstCharacter = nanoid.customAlphabet('abcdefghijklmnopqrstuvwxyz', 1);
var getRandomCharacters = nanoid.customAlphabet('0123456789abcdefghijklmnopqrstuvwxyz', 5);
var generateEventStoreId = function () { return [getFirstCharacter(), getRandomCharacters()].join(''); };
var generateDeploymentId = function () { return [getFirstCharacter(), getRandomCharacters()].join(''); };

function validate(schema, params, errorName) {
    var validationResult = schema.decode(params);
    if (!Either.isRight(validationResult)) {
        var messages = PathReporter.PathReporter.report(validationResult);
        var error = new Error(messages.join('\r\n'));
        if (errorName != null) {
            error.name = errorName;
        }
        throw error;
    }
    return params;
}

var VirtualHostsSchema = t__namespace.array(t__namespace.type({
    virtualHost: t__namespace.string,
    functionArn: t__namespace.string,
}));
var DomainUsersSchema = t__namespace.union([t__namespace.literal('*'), t__namespace.array(t__namespace.string)]);
var DomainTypeSchema = t__namespace.union([
    t__namespace.literal('proxy'),
    t__namespace.literal('static'),
    t__namespace.literal('uploader'),
]);
var DomainSchema = t__namespace.type({
    domainId: t__namespace.string,
    domainType: DomainTypeSchema,
    domainName: t__namespace.string,
    resourceARN: t__namespace.string,
    aliases: t__namespace.array(t__namespace.string),
    verified: t__namespace.boolean,
    owner: t__namespace.string,
    users: DomainUsersSchema,
    verificationCode: t__namespace.string,
    certificateId: t__namespace.string,
});
var DomainsSchema = t__namespace.array(DomainSchema);
var DeploymentSchema = t__namespace.intersection([
    t__namespace.type({
        deploymentId: t__namespace.string,
        applicationName: t__namespace.string,
        version: t__namespace.string,
        domains: t__namespace.array(t__namespace.string),
    }),
    t__namespace.partial({
        eventStoreId: t__namespace.string,
    }),
]);
var CognitoUserSchema = t__namespace.type({
    userId: t__namespace.string,
    email: t__namespace.string,
    enabled: t__namespace.boolean,
    userStatus: t__namespace.string,
    isAdmin: t__namespace.boolean,
});
var CognitoJWTPayloadSchema = t__namespace.intersection([
    t__namespace.type({
        sub: t__namespace.string,
        aud: t__namespace.string,
        event_id: t__namespace.string,
        token_use: t__namespace.literal('id'),
        auth_time: t__namespace.number,
        iss: t__namespace.string,
        'cognito:username': t__namespace.string,
        exp: t__namespace.number,
        iat: t__namespace.number,
        email: t__namespace.string,
    }),
    t__namespace.partial({
        'cognito:groups': t__namespace.array(t__namespace.string),
        email_verified: t__namespace.boolean,
    }),
]);
var CognitoJWTHeaderSchema = t__namespace.type({
    kid: t__namespace.string,
    alg: t__namespace.literal('RS256'),
});
var ClientApiEventSchema = t__namespace.type({
    httpMethod: t__namespace.string,
    headers: t__namespace.array(t__namespace.type({ key: t__namespace.string, value: t__namespace.string })),
    uri: t__namespace.string,
    querystring: t__namespace.string,
    body: t__namespace.string, // Base64
});
var ClientApiResultSchema = t__namespace.type({
    httpStatus: t__namespace.number,
    httpStatusText: t__namespace.string,
    headers: t__namespace.array(t__namespace.type({ key: t__namespace.string, value: t__namespace.string })),
    body: t__namespace.string, // Base64
});
var CertificateSchema = t__namespace.intersection([
    t__namespace.type({
        certificateId: t__namespace.string,
        additionalNames: t__namespace.array(t__namespace.string),
        resourceARN: t__namespace.string,
    }),
    t__namespace.partial({
        domainName: t__namespace.string,
        importedAt: t__namespace.string,
        issuer: t__namespace.string,
        notBefore: t__namespace.string,
        notAfter: t__namespace.string,
    }),
]);
var RDSUserSchema = t__namespace.type({
    userId: t__namespace.string,
    password: t__namespace.string,
    secretName: t__namespace.string,
    secretArn: t__namespace.string,
});
var IS_RESOLVE_CLOUD_SDK_SCHEMA = Symbol('IS_RESOLVE_CLOUD_SDK_SCHEMA');
var defineSchema = function (route) {
    var _a;
    Object.assign(route, (_a = {}, _a[IS_RESOLVE_CLOUD_SDK_SCHEMA] = true, _a));
    return route;
};

var getXRangeVersion = function (version) {
    var parsedVersion = semver__default["default"].parse(version);
    if (parsedVersion == null) {
        throw new Error("Parse version \"".concat(version, "\" failed"));
    }
    var major = parsedVersion.major, minor = parsedVersion.minor;
    return "".concat(major, ".").concat(minor, ".x");
};
var coerceVersion = function (version) { return semver__default["default"].valid(semver__default["default"].coerce(version)); };
var intersectsVersions = function (range, version) {
    var parsedRange = "".concat(semver__default["default"].major(range), ".").concat(semver__default["default"].minor(range), ".x");
    var parsedVersion = "".concat(semver__default["default"].major(version), ".").concat(semver__default["default"].minor(version), ".").concat(semver__default["default"].patch(version));
    return semver__default["default"].intersects(parsedRange, parsedVersion);
};

var ipV4RegExp = /[0-9]+.[0-9]+.[0-9]+.[0-9]+/;
var rateExceededRegExp = /Rate exceeded/;
var socketHangUpRegExp = /socket hang up/;
var throttledRegExp = /The Lambda function associated with the CloudFront distribution was throttled/;
var requiredPermissionsRegExp = /The Lambda function associated with the CloudFront distribution is invalid or doesn't have the required permissions/;
var eTimedOutRegExp = /ETIMEDOUT/;
var eConnectionResetRegExp = /ECONNRESET/;
var eNotFoundRegExp = /ENOTFOUND/;
var eProtoRegExp = /EPROTO/;
var eHostUnreach = /EHOSTUNREACH/;
var eConnRefused = /ECONNREFUSED/;
var cloudFrontError = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>";
var lambdaEdgeTimeout = 'lambda@edge timeout';
var failedToSetupAuthentication = 'Failed to setup authentication';
var isNetworkError = function (_a) {
    var errorText = _a.errorText;
    return eTimedOutRegExp.test(errorText) ||
        eConnectionResetRegExp.test(errorText) ||
        eNotFoundRegExp.test(errorText) ||
        eProtoRegExp.test(errorText) ||
        eHostUnreach.test(errorText) ||
        eConnRefused.test(errorText) ||
        socketHangUpRegExp.test(errorText) ||
        errorText.includes(lambdaEdgeTimeout) ||
        errorText.includes(failedToSetupAuthentication) ||
        errorText.includes(cloudFrontError);
};
var isLambdaError = function (_a) {
    var errorText = _a.errorText;
    return rateExceededRegExp.test(errorText) ||
        throttledRegExp.test(errorText) ||
        requiredPermissionsRegExp.test(errorText);
};
var isHeartbeat = function (_a) {
    var method = _a.method;
    return method === 'HEAD';
};
var isUrlContainIp = function (_a) {
    var baseUrl = _a.baseUrl;
    return ipV4RegExp.test(baseUrl);
};
var isRetryable = function (params) {
    return !isHeartbeat(params) && (isLambdaError(params) || isNetworkError(params));
};

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise */

var extendStatics = function(d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
    return extendStatics(d, b);
};

function __extends(d, b) {
    if (typeof b !== "function" && b !== null)
        throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

var FATAL_ERROR_MESSAGE = 'Please contact the ReSolve team by e-mail: reimagined@devexpress.com';
var FatalError = /** @class */ (function (_super) {
    __extends(FatalError, _super);
    function FatalError(message) {
        return _super.call(this, message == null || message.trim() === ''
            ? FATAL_ERROR_MESSAGE
            : "".concat(message, ". ").concat(FATAL_ERROR_MESSAGE)) || this;
    }
    return FatalError;
}(Error));

var Namespace$c = 'System';
/* Heartbeat */
var HeartbeatSchema = defineSchema({
    Namespace: Namespace$c,
    Description: 'Check if the service is available.',
    Path: '/v0',
    Method: 'HEAD',
    Mode: 'SYNC',
    Params: t__namespace.type({}),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.heartbeat),
        payload: t__namespace.void,
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});
/* ListVersions */
var ListVersionsSchema = defineSchema({
    Namespace: Namespace$c,
    Description: 'Get a list of the available reSolve versions.',
    Path: '/v0/runtimes',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({}),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.listVersions),
        payload: t__namespace.UnknownRecord,
    }),
    Result: t__namespace.array(t__namespace.string),
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});
/* DescribeExecution */
var DescribeExecutionSchema = defineSchema({
    Namespace: Namespace$c,
    Description: 'Get the status of a long-running operation specified by its ID.',
    Path: '/v0/describe-execution/:executionId',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({
        executionId: t__namespace.string,
    }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.describeExecution),
        payload: t__namespace.type({
            executionId: t__namespace.string,
            userId: t__namespace.string,
        }),
    }),
    Result: t__namespace.type({
        status: t__namespace.union([
            t__namespace.literal('RUNNING'),
            t__namespace.literal('SUCCEEDED'),
            t__namespace.literal('FAILED'),
            t__namespace.literal('TIMED_OUT'),
            t__namespace.literal('ABORTED'),
        ]),
        output: t__namespace.any,
    }),
    ArgumentsTransformer: function (args) { return ({
        params: { executionId: args.executionId },
        body: {},
        query: {},
    }); },
});
/* GetClientAppConfig */
var GetClientAppConfigSchema = defineSchema({
    Namespace: Namespace$c,
    Description: "Get reSolve Cloud's app client ID and user pool ID on Amazon Cognito.",
    Path: '/v0/client-app-config',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({}),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.getClientAppConfig),
        payload: t__namespace.type({}),
    }),
    Result: t__namespace.type({
        clientId: t__namespace.string,
        userPoolId: t__namespace.string,
    }),
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});

var Namespace$b = 'Deployments';
/* CreateDeployment */
var CreateDeploymentSchema = defineSchema({
    Namespace: Namespace$b,
    Description: 'Create a new deployment.',
    Path: '/v0/deployments',
    Method: 'POST',
    Mode: 'ASYNC',
    Params: t__namespace.type({}),
    Body: t__namespace.intersection([
        t__namespace.type({
            applicationName: t__namespace.string,
            version: t__namespace.string,
            eventStoreId: t__namespace.string,
        }),
        t__namespace.partial({
            domain: t__namespace.string,
        }),
    ]),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.createDeployment),
        payload: t__namespace.intersection([
            t__namespace.type({
                userId: t__namespace.string,
                applicationName: t__namespace.string,
                version: t__namespace.string,
                eventStoreId: t__namespace.string,
            }),
            t__namespace.partial({
                domain: t__namespace.string,
                deploymentTag: t__namespace.string,
            }),
        ]),
    }),
    Result: DeploymentSchema,
    ArgumentsTransformer: function (args) { return ({
        params: {},
        body: args,
        query: {},
    }); },
});
/* DropDeployment */
var DropDeploymentSchema = defineSchema({
    Namespace: Namespace$b,
    Description: 'Remove an existing deployment.',
    Path: '/v0/deployments/:deploymentId',
    Method: 'DELETE',
    Mode: 'ASYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.partial({ withEventStore: t__namespace.boolean }),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.dropDeployment),
        payload: t__namespace.intersection([
            t__namespace.type({
                userId: t__namespace.string,
                deploymentId: t__namespace.string,
            }),
            t__namespace.partial({
                withEventStore: t__namespace.boolean,
            }),
        ]),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, withEventStore = _a.withEventStore;
        return ({
            params: { deploymentId: deploymentId },
            body: { withEventStore: withEventStore },
            query: {},
        });
    },
});
/* ListDeployments */
var ListDeploymentsSchema = defineSchema({
    Namespace: Namespace$b,
    Description: 'Get a list of existing deployments.',
    Path: '/v0/deployments',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({}),
    Body: t__namespace.type({}),
    Query: t__namespace.partial({ applicationName: t__namespace.string }),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.listDeployments),
        payload: t__namespace.intersection([
            t__namespace.type({
                userId: t__namespace.string,
            }),
            t__namespace.partial({
                applicationName: t__namespace.string,
            }),
        ]),
    }),
    Result: t__namespace.array(DeploymentSchema),
    ArgumentsTransformer: function (_a) {
        var _b = _a === void 0 ? {} : _a, applicationName = _b.applicationName;
        return ({
            params: {},
            body: {},
            query: { applicationName: applicationName },
        });
    },
});
/* DescribeDeployment */
var DescribeDeploymentSchema = defineSchema({
    Namespace: Namespace$b,
    Description: 'Obtain information about a deployment.',
    Path: '/v0/deployments/:deploymentId',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.describeDeployment),
        payload: t__namespace.type({
            userId: t__namespace.string,
            deploymentId: t__namespace.string,
        }),
    }),
    Result: DeploymentSchema,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});
/* BootstrapDeployment */
var BootstrapDeploymentSchema = defineSchema({
    Namespace: Namespace$b,
    Description: 'Run the specified deployment.',
    Path: '/v0/deployments/:deploymentId/bootstrap',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.bootstrapDeployment),
        payload: t__namespace.type({
            version: t__namespace.string,
            userId: t__namespace.string,
            deploymentId: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});
/* ShutdownDeployment */
var ShutdownDeploymentSchema = defineSchema({
    Namespace: Namespace$b,
    Description: 'Shut down a deployment.',
    Path: '/v0/deployments/:deploymentId/shutdown',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.shutdownDeployment),
        payload: t__namespace.type({
            version: t__namespace.string,
            userId: t__namespace.string,
            deploymentId: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});
/* Build Deployment */
var BuildDeploymentSchema = defineSchema({
    Namespace: Namespace$b,
    Description: 'Build an uploaded application on the cloud.',
    Path: '/v0/deployments/:deploymentId/upload',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.partial({
        npmRegistry: t__namespace.string,
    }),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.buildDeployment),
        payload: t__namespace.intersection([
            t__namespace.type({
                userId: t__namespace.string,
                deploymentId: t__namespace.string,
            }),
            t__namespace.partial({
                npmRegistry: t__namespace.string,
            }),
        ]),
    }),
    Result: t__namespace.type({
        installLog: t__namespace.string,
        files: t__namespace.array(t__namespace.string),
    }),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, npmRegistry = _a.npmRegistry;
        return ({
            params: { deploymentId: deploymentId },
            body: { npmRegistry: npmRegistry },
            query: {},
        });
    },
});
/* GetDeploymentUploadSignedUrl */
var GetDeploymentUploadSignedUrlSchema = defineSchema({
    Namespace: Namespace$b,
    Description: "Get URLs used to upload an application's source code and static resources.",
    Path: '/v0/deployments/:deploymentId/upload',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.getDeploymentUploadSignedUrl),
        payload: t__namespace.type({
            userId: t__namespace.string,
            deploymentId: t__namespace.string,
        }),
    }),
    Result: t__namespace.type({
        codeUploadUrl: t__namespace.string,
        staticUploadUrl: t__namespace.string,
    }),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});

var Namespace$a = 'Deployments / Domains';
/* SetDeploymentDomain */
var SetDeploymentDomainSchema = defineSchema({
    Namespace: Namespace$a,
    Description: 'Assigns a domain to a deployment.',
    Path: '/v0/deployments/:deploymentId/domain',
    Method: 'PUT',
    Mode: 'ASYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({ domain: t__namespace.string }),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.setDeploymentDomain),
        payload: t__namespace.type({
            userId: t__namespace.string,
            deploymentId: t__namespace.string,
            domain: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, domain = _a.domain;
        return ({
            params: { deploymentId: deploymentId },
            body: { domain: domain },
            query: {},
        });
    },
});
/* UnsetDeploymentDomain */
var UnsetDeploymentDomainSchema = defineSchema({
    Namespace: Namespace$a,
    Description: 'Detach a domain from a deployment.',
    Path: '/v0/deployments/:deploymentId/domain',
    Method: 'DELETE',
    Mode: 'ASYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({ domain: t__namespace.string }),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.unsetDeploymentDomain),
        payload: t__namespace.type({
            userId: t__namespace.string,
            deploymentId: t__namespace.string,
            domain: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, domain = _a.domain;
        return ({
            params: { deploymentId: deploymentId },
            body: { domain: domain },
            query: {},
        });
    },
});

/* UpdateEnvironmentVariables */
var UpdateEnvironmentVariablesSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.updateEnvironmentVariables),
        payload: t__namespace.type({
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
            variables: t__namespace.record(t__namespace.string, t__namespace.union([t__namespace.string, t__namespace.null])),
        }),
    }),
    Result: t__namespace.void,
});

var Namespace$9 = 'Deployments / Environment variables';
/* SetEnvironmentVariables */
var SetEnvironmentVariablesSchema = defineSchema({
    Namespace: Namespace$9,
    Description: 'Set environment variables for a deployment.',
    Path: '/v0/deployments/:deploymentId/environment',
    Method: 'PUT',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({
        variables: t__namespace.record(t__namespace.string, t__namespace.string),
    }),
    Query: t__namespace.type({}),
    Event: UpdateEnvironmentVariablesSchema.Event,
    Result: UpdateEnvironmentVariablesSchema.Result,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, variables = _a.variables;
        return ({
            params: { deploymentId: deploymentId },
            body: { variables: variables },
            query: {},
        });
    },
});
/* RemoveEnvironmentVariables */
var RemoveEnvironmentVariablesSchema = defineSchema({
    Namespace: Namespace$9,
    Description: 'Remove environment variables.',
    Path: '/v0/deployments/:deploymentId/environment',
    Method: 'DELETE',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({
        variables: t__namespace.array(t__namespace.string),
    }),
    Query: t__namespace.type({}),
    Event: UpdateEnvironmentVariablesSchema.Event,
    Result: UpdateEnvironmentVariablesSchema.Result,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, variables = _a.variables;
        return ({
            params: { deploymentId: deploymentId },
            body: { variables: variables },
            query: {},
        });
    },
});
/* ListEnvironmentVariables */
var ListEnvironmentVariablesSchema = defineSchema({
    Namespace: Namespace$9,
    Description: "Get a list of a deployment's environment variables.",
    Path: '/v0/deployments/:deploymentId/environment',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.listEnvironmentVariables),
        payload: t__namespace.type({
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
        }),
    }),
    Result: t__namespace.record(t__namespace.string, t__namespace.string),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});

var Namespace$8 = 'Deployments / Logs';
var LogLevelSchema = t__namespace.union([
    t__namespace.literal('log'),
    t__namespace.literal('error'),
    t__namespace.literal('warn'),
    t__namespace.literal('debug'),
    t__namespace.literal('info'),
    t__namespace.literal('verbose'),
]);
/* EnableLogs */
var EnableLogsSchema = defineSchema({
    Namespace: Namespace$8,
    Description: 'Enable logs for a deployment.',
    Path: '/v0/deployments/:deploymentId/logs/enable',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.partial({
        logLevel: LogLevelSchema,
        scope: t__namespace.string,
    }),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.enableLogs),
        payload: t__namespace.intersection([
            t__namespace.type({
                deploymentId: t__namespace.string,
                userId: t__namespace.string,
            }),
            t__namespace.partial({
                logLevel: LogLevelSchema,
                scope: t__namespace.string,
            }),
        ]),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, scope = _a.scope, logLevel = _a.logLevel;
        return ({
            params: { deploymentId: deploymentId },
            body: { scope: scope, logLevel: logLevel },
            query: {},
        });
    },
});
/* DisableLogs */
var DisableLogsSchema = defineSchema({
    Namespace: Namespace$8,
    Description: 'Disable logs for a deployment.',
    Path: '/v0/deployments/:deploymentId/logs/disable',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.disableLogs),
        payload: t__namespace.type({
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});
/* GetLogs */
var GetLogsSchema = defineSchema({
    Namespace: Namespace$8,
    Description: 'Get logs for a time interval.',
    Path: '/v0/deployments/:deploymentId/logs',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.partial({
        startTime: t__namespace.string,
        endTime: t__namespace.string,
        filterPattern: t__namespace.string,
        streamLimit: t__namespace.string,
    }),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.getLogs),
        payload: t__namespace.intersection([
            t__namespace.type({
                deploymentId: t__namespace.string,
                userId: t__namespace.string,
            }),
            t__namespace.partial({
                streamLimit: t__namespace.number,
                startTime: t__namespace.number,
                endTime: t__namespace.number,
                filterPattern: t__namespace.string,
            }),
        ]),
    }),
    Result: t__namespace.string,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, streamLimit = _a.streamLimit, startTime = _a.startTime, endTime = _a.endTime, filterPattern = _a.filterPattern;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {
                streamLimit: streamLimit,
                startTime: startTime,
                endTime: endTime,
                filterPattern: filterPattern,
            },
        });
    },
});
/* RemoveLogs */
var RemoveLogsSchema = defineSchema({
    Namespace: Namespace$8,
    Description: "Remove a deployment's logs.",
    Path: '/v0/deployments/:deploymentId/logs',
    Method: 'DELETE',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.removeLogs),
        payload: t__namespace.type({
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});

var Namespace$7 = 'Deployments / Sagas';
/* PauseSaga */
var PauseSagaSchema = defineSchema({
    Namespace: Namespace$7,
    Description: 'Pause saga updates.',
    Path: '/v0/deployments/:deploymentId/sagas/:sagaName/pause',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string, sagaName: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.pauseSaga),
        payload: t__namespace.type({
            version: t__namespace.string,
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
            eventListener: t__namespace.string,
        }),
    }),
    Result: t__namespace.any,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, sagaName = _a.sagaName;
        return ({
            params: { deploymentId: deploymentId, sagaName: sagaName },
            body: {},
            query: {},
        });
    },
});
/* ResetSaga */
var ResetSagaSchema = defineSchema({
    Namespace: Namespace$7,
    Description: "Reset a saga's persistent state.",
    Path: '/v0/deployments/:deploymentId/sagas/:sagaName/reset',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string, sagaName: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.resetSaga),
        payload: t__namespace.type({
            version: t__namespace.string,
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
            eventListener: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, sagaName = _a.sagaName;
        return ({
            params: { deploymentId: deploymentId, sagaName: sagaName },
            body: {},
            query: {},
        });
    },
});
/* ResumeSaga */
var ResumeSagaSchema = defineSchema({
    Namespace: Namespace$7,
    Description: 'Resume saga updates.',
    Path: '/v0/deployments/:deploymentId/sagas/:sagaName/resume',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string, sagaName: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.resumeSaga),
        payload: t__namespace.type({
            version: t__namespace.string,
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
            eventListener: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, sagaName = _a.sagaName;
        return ({
            params: { deploymentId: deploymentId, sagaName: sagaName },
            body: {},
            query: {},
        });
    },
});
/* ListSagas */
var ListSagasSchema = defineSchema({
    Namespace: Namespace$7,
    Description: "Get the list of a deployment's sagas.",
    Path: '/v0/deployments/:deploymentId/sagas',
    Method: 'GET',
    Mode: 'ASYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.listSagas),
        payload: t__namespace.type({
            version: t__namespace.string,
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
        }),
    }),
    Result: t__namespace.array(t__namespace.type({
        name: t__namespace.string,
        status: t__namespace.union([t__namespace.string, t__namespace.null]),
        successEvent: t__namespace.union([t__namespace.record(t__namespace.string, t__namespace.any), t__namespace.null]),
        failedEvent: t__namespace.union([t__namespace.record(t__namespace.string, t__namespace.any), t__namespace.null]),
        errors: t__namespace.array(t__namespace.type({
            name: t__namespace.string,
            message: t__namespace.string,
            stack: t__namespace.string,
        })),
    })),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});

var Namespace$6 = 'Deployments / Sagas / Properties';
/* SetSagaProperty */
var SetSagaPropertySchema = defineSchema({
    Namespace: Namespace$6,
    Description: 'Assign a value to a saga property.',
    Path: '/v0/deployments/:deploymentId/sagas/:sagaName/properties',
    Method: 'PUT',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string, sagaName: t__namespace.string }),
    Body: t__namespace.type({
        key: t__namespace.string,
        value: t__namespace.string,
    }),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.setSagaProperty),
        payload: t__namespace.type({
            version: t__namespace.string,
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
            eventListener: t__namespace.string,
            key: t__namespace.string,
            value: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, sagaName = _a.sagaName, key = _a.key, value = _a.value;
        return ({
            params: { deploymentId: deploymentId, sagaName: sagaName },
            body: { key: key, value: value },
            query: {},
        });
    },
});
/* DeleteSagaProperty */
var DeleteSagaPropertySchema = defineSchema({
    Namespace: Namespace$6,
    Description: 'Delete a saga property.',
    Path: '/v0/deployments/:deploymentId/sagas/:sagaName/properties/:key',
    Method: 'DELETE',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string, sagaName: t__namespace.string, key: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.deleteSagaProperty),
        payload: t__namespace.type({
            version: t__namespace.string,
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
            eventListener: t__namespace.string,
            key: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, sagaName = _a.sagaName, key = _a.key;
        return ({
            params: { deploymentId: deploymentId, sagaName: sagaName, key: key },
            body: {},
            query: {},
        });
    },
});
/* GetSagaProperty */
var GetSagaPropertySchema = defineSchema({
    Namespace: Namespace$6,
    Description: "Get a saga property's value.",
    Path: '/v0/deployments/:deploymentId/sagas/:sagaName/properties/:key',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string, sagaName: t__namespace.string, key: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.getSagaProperty),
        payload: t__namespace.type({
            version: t__namespace.string,
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
            eventListener: t__namespace.string,
            key: t__namespace.string,
        }),
    }),
    Result: t__namespace.record(t__namespace.string, t__namespace.any),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, sagaName = _a.sagaName, key = _a.key;
        return ({
            params: { deploymentId: deploymentId, sagaName: sagaName, key: key },
            body: {},
            query: {},
        });
    },
});
/* ListSagaProperties */
var ListSagaPropertiesSchema = defineSchema({
    Namespace: Namespace$6,
    Description: 'Get the list of assigned saga properties.',
    Path: '/v0/deployments/:deploymentId/sagas/:sagaName/properties',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string, sagaName: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.listSagaProperties),
        payload: t__namespace.type({
            version: t__namespace.string,
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
            eventListener: t__namespace.string,
        }),
    }),
    Result: t__namespace.any,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, sagaName = _a.sagaName;
        return ({
            params: { deploymentId: deploymentId, sagaName: sagaName },
            body: {},
            query: {},
        });
    },
});

var Namespace$5 = 'Deployments / Read models';
/* PauseReadModel */
var PauseReadModelSchema = defineSchema({
    Namespace: Namespace$5,
    Description: 'Pause read model updates.',
    Path: '/v0/deployments/:deploymentId/read-models/:readModelName/pause',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string, readModelName: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.pauseReadModel),
        payload: t__namespace.type({
            version: t__namespace.string,
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
            eventListener: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, readModelName = _a.readModelName;
        return ({
            params: { deploymentId: deploymentId, readModelName: readModelName },
            body: {},
            query: {},
        });
    },
});
/* ResetReadModel */
var ResetReadModelSchema = defineSchema({
    Namespace: Namespace$5,
    Description: "Reset a read model's persistent state.",
    Path: '/v0/deployments/:deploymentId/read-models/:readModelName/reset',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string, readModelName: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.resetReadModel),
        payload: t__namespace.type({
            version: t__namespace.string,
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
            eventListener: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, readModelName = _a.readModelName;
        return ({
            params: { deploymentId: deploymentId, readModelName: readModelName },
            body: {},
            query: {},
        });
    },
});
/* ResumeReadModel */
var ResumeReadModelSchema = defineSchema({
    Namespace: Namespace$5,
    Description: 'Resume read model updates.',
    Path: '/v0/deployments/:deploymentId/read-models/:readModelName/resume',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string, readModelName: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.resumeReadModel),
        payload: t__namespace.type({
            version: t__namespace.string,
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
            eventListener: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, readModelName = _a.readModelName;
        return ({
            params: { deploymentId: deploymentId, readModelName: readModelName },
            body: {},
            query: {},
        });
    },
});
/* ListReadModels */
var ListReadModelsSchema = defineSchema({
    Namespace: Namespace$5,
    Description: "Obtain the list of a deployment's read models.",
    Path: '/v0/deployments/:deploymentId/read-models',
    Method: 'GET',
    Mode: 'ASYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.listReadModels),
        payload: t__namespace.type({
            version: t__namespace.string,
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
        }),
    }),
    Result: t__namespace.array(t__namespace.type({
        name: t__namespace.string,
        status: t__namespace.union([t__namespace.string, t__namespace.null]),
        successEvent: t__namespace.union([t__namespace.record(t__namespace.string, t__namespace.any), t__namespace.null]),
        failedEvent: t__namespace.union([t__namespace.record(t__namespace.string, t__namespace.any), t__namespace.null]),
        errors: t__namespace.array(t__namespace.type({
            name: t__namespace.string,
            message: t__namespace.string,
            stack: t__namespace.string,
        })),
    })),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});
/* CreateReadModel */
var CreateReadModelSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.createReadModel),
        payload: t__namespace.type({
            version: t__namespace.string,
            deploymentId: t__namespace.string,
            user: RDSUserSchema,
            readModelsClusterArn: t__namespace.string,
            postgresAdminSecretArn: t__namespace.string,
            readModelsClusterEndpoint: t__namespace.string,
            readModelsClusterPort: t__namespace.number,
            postgresAdminUsername: t__namespace.string,
            postgresAdminPassword: t__namespace.string,
        }),
    }),
    Result: t__namespace.type({
        readModelDatabaseName: t__namespace.string,
    }),
});
/* DropReadModel */
var DropReadModelSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.dropReadModel),
        payload: t__namespace.type({
            version: t__namespace.string,
            deploymentId: t__namespace.string,
            user: RDSUserSchema,
            readModelsClusterArn: t__namespace.string,
            postgresAdminSecretArn: t__namespace.string,
            readModelsClusterEndpoint: t__namespace.string,
            readModelsClusterPort: t__namespace.number,
            postgresAdminUsername: t__namespace.string,
            postgresAdminPassword: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
});

var Namespace$4 = 'Deployments / Tracing';
/* DisableTracing */
var DisableTracingSchema = defineSchema({
    Namespace: Namespace$4,
    Description: 'Disable performance tracing for a deployment.',
    Path: '/v0/deployments/:deploymentId/tracing/disable',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.disableTracing),
        payload: t__namespace.type({
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});
/* EnableTracing */
var EnableTracingSchema = defineSchema({
    Namespace: Namespace$4,
    Description: 'Enable performance tracing for a deployment.',
    Path: '/v0/deployments/:deploymentId/tracing/enable',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.enableTracing),
        payload: t__namespace.type({
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});
/* GetSummaries */
var GetSummariesSchema = defineSchema({
    Namespace: Namespace$4,
    Description: "Get the list of a deployment's performance tracing summaries for the specified time interval.",
    Path: '/v0/deployments/:deploymentId/tracing/summary',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.intersection([
        t__namespace.type({ startTime: t__namespace.string, endTime: t__namespace.string }),
        t__namespace.partial({ filterExpression: t__namespace.string }),
    ]),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.getSummaries),
        payload: t__namespace.intersection([
            t__namespace.type({
                deploymentId: t__namespace.string,
                userId: t__namespace.string,
                startTime: t__namespace.number,
                endTime: t__namespace.number,
            }),
            t__namespace.partial({
                filterExpression: t__namespace.string,
            }),
        ]),
    }),
    Result: t__namespace.array(t__namespace.intersection([
        t__namespace.partial({
            id: t__namespace.string,
            responseTime: t__namespace.number,
            http: t__namespace.partial({
                httpURL: t__namespace.string,
                httpStatus: t__namespace.number,
                httpMethod: t__namespace.string,
                userAgent: t__namespace.string,
                clientIp: t__namespace.string,
            }),
        }),
        t__namespace.record(t__namespace.string, t__namespace.any),
    ])),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, startTime = _a.startTime, endTime = _a.endTime, filterExpression = _a.filterExpression;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: { startTime: startTime, endTime: endTime, filterExpression: filterExpression },
        });
    },
});
/* GetTrace */
var GetTracingDetailsSchema = defineSchema({
    Namespace: Namespace$4,
    Description: 'Get details on the specified performance trace.',
    Path: '/v0/deployments/:deploymentId/tracing/details',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({
        traceIds: t__namespace.array(t__namespace.string),
    }),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.getTracingDetails),
        payload: t__namespace.type({
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
            traceIds: t__namespace.array(t__namespace.string),
        }),
    }),
    Result: t__namespace.array(t__namespace.record(t__namespace.string, t__namespace.any)),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, traceIds = _a.traceIds;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: { traceIds: traceIds },
        });
    },
});
/* GetTracing */
var GetTracingStatusSchema = defineSchema({
    Namespace: Namespace$4,
    Description: 'Check whether performance tracing is enabled for a deployment.',
    Path: '/v0/deployments/:deploymentId/tracing/status',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({ deploymentId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.getTracingStatus),
        payload: t__namespace.type({
            deploymentId: t__namespace.string,
            userId: t__namespace.string,
        }),
    }),
    Result: t__namespace.union([t__namespace.literal('enabled'), t__namespace.literal('disabled')]),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});

var Namespace$3 = 'Event stores';
/* CreateEventStore */
var CreateEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Create a new event store.',
    Path: '/v0/event-stores',
    Method: 'POST',
    Mode: 'ASYNC',
    Params: t__namespace.type({}),
    Body: t__namespace.type({
        version: t__namespace.string,
    }),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.createEventStore),
        payload: t__namespace.type({
            version: t__namespace.string,
            user: RDSUserSchema,
            eventStoreClusterArn: t__namespace.string,
            postgresAdminSecretArn: t__namespace.string,
            eventStoreClusterEndpoint: t__namespace.string,
            eventStoreClusterPort: t__namespace.number,
            postgresAdminUsername: t__namespace.string,
            postgresAdminPassword: t__namespace.string,
        }),
    }),
    Result: t__namespace.type({
        eventStoreId: t__namespace.string,
    }),
    ArgumentsTransformer: function (_a) {
        var version = _a.version;
        return ({
            params: {},
            body: { version: version },
            query: {},
        });
    },
});
/* DropEventStore */
var DropEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Remove an existing event store.',
    Path: '/v0/event-stores/:eventStoreId',
    Method: 'DELETE',
    Mode: 'ASYNC',
    Params: t__namespace.type({ eventStoreId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.dropEventStore),
        payload: t__namespace.type({
            version: t__namespace.string,
            user: RDSUserSchema,
            eventStoreId: t__namespace.string,
            eventStoreClusterArn: t__namespace.string,
            postgresAdminSecretArn: t__namespace.string,
            eventStoreClusterEndpoint: t__namespace.string,
            eventStoreClusterPort: t__namespace.number,
            postgresAdminUsername: t__namespace.string,
            postgresAdminPassword: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: {},
            query: {},
        });
    },
});
/* GetEventStore */
var GetEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Get information about the specified event store.',
    Path: '/v0/event-stores/:eventStoreId',
    Method: 'GET',
    Mode: 'ASYNC',
    Params: t__namespace.type({ eventStoreId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.getEventStore),
        payload: t__namespace.type({
            user: RDSUserSchema,
            eventStoreId: t__namespace.string,
            eventStoreClusterArn: t__namespace.string,
            postgresAdminSecretArn: t__namespace.string,
            eventStoreClusterEndpoint: t__namespace.string,
            eventStoreClusterPort: t__namespace.number,
            postgresAdminUsername: t__namespace.string,
            postgresAdminPassword: t__namespace.string,
        }),
    }),
    Result: t__namespace.type({
        eventStoreClusterArn: t__namespace.string,
        eventStoreSecretArn: t__namespace.string,
        eventStoreDatabaseName: t__namespace.string,
        version: t__namespace.string,
        eventStoreId: t__namespace.string,
        linkedDeployments: t__namespace.array(t__namespace.string),
        region: t__namespace.string,
        accessKeyId: t__namespace.string,
        secretAccessKey: t__namespace.string,
        sessionToken: t__namespace.string,
    }),
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: {},
            query: {},
        });
    },
});
/* ListEventStores */
var ListEventStoresSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Get a list of objects that describe available event stores.',
    Path: '/v0/event-stores',
    Method: 'GET',
    Mode: 'ASYNC',
    Params: t__namespace.type({}),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.listEventStores),
        payload: t__namespace.type({
            user: RDSUserSchema,
            eventStoreClusterArn: t__namespace.string,
            postgresAdminSecretArn: t__namespace.string,
            eventStoreClusterEndpoint: t__namespace.string,
            eventStoreClusterPort: t__namespace.number,
            postgresAdminUsername: t__namespace.string,
            postgresAdminPassword: t__namespace.string,
        }),
    }),
    Result: t__namespace.array(t__namespace.type({
        version: t__namespace.string,
        eventStoreId: t__namespace.string,
        linkedDeployments: t__namespace.array(t__namespace.string),
        eventStoreDatabaseName: t__namespace.string,
        events: t__namespace.union([t__namespace.number, t__namespace.null]),
        secrets: t__namespace.union([t__namespace.number, t__namespace.null]),
        modifiedAt: t__namespace.union([t__namespace.number, t__namespace.null]),
        createdAt: t__namespace.union([t__namespace.number, t__namespace.null]),
        isFrozen: t__namespace.union([t__namespace.boolean, t__namespace.null]),
    })),
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});
/* CloneEventStore */
var CloneEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Create a new event store based on the specified event store.',
    Path: '/v0/event-stores/:eventStoreId/clone',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t__namespace.type({ eventStoreId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.cloneEventStore),
        payload: t__namespace.type({
            version: t__namespace.string,
            user: RDSUserSchema,
            eventStoreClusterArn: t__namespace.string,
            postgresAdminSecretArn: t__namespace.string,
            eventStoreId: t__namespace.string,
            eventStoreClusterEndpoint: t__namespace.string,
            eventStoreClusterPort: t__namespace.number,
            postgresAdminUsername: t__namespace.string,
            postgresAdminPassword: t__namespace.string,
        }),
    }),
    Result: t__namespace.type({
        eventStoreId: t__namespace.string,
        eventStoreDatabaseName: t__namespace.string,
    }),
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: {},
            query: {},
        });
    },
});
/* ClearEventStore */
var ClearEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Remove all events from an event store.',
    Path: '/v0/event-stores/:eventStoreId/clear',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t__namespace.type({ eventStoreId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.clearEventStore),
        payload: t__namespace.type({
            version: t__namespace.string,
            user: RDSUserSchema,
            eventStoreId: t__namespace.string,
            eventStoreClusterArn: t__namespace.string,
            postgresAdminSecretArn: t__namespace.string,
            eventStoreClusterEndpoint: t__namespace.string,
            eventStoreClusterPort: t__namespace.number,
            postgresAdminUsername: t__namespace.string,
            postgresAdminPassword: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: {},
            query: {},
        });
    },
});
/* FreezeEventStore */
var FreezeEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Disable event store updates.',
    Path: '/v0/event-stores/:eventStoreId/freeze',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t__namespace.type({ eventStoreId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.freezeEventStore),
        payload: t__namespace.type({
            version: t__namespace.string,
            user: RDSUserSchema,
            eventStoreId: t__namespace.string,
            eventStoreClusterArn: t__namespace.string,
            postgresAdminSecretArn: t__namespace.string,
            eventStoreClusterEndpoint: t__namespace.string,
            eventStoreClusterPort: t__namespace.number,
            postgresAdminUsername: t__namespace.string,
            postgresAdminPassword: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: {},
            query: {},
        });
    },
});
/* UnfreezeEventStore */
var UnfreezeEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Resume event store updates.',
    Path: '/v0/event-stores/:eventStoreId/unfreeze',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t__namespace.type({ eventStoreId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.unfreezeEventStore),
        payload: t__namespace.type({
            version: t__namespace.string,
            user: RDSUserSchema,
            eventStoreId: t__namespace.string,
            eventStoreClusterArn: t__namespace.string,
            postgresAdminSecretArn: t__namespace.string,
            eventStoreClusterEndpoint: t__namespace.string,
            eventStoreClusterPort: t__namespace.number,
            postgresAdminUsername: t__namespace.string,
            postgresAdminPassword: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: {},
            query: {},
        });
    },
});
/* LinkDeployment */
var LinkDeploymentSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Connect an existing application deployment to the specified event store.',
    Path: '/v0/event-stores/:eventStoreId/link',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t__namespace.type({ eventStoreId: t__namespace.string }),
    Body: t__namespace.type({ deploymentId: t__namespace.string }),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.linkDeployment),
        payload: t__namespace.type({
            version: t__namespace.string,
            user: RDSUserSchema,
            eventStoreClusterArn: t__namespace.string,
            postgresAdminSecretArn: t__namespace.string,
            eventStoreId: t__namespace.string,
            deploymentId: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId, deploymentId = _a.deploymentId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: { deploymentId: deploymentId },
            query: {},
        });
    },
});
/* UnlinkDeployment */
var UnlinkDeploymentSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Disconnect an application deployment from the specified event store.',
    Path: '/v0/event-stores/:eventStoreId/unlink',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t__namespace.type({ eventStoreId: t__namespace.string }),
    Body: t__namespace.type({ deploymentId: t__namespace.string }),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.unlinkDeployment),
        payload: t__namespace.type({
            version: t__namespace.string,
            user: RDSUserSchema,
            eventStoreClusterArn: t__namespace.string,
            postgresAdminSecretArn: t__namespace.string,
            eventStoreId: t__namespace.string,
            deploymentId: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId, deploymentId = _a.deploymentId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: { deploymentId: deploymentId },
            query: {},
        });
    },
});
/* ImportEventStore */
var ImportEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Import events into the specified event store.',
    Path: '/v0/event-stores/:eventStoreId/import',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t__namespace.type({ eventStoreId: t__namespace.string }),
    Body: t__namespace.type({ partIndex: t__namespace.number }),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.importEventStore),
        payload: t__namespace.type({
            version: t__namespace.string,
            user: RDSUserSchema,
            eventStoreId: t__namespace.string,
            eventStoreDatabaseName: t__namespace.string,
            eventStoreClusterEndpoint: t__namespace.string,
            eventStoreClusterPort: t__namespace.number,
            bucketName: t__namespace.string,
            partIndex: t__namespace.number,
            accessKeyId: t__namespace.string,
            secretAccessKey: t__namespace.string,
            sessionToken: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId, partIndex = _a.partIndex;
        return ({
            params: { eventStoreId: eventStoreId },
            body: { partIndex: partIndex },
            query: {},
        });
    },
});
/* ExportEventStore */
var ExportEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Export events from the specified event store.',
    Path: '/v0/event-stores/:eventStoreId/export',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t__namespace.type({ eventStoreId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.partial({ cursor: t__namespace.string }),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.exportEventStore),
        payload: t__namespace.intersection([
            t__namespace.type({
                version: t__namespace.string,
                user: RDSUserSchema,
                eventStoreId: t__namespace.string,
                eventStoreDatabaseName: t__namespace.string,
                eventStoreClusterEndpoint: t__namespace.string,
                eventStoreClusterPort: t__namespace.number,
                bucketName: t__namespace.string,
                importExportStepFunctionArn: t__namespace.string,
            }),
            t__namespace.partial({
                cursor: t__namespace.string,
            }),
        ]),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId, cursor = _a.cursor;
        return ({
            params: { eventStoreId: eventStoreId },
            body: {},
            query: { cursor: cursor },
        });
    },
});
/* GetImportUrls */
var GetImportUrlsSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Get URLs used to upload files that contain events and secrets to import.',
    Path: '/v0/event-stores/:eventStoreId/import',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({ eventStoreId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({ eventsPartCount: t__namespace.string, secretsPartCount: t__namespace.string }),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.getImportUrls),
        payload: t__namespace.type({
            version: t__namespace.string,
            userId: t__namespace.string,
            eventStoreId: t__namespace.string,
            bucketName: t__namespace.string,
            eventsPartCount: t__namespace.number,
            secretsPartCount: t__namespace.number,
        }),
    }),
    Result: t__namespace.type({
        eventsImportUrls: t__namespace.array(t__namespace.string),
        secretsImportUrls: t__namespace.array(t__namespace.string),
    }),
    ArgumentsTransformer: (function (args) { return ({
        params: { eventStoreId: args.eventStoreId },
        body: {},
        query: {
            eventsPartCount: "".concat(args.eventsPartCount),
            secretsPartCount: "".concat(args.secretsPartCount),
        },
    }); }),
});
/* GetExportUrls */
var GetExportUrlsSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Get URLs used to download files that contain events and secrets to import as well as a file that contains information about the status of the export process.',
    Path: '/v0/event-stores/:eventStoreId/export',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({ eventStoreId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.getExportUrls),
        payload: t__namespace.type({
            version: t__namespace.string,
            userId: t__namespace.string,
            eventStoreId: t__namespace.string,
            bucketName: t__namespace.string,
        }),
    }),
    Result: t__namespace.type({
        eventsExportUrl: t__namespace.string,
        secretsExportUrl: t__namespace.string,
        statusFileUrl: t__namespace.string,
    }),
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: {},
            query: {},
        });
    },
});

var Namespace$2 = 'Certificates';
/* EnsureCertificate */
var EnsureCertificateSchema = defineSchema({
    Namespace: Namespace$2,
    Description: "Check an SSL certificate's validity.",
    Path: '/v0/certificates',
    Method: 'PUT',
    Mode: 'ASYNC',
    Params: t__namespace.type({}),
    Body: t__namespace.intersection([
        t__namespace.type({
            certificate: t__namespace.string,
            key: t__namespace.string,
        }),
        t__namespace.partial({
            certificateId: t__namespace.string,
            chain: t__namespace.string,
        }),
    ]),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.ensureCertificate),
        payload: t__namespace.intersection([
            t__namespace.type({
                userId: t__namespace.string,
                certificate: t__namespace.string,
                key: t__namespace.string,
            }),
            t__namespace.partial({
                certificateId: t__namespace.string,
                chain: t__namespace.string,
            }),
        ]),
    }),
    Result: t__namespace.string,
    ArgumentsTransformer: function (_a) {
        var certificateId = _a.certificateId, certificate = _a.certificate, key = _a.key, chain = _a.chain;
        return ({
            params: {},
            body: { certificateId: certificateId, certificate: certificate, key: key, chain: chain },
            query: {},
        });
    },
});
/* DropCertificate */
var DropCertificateSchema = defineSchema({
    Namespace: Namespace$2,
    Description: 'Remove the specified certificate.',
    Path: '/v0/certificates/:certificateId',
    Method: 'DELETE',
    Mode: 'ASYNC',
    Params: t__namespace.type({ certificateId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.dropCertificate),
        payload: t__namespace.type({
            userId: t__namespace.string,
            certificateId: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var certificateId = _a.certificateId;
        return ({
            params: { certificateId: certificateId },
            body: {},
            query: {},
        });
    },
});
/* ListCertificates */
var ListCertificatesSchema = defineSchema({
    Namespace: Namespace$2,
    Description: 'Get a list of the available SSL certificates.',
    Path: '/v0/certificates',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({}),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.listCertificates),
        payload: t__namespace.type({
            userId: t__namespace.string,
        }),
    }),
    Result: t__namespace.array(CertificateSchema),
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});

var Namespace$1 = 'Domains';
/* CreateDomain */
var CreateDomainSchema = defineSchema({
    Namespace: Namespace$1,
    Description: 'Create a new domain with the specified certificate based on a list of aliases.',
    Path: '/v0/domains',
    Method: 'POST',
    Mode: 'ASYNC',
    Params: t__namespace.type({}),
    Body: t__namespace.intersection([
        t__namespace.type({
            certificateId: t__namespace.string,
            aliases: t__namespace.array(t__namespace.string),
        }),
        t__namespace.partial({
            domainId: t__namespace.string,
        }),
    ]),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.union([
            t__namespace.literal(exports.InstallerEventNames.createStaticDomain),
            t__namespace.literal(exports.InstallerEventNames.createProxyDomain),
            t__namespace.literal(exports.InstallerEventNames.createUploaderDomain),
        ]),
        payload: t__namespace.intersection([
            t__namespace.type({
                userId: t__namespace.string,
                certificateId: t__namespace.string,
            }),
            t__namespace.partial({
                aliases: t__namespace.array(t__namespace.string),
                domainId: t__namespace.string,
                customName: t__namespace.string,
                users: t__namespace.union([t__namespace.literal('*'), t__namespace.array(t__namespace.string)]),
                verification: t__namespace.boolean,
            }),
        ]),
    }),
    Result: DomainSchema,
    ArgumentsTransformer: function (_a) {
        var certificateId = _a.certificateId, aliases = _a.aliases, domainId = _a.domainId;
        return ({
            params: {},
            body: { certificateId: certificateId, aliases: aliases, domainId: domainId },
            query: {},
        });
    },
});
/* DropDomain */
var DropDomainSchema = defineSchema({
    Namespace: Namespace$1,
    Description: 'Remove the specified domain.',
    Path: '/v0/domains/:domainId',
    Method: 'DELETE',
    Mode: 'ASYNC',
    Params: t__namespace.type({ domainId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.dropDomain),
        payload: t__namespace.type({
            userId: t__namespace.string,
            domainId: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var domainId = _a.domainId;
        return ({
            params: { domainId: domainId },
            body: {},
            query: {},
        });
    },
});
/* ReleaseDomain */
var ReleaseDomainSchema = defineSchema({
    Namespace: Namespace$1,
    Description: 'Release a domain from the associated application deployments.',
    Path: '/v0/domains',
    Method: 'DELETE',
    Mode: 'ASYNC',
    Params: t__namespace.type({}),
    Body: t__namespace.type({ domain: t__namespace.string }),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.releaseDomain),
        payload: t__namespace.type({
            userId: t__namespace.string,
            domain: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var domain = _a.domain;
        return ({
            params: {},
            body: { domain: domain },
            query: {},
        });
    },
});
/* ListDomains */
var ListDomainsSchema = defineSchema({
    Namespace: Namespace$1,
    Description: 'Get a list of the available domains.',
    Path: '/v0/domains',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({}),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.listDomains),
        payload: t__namespace.intersection([
            t__namespace.type({
                userId: t__namespace.string,
            }),
            t__namespace.partial({
                domain: t__namespace.string,
            }),
        ]),
    }),
    Result: t__namespace.array(DomainSchema),
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});
/* VerifyDomain */
var VerifyDomainSchema = defineSchema({
    Namespace: Namespace$1,
    Description: 'Verify a domain after a verification record was added to the domain zone.',
    Path: '/v0/domains/:domainId/verify',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t__namespace.type({
        domainId: t__namespace.string,
    }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.verifyDomain),
        payload: t__namespace.type({
            userId: t__namespace.string,
            domainId: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (_a) {
        var domainId = _a.domainId;
        return ({
            params: { domainId: domainId },
            body: {},
            query: {},
        });
    },
});
/* GetVerificationCode */
var GetVerificationCodeSchema = defineSchema({
    Namespace: Namespace$1,
    Description: 'Get a code to add to a verification record within your domain zone.',
    Path: '/v0/domains/:domainId/verification-code',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({ domainId: t__namespace.string }),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.getVerificationCode),
        payload: t__namespace.type({
            userId: t__namespace.string,
            domainId: t__namespace.string,
        }),
    }),
    Result: t__namespace.type({
        verificationCode: t__namespace.string,
    }),
    ArgumentsTransformer: function (_a) {
        var domainId = _a.domainId;
        return ({
            params: { domainId: domainId },
            body: {},
            query: {},
        });
    },
});

var getApiRouteUrl = function (baseUrl, pathname) {
    var url = baseUrl;
    if (/\/$/.test(url)) {
        url = url.substr(0, url.length - 1);
    }
    if (/^\//.test(pathname)) {
        url += pathname;
    }
    else {
        url += "/".concat(pathname);
    }
    return url;
};

var getResponseMethod = function (contentType) {
    var responseMethod = contentType != null &&
        contentType
            .split(';')
            .map(function (item) { return item.trim(); })
            .find(function (item) { return item === 'application/json'; })
        ? 'json'
        : 'text';
    return responseMethod;
};

var request = function (params) { return __awaiter(void 0, void 0, void 0, function () {
    var baseHeaders, baseUrl, fetch, _a, logger, path, query, body, method, token, _b, customHeaders, _c, retryTimeout, _d, mode, headers, startTime, executeRequest, describeRequest, apiRequest;
    return __generator(this, function (_e) {
        switch (_e.label) {
            case 0:
                baseHeaders = params.baseHeaders, baseUrl = params.baseUrl, fetch = params.fetch, _a = params.logger, logger = _a === void 0 ? {
                    debug: function () { },
                    trace: function () { },
                    log: function () { },
                } : _a, path = params.path, query = params.query, body = params.body, method = params.method, token = params.token, _b = params.headers, customHeaders = _b === void 0 ? {} : _b, _c = params.retryTimeout, retryTimeout = _c === void 0 ? 15 * 60 * 1000 : _c, _d = params.mode, mode = _d === void 0 ? 'SYNC' : _d;
                headers = __assign(__assign({}, baseHeaders), customHeaders);
                if (token != null) {
                    headers.Authorization = "Bearer ".concat(token);
                }
                headers[HEADER_EXECUTION_MODE] = mode === 'ASYNC' ? 'async' : 'sync';
                if (fetch == null) {
                    throw new Error('Fetch is not defined');
                }
                if (baseUrl == null) {
                    throw new Error('BaseUrl is not defined');
                }
                startTime = Date.now();
                executeRequest = function (req, options) { return __awaiter(void 0, void 0, void 0, function () {
                    var result, error_1, errorText, timeLeft;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                _a.trys.push([0, 2, , 7]);
                                return [4 /*yield*/, req(options)];
                            case 1:
                                result = _a.sent();
                                if (mode === 'SYNC' || result !== 'running') {
                                    return [2 /*return*/, result];
                                }
                                return [3 /*break*/, 7];
                            case 2:
                                error_1 = _a.sent();
                                errorText = "".concat(error_1);
                                timeLeft = retryTimeout - (Date.now() - startTime);
                                if (!(timeLeft <= 0)) return [3 /*break*/, 3];
                                logger.debug("Task timed out");
                                throw error_1;
                            case 3:
                                if (!isRetryable({ baseUrl: baseUrl, method: method, errorText: errorText })) return [3 /*break*/, 5];
                                logger.debug("Retrying... ".concat(Math.round(timeLeft / 1000), " seconds left"));
                                return [4 /*yield*/, new Promise(function (resolve) { return setTimeout(resolve, 1000); })];
                            case 4:
                                _a.sent();
                                return [3 /*break*/, 6];
                            case 5: throw error_1;
                            case 6: return [3 /*break*/, 7];
                            case 7: return [3 /*break*/, 0];
                            case 8: return [2 /*return*/];
                        }
                    });
                }); };
                describeRequest = function (data) { return __awaiter(void 0, void 0, void 0, function () {
                    var executionId, describePath, _a, _b, describeHeaders, describeExecutionResponse, describeExecutionResponseMethod, describeExecutionData, executionStatus, Output, error, _c;
                    var _d, _e;
                    return __generator(this, function (_f) {
                        switch (_f.label) {
                            case 0:
                                executionId = data.executionId;
                                describePath = "/v0/describe-execution/".concat(executionId);
                                _a = headers, _b = HEADER_EXECUTION_MODE, describeHeaders = __rest(_a, [typeof _b === "symbol" ? _b : _b + ""]);
                                return [4 /*yield*/, fetch(getApiRouteUrl(baseUrl, describePath), __assign({ method: 'GET', credentials: 'same-origin' }, (describeHeaders == null || Object.keys(describeHeaders).length === 0
                                        ? {}
                                        : { headers: describeHeaders })))];
                            case 1:
                                describeExecutionResponse = _f.sent();
                                describeExecutionResponseMethod = getResponseMethod(describeExecutionResponse.headers.get('Content-Type'));
                                return [4 /*yield*/, describeExecutionResponse[describeExecutionResponseMethod]()];
                            case 2:
                                describeExecutionData = _f.sent();
                                if (!(describeExecutionResponse.status >= 200 && describeExecutionResponse.status < 300)) {
                                    throw new Error(describeExecutionData);
                                }
                                if ("".concat(describeExecutionData).includes("<?xml version=\"1.0\" encoding=\"UTF-8\"?>")) {
                                    throw new Error(data);
                                }
                                executionStatus = (_d = describeExecutionData === null || describeExecutionData === void 0 ? void 0 : describeExecutionData.result) === null || _d === void 0 ? void 0 : _d.status;
                                Output = (_e = describeExecutionData === null || describeExecutionData === void 0 ? void 0 : describeExecutionData.result) === null || _e === void 0 ? void 0 : _e.output;
                                logger.trace(">> [".concat(executionStatus, "] ").concat(method, ": https://").concat(headers.Host).concat(describePath));
                                if ((Output === null || Output === void 0 ? void 0 : Output.errorType) != null && (Output === null || Output === void 0 ? void 0 : Output.errorMessage) != null && (Output === null || Output === void 0 ? void 0 : Output.trace) != null) {
                                    error = new Error();
                                    error.name = Output.errorType;
                                    error.message = Output.errorMessage;
                                    error.stack = Output.trace.join('\n');
                                    throw error;
                                }
                                _c = executionStatus;
                                switch (_c) {
                                    case 'SUCCEEDED': return [3 /*break*/, 3];
                                    case 'RUNNING': return [3 /*break*/, 4];
                                }
                                return [3 /*break*/, 6];
                            case 3:
                                {
                                    return [2 /*return*/, Output];
                                }
                            case 4:
                                logger.debug('Execution status "RUNNING". Retrying...');
                                return [4 /*yield*/, new Promise(function (resolve) { return setTimeout(resolve, 3000); })];
                            case 5:
                                _f.sent();
                                return [2 /*return*/, 'running'];
                            case 6:
                                {
                                    return [2 /*return*/, Promise.reject(new Error("Command has been completed with status \"".concat(executionStatus, "\"")))];
                                }
                            case 7: return [2 /*return*/];
                        }
                    });
                }); };
                apiRequest = function () { return __awaiter(void 0, void 0, void 0, function () {
                    var response, responseMethod, data, result, describeResult;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                logger.trace("< [".concat(mode, "] ").concat(method, ": https://").concat(headers.Host).concat(path));
                                return [4 /*yield*/, fetch("".concat(getApiRouteUrl(baseUrl, path)).concat(query == null || Object.keys(query).length === 0
                                        ? ''
                                        : "?".concat(queryString.stringify(query, { arrayFormat: 'bracket' }))), __assign(__assign({ method: method, credentials: 'same-origin' }, (body == null || Object.keys(body).length === 0 ? {} : { body: JSON.stringify(body) })), (headers == null || Object.keys(headers).length === 0 ? {} : { headers: headers })))];
                            case 1:
                                response = _a.sent();
                                responseMethod = getResponseMethod(response.headers.get('Content-Type'));
                                return [4 /*yield*/, response[responseMethod]()];
                            case 2:
                                data = _a.sent();
                                if (!(response.status >= 200 && response.status < 300)) {
                                    logger.trace("> [".concat(response.status, "] ").concat(method, ": https://").concat(headers.Host).concat(path));
                                    throw new Error(data);
                                }
                                if (!(responseMethod === 'json')) return [3 /*break*/, 6];
                                result = data.result;
                                if (!(mode === 'SYNC')) return [3 /*break*/, 3];
                                logger.trace("> [".concat(response.status, "] ").concat(method, ": https://").concat(headers.Host).concat(path));
                                return [2 /*return*/, result];
                            case 3: return [4 /*yield*/, executeRequest(describeRequest, data)];
                            case 4:
                                describeResult = _a.sent();
                                logger.trace("> [".concat(response.status, "] ").concat(method, ": https://").concat(headers.Host).concat(path));
                                return [2 /*return*/, describeResult];
                            case 5: return [3 /*break*/, 7];
                            case 6:
                                logger.trace("> [".concat(response.status, "] ").concat(method, ": https://").concat(headers.Host).concat(path));
                                if ("".concat(data).includes("<?xml version=\"1.0\" encoding=\"UTF-8\"?>")) {
                                    throw new Error(data);
                                }
                                return [2 /*return*/, data];
                            case 7: return [2 /*return*/];
                        }
                    });
                }); };
                return [4 /*yield*/, executeRequest(apiRequest)];
            case 1: return [2 /*return*/, _e.sent()];
        }
    });
}); };

var formatPath = function (urlPattern, params) {
    var _a;
    var result = urlPattern;
    var urlKeys = (_a = urlPattern.match(/:[a-z0-9-]+/gi)) !== null && _a !== void 0 ? _a : [];
    if (urlKeys.length !== Object.keys(params).length) {
        throw new Error("The params \"".concat(JSON.stringify(params), "\" does not match a pattern \"").concat(urlPattern, "\""));
    }
    for (var _i = 0, urlKeys_1 = urlKeys; _i < urlKeys_1.length; _i++) {
        var urlKey = urlKeys_1[_i];
        var paramKey = urlKey.replace(/^:/, '');
        var paramValue = params[paramKey];
        if (paramValue == null) {
            throw new Error("The parameter \"".concat(paramKey, " is required\""));
        }
        result = result.replace(urlKey, paramValue);
    }
    return result;
};

var createCloudSdk = function () {
    var options = {};
    var createCloudSDKMethod = function (schema) {
        return function (args) { return __awaiter(void 0, void 0, void 0, function () {
            var transformedArgs, params, query, body, result;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        transformedArgs = schema.ArgumentsTransformer(args !== null && args !== void 0 ? args : {});
                        params = validate(schema.Params, transformedArgs.params);
                        query = validate(schema.Query, transformedArgs.query);
                        body = validate(schema.Body, transformedArgs.body);
                        return [4 /*yield*/, request(__assign({ mode: schema.Mode, method: schema.Method, path: formatPath(schema.Path, params), body: body, query: query }, options))];
                    case 1:
                        result = _a.sent();
                        return [2 /*return*/, result];
                }
            });
        }); };
    };
    return {
        /* Setup */
        setup: function (params) {
            options = params;
        },
        /* System */
        heartbeat: function (args) {
            return __awaiter(this, void 0, void 0, function () {
                var params, query, body;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            params = validate(HeartbeatSchema.Params, {});
                            query = validate(HeartbeatSchema.Query, {});
                            body = validate(HeartbeatSchema.Body, {});
                            return [4 /*yield*/, request(__assign({ mode: HeartbeatSchema.Mode, method: HeartbeatSchema.Method, path: formatPath(HeartbeatSchema.Path, params), body: body, query: query }, options))];
                        case 1:
                            _a.sent();
                            return [2 /*return*/];
                    }
                });
            });
        },
        getDeploymentByApplicationName: function (args) {
            return __awaiter(this, void 0, void 0, function () {
                var params, query, body, deployments, deployment;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            params = validate(ListDeploymentsSchema.Params, {});
                            query = validate(ListDeploymentsSchema.Query, {
                                applicationName: args.applicationName,
                            });
                            body = validate(ListDeploymentsSchema.Body, {});
                            return [4 /*yield*/, request(__assign({ mode: ListDeploymentsSchema.Mode, method: ListDeploymentsSchema.Method, path: formatPath(ListDeploymentsSchema.Path, params), body: body, query: query }, options))];
                        case 1:
                            deployments = _a.sent();
                            if (deployments.length > 1) {
                                throw new FatalError("Duplicate applicationName = \"".concat(args.applicationName, "\""));
                            }
                            deployment = deployments[0];
                            return [2 /*return*/, deployment !== null && deployment !== void 0 ? deployment : null];
                    }
                });
            });
        },
        getClientAppConfig: createCloudSDKMethod(GetClientAppConfigSchema),
        listVersions: createCloudSDKMethod(ListVersionsSchema),
        /* Deployments */
        createDeployment: createCloudSDKMethod(CreateDeploymentSchema),
        dropDeployment: createCloudSDKMethod(DropDeploymentSchema),
        describeDeployment: createCloudSDKMethod(DescribeDeploymentSchema),
        // listDeployments: createCloudSDKMethod(ListDeploymentsSchema),
        listDeployments: function (args) {
            return __awaiter(this, void 0, void 0, function () {
                var params, query, body, result;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            params = validate(ListDeploymentsSchema.Params, {});
                            query = validate(ListDeploymentsSchema.Query, {});
                            body = validate(ListDeploymentsSchema.Body, {});
                            return [4 /*yield*/, request(__assign({ mode: ListDeploymentsSchema.Mode, method: ListDeploymentsSchema.Method, path: formatPath(ListDeploymentsSchema.Path, params), body: body, query: query }, options))];
                        case 1:
                            result = _a.sent();
                            return [2 /*return*/, result];
                    }
                });
            });
        },
        bootstrapDeployment: createCloudSDKMethod(BootstrapDeploymentSchema),
        shutdownDeployment: createCloudSDKMethod(ShutdownDeploymentSchema),
        buildDeployment: createCloudSDKMethod(BuildDeploymentSchema),
        getDeploymentUploadSignedUrl: createCloudSDKMethod(GetDeploymentUploadSignedUrlSchema),
        setDeploymentDomain: createCloudSDKMethod(SetDeploymentDomainSchema),
        unsetDeploymentDomain: createCloudSDKMethod(UnsetDeploymentDomainSchema),
        /* Link/unlink EventStore <-> Deployment */
        linkDeployment: createCloudSDKMethod(LinkDeploymentSchema),
        unlinkDeployment: createCloudSDKMethod(UnlinkDeploymentSchema),
        /* EnvironmentVariables */
        listEnvironmentVariables: createCloudSDKMethod(ListEnvironmentVariablesSchema),
        removeEnvironmentVariables: createCloudSDKMethod(RemoveEnvironmentVariablesSchema),
        setEnvironmentVariables: createCloudSDKMethod(SetEnvironmentVariablesSchema),
        /* Logs */
        disableLogs: createCloudSDKMethod(DisableLogsSchema),
        enableLogs: createCloudSDKMethod(EnableLogsSchema),
        // getLogs: createCloudSDKMethod(GetLogsSchema),
        getLogs: function (args) {
            return __awaiter(this, void 0, void 0, function () {
                var params, query, body, result;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            params = validate(GetLogsSchema.Params, {
                                deploymentId: args.deploymentId,
                            });
                            query = validate(GetLogsSchema.Query, {
                                streamLimit: args.streamLimit == null ? args.streamLimit : undefined,
                                startTime: args.startTime == null ? args.startTime : undefined,
                                endTime: args.endTime == null ? args.endTime : undefined,
                                filterPattern: args.filterPattern == null ? args.filterPattern : undefined,
                            });
                            body = validate(GetLogsSchema.Body, {});
                            return [4 /*yield*/, request(__assign({ mode: GetLogsSchema.Mode, method: GetLogsSchema.Method, path: formatPath(GetLogsSchema.Path, params), body: body, query: query }, options))];
                        case 1:
                            result = _a.sent();
                            return [2 /*return*/, result];
                    }
                });
            });
        },
        removeLogs: createCloudSDKMethod(RemoveLogsSchema),
        /* Sagas */
        listSagas: createCloudSDKMethod(ListSagasSchema),
        pauseSaga: createCloudSDKMethod(PauseSagaSchema),
        resetSaga: createCloudSDKMethod(ResetSagaSchema),
        resumeSaga: createCloudSDKMethod(ResumeSagaSchema),
        listSagaProperties: createCloudSDKMethod(ListSagaPropertiesSchema),
        setSagaProperty: createCloudSDKMethod(SetSagaPropertySchema),
        getSagaProperty: createCloudSDKMethod(GetSagaPropertySchema),
        deleteSagaProperty: createCloudSDKMethod(DeleteSagaPropertySchema),
        /* ReadModels */
        listReadModels: createCloudSDKMethod(ListReadModelsSchema),
        pauseReadModel: createCloudSDKMethod(PauseReadModelSchema),
        resetReadModel: createCloudSDKMethod(ResetReadModelSchema),
        resumeReadModel: createCloudSDKMethod(ResumeReadModelSchema),
        /* Tracing */
        getTracingDetails: createCloudSDKMethod(GetTracingDetailsSchema),
        getTracingStatus: createCloudSDKMethod(GetTracingStatusSchema),
        getSummaries: createCloudSDKMethod(GetSummariesSchema),
        enableTracing: createCloudSDKMethod(EnableTracingSchema),
        disableTracing: createCloudSDKMethod(DisableTracingSchema),
        /* EventStores */
        listEventStores: createCloudSDKMethod(ListEventStoresSchema),
        cloneEventStore: createCloudSDKMethod(CloneEventStoreSchema),
        createEventStore: createCloudSDKMethod(CreateEventStoreSchema),
        dropEventStore: createCloudSDKMethod(DropEventStoreSchema),
        getEventStore: createCloudSDKMethod(GetEventStoreSchema),
        clearEventStore: createCloudSDKMethod(ClearEventStoreSchema),
        freezeEventStore: createCloudSDKMethod(FreezeEventStoreSchema),
        unfreezeEventStore: createCloudSDKMethod(UnfreezeEventStoreSchema),
        exportEvents: createCloudSDKMethod(ExportEventStoreSchema),
        importEvents: createCloudSDKMethod(ImportEventStoreSchema),
        getExportUrls: createCloudSDKMethod(GetExportUrlsSchema),
        // getImportUrls: createCloudSDKMethod(GetImportUrlsSchema),
        getImportUrls: function (args) {
            return __awaiter(this, void 0, void 0, function () {
                var params, query, body, result;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            params = validate(GetImportUrlsSchema.Params, {
                                eventStoreId: args.eventStoreId,
                            });
                            query = validate(GetImportUrlsSchema.Query, {
                                eventsPartCount: "".concat(args.eventsPartCount),
                                secretsPartCount: "".concat(args.secretsPartCount),
                            });
                            body = validate(GetImportUrlsSchema.Body, {});
                            return [4 /*yield*/, request(__assign({ mode: GetImportUrlsSchema.Mode, method: GetImportUrlsSchema.Method, path: formatPath(GetImportUrlsSchema.Path, params), body: body, query: query }, options))];
                        case 1:
                            result = _a.sent();
                            return [2 /*return*/, result];
                    }
                });
            });
        },
        /* Certificates */
        listCertificates: createCloudSDKMethod(ListCertificatesSchema),
        dropCertificate: createCloudSDKMethod(DropCertificateSchema),
        ensureCertificate: createCloudSDKMethod(EnsureCertificateSchema),
        /* Domains */
        createDomain: createCloudSDKMethod(CreateDomainSchema),
        dropDomain: createCloudSDKMethod(DropDomainSchema),
        getVerificationCode: createCloudSDKMethod(GetVerificationCodeSchema),
        listDomains: createCloudSDKMethod(ListDomainsSchema),
        verifyDomain: createCloudSDKMethod(VerifyDomainSchema),
        releaseDomain: createCloudSDKMethod(ReleaseDomainSchema),
    };
};

/* BuildCode */
var BuildCodeSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.BuilderEventNames.buildCode),
        payload: t__namespace.intersection([
            t__namespace.type({
                region: t__namespace.string,
                bucketName: t__namespace.string,
                userId: t__namespace.string,
                inputFileKey: t__namespace.string,
                outputFileKey: t__namespace.string,
            }),
            t__namespace.partial({
                npmRegistry: t__namespace.string,
            }),
        ]),
    }),
    Result: t__namespace.intersection([
        t__namespace.type({
            installLog: t__namespace.string,
            version: t__namespace.string,
        }),
        t__namespace.partial({
            routesManifest: t__namespace.string,
        }),
    ]),
});
/* DeployStatic */
var DeployStaticSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.BuilderEventNames.deployStatic),
        payload: t__namespace.type({
            region: t__namespace.string,
            inputBucketName: t__namespace.string,
            outputBucketName: t__namespace.string,
            userId: t__namespace.string,
            fileKey: t__namespace.string,
            deploymentId: t__namespace.string,
        }),
    }),
    Result: t__namespace.type({
        files: t__namespace.array(t__namespace.string),
    }),
});

/* GetCertificateById */
var GetCertificateByIdSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.getCertificateById),
        payload: t__namespace.type({
            userId: t__namespace.string,
            certificateId: t__namespace.string,
        }),
    }),
    Result: CertificateSchema,
});
/* GetCertificateByDomainName */
var GetCertificateByDomainNameSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.getCertificateByDomainName),
        payload: t__namespace.type({
            userId: t__namespace.string,
            domainName: t__namespace.string,
        }),
    }),
    Result: CertificateSchema,
});

/* AttachClientAppUrls */
var AttachClientAppUrlsSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.attachClientAppUrls),
        payload: t__namespace.type({
            callbackUrl: t__namespace.string,
            logoutUrl: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
});
/* CreateUser */
var CreateUserSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.createUser),
        payload: t__namespace.intersection([
            t__namespace.type({
                email: t__namespace.string,
                temporaryPassword: t__namespace.string,
            }),
            t__namespace.partial({
                forceAliasCreation: t__namespace.boolean,
                messageAction: t__namespace.union([t__namespace.literal('RESEND'), t__namespace.literal('SUPPRESS')]),
                clientMetadata: t__namespace.record(t__namespace.string, t__namespace.string),
                userAttributes: t__namespace.array(t__namespace.type({ Name: t__namespace.string, Value: t__namespace.string })),
                validationData: t__namespace.array(t__namespace.type({ Name: t__namespace.string, Value: t__namespace.string })),
                isAdmin: t__namespace.boolean,
            }),
        ]),
    }),
    Result: CognitoUserSchema,
});
/* DetachClientAppUrls */
var DetachClientAppUrlsSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.detachClientAppUrls),
        payload: t__namespace.type({
            callbackUrl: t__namespace.string,
            logoutUrl: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
});
/* DropUser */
var DropUserSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.dropUser),
        payload: t__namespace.type({
            userId: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
});
/* GetUser */
var GetUserSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.getUser),
        payload: t__namespace.type({
            userId: t__namespace.string,
        }),
    }),
    Result: CognitoUserSchema,
});
/* GetUserIdByEmail */
var GetUserIdByEmailSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.getUserIdByEmail),
        payload: t__namespace.type({
            email: t__namespace.string,
        }),
    }),
    Result: t__namespace.string,
});
/* ListUsers */
var ListUsersSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.listUsers),
        payload: t__namespace.UnknownRecord,
    }),
    Result: t__namespace.array(CognitoUserSchema),
});

/* CreateDnsRecord */
var CreateDnsRecordSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.createDnsRecord),
        payload: t__namespace.type({
            userId: t__namespace.string,
            records: t__namespace.array(t__namespace.type({
                alias: t__namespace.string,
                domainId: t__namespace.string,
            })),
        }),
    }),
    Result: t__namespace.void,
});
/* DeleteDnsRecord */
var DeleteDnsRecordSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.deleteDnsRecord),
        payload: t__namespace.type({
            userId: t__namespace.string,
            records: t__namespace.array(t__namespace.type({
                alias: t__namespace.string,
            })),
        }),
    }),
    Result: t__namespace.void,
});
/* ListDnsRecords */
var ListDnsRecordsSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.listDnsRecords),
        payload: t__namespace.UnknownRecord,
    }),
    Result: t__namespace.any,
});

/* AddDomainUser */
var AddDomainUserSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.addDomainUser),
        payload: t__namespace.type({
            userId: t__namespace.string,
            domainId: t__namespace.string,
            user: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
});
/* RemoveDomainUser */
var RemoveDomainUserSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.removeDomainUser),
        payload: t__namespace.type({
            userId: t__namespace.string,
            domainId: t__namespace.string,
            user: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
});
/* SetDomainUsers */
var SetDomainUsersSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.setDomainUsers),
        payload: t__namespace.type({
            userId: t__namespace.string,
            domainId: t__namespace.string,
            users: DomainUsersSchema,
        }),
    }),
    Result: t__namespace.void,
});

/* SetVirtualHost */
var SetVirtualHostSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.setVirtualHost),
        payload: t__namespace.intersection([
            t__namespace.type({
                userId: t__namespace.string,
                domainId: t__namespace.string,
                virtualHost: t__namespace.string,
                functionArn: t__namespace.string,
            }),
            t__namespace.partial({
                routesManifest: t__namespace.string,
            }),
        ]),
    }),
    Result: t__namespace.void,
});
/* UnsetVirtualHost */
var UnsetVirtualHostSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.unsetVirtualHost),
        payload: t__namespace.intersection([
            t__namespace.type({
                userId: t__namespace.string,
                domainId: t__namespace.string,
            }),
            t__namespace.partial({ virtualHost: t__namespace.string, functionArn: t__namespace.string }),
        ]),
    }),
    Result: t__namespace.void,
});
/* ListVirtualHosts */
var ListVirtualHostsSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.listVirtualHosts),
        payload: t__namespace.type({
            userId: t__namespace.string,
            domainId: t__namespace.string,
        }),
    }),
    Result: VirtualHostsSchema,
});

/* GetDomain */
var GetDomainSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.getDomain),
        payload: t__namespace.type({
            userId: t__namespace.string,
            domainId: t__namespace.string,
        }),
    }),
    Result: DomainSchema,
});

/* DescribeEventStore */
var DescribeEventStoreSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.describeEventStore),
        payload: t__namespace.type({
            version: t__namespace.string,
            user: RDSUserSchema,
            eventStoreId: t__namespace.string,
            eventStoreClusterArn: t__namespace.string,
            postgresAdminSecretArn: t__namespace.string,
            eventStoreClusterEndpoint: t__namespace.string,
            eventStoreClusterPort: t__namespace.number,
            postgresAdminUsername: t__namespace.string,
            postgresAdminPassword: t__namespace.string,
        }),
    }),
    Result: t__namespace.type({
        events: t__namespace.union([t__namespace.number, t__namespace.null]),
        secrets: t__namespace.union([t__namespace.number, t__namespace.null]),
        modifiedAt: t__namespace.union([t__namespace.number, t__namespace.null]),
        createdAt: t__namespace.union([t__namespace.number, t__namespace.null]),
        isFrozen: t__namespace.union([t__namespace.boolean, t__namespace.null]),
    }),
});
/* UploadEventsToS3 */
var UploadEventsToS3EventSchema = t__namespace.type({
    name: t__namespace.literal(exports.FactoryEventNames.uploadEventsToS3),
    payload: t__namespace.intersection([
        t__namespace.type({
            version: t__namespace.string,
            user: RDSUserSchema,
            eventStoreId: t__namespace.string,
            eventStoreClusterEndpoint: t__namespace.string,
            eventStoreClusterPort: t__namespace.number,
            bucketName: t__namespace.string,
            databaseName: t__namespace.string,
        }),
        t__namespace.partial({
            cursor: t__namespace.union([t__namespace.string, t__namespace.null]),
            uploadId: t__namespace.union([t__namespace.string, t__namespace.null]),
            parts: t__namespace.array(t__namespace.any),
            partNumber: t__namespace.number,
            done: t__namespace.boolean,
        }),
    ]),
});
var UploadEventsToS3Schema = defineSchema({
    Event: UploadEventsToS3EventSchema,
    Result: UploadEventsToS3EventSchema,
});

/* DropEventSubscribers */
var DropEventSubscribersSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.FactoryEventNames.dropEventSubscribers),
        payload: t__namespace.type({
            userId: t__namespace.string,
            deploymentId: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
});

/* AddNotificationsWebhook */
var AddNotificationsWebhookSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.addNotificationsWebhook),
        payload: t__namespace.type({
            alarmName: t__namespace.string,
            url: t__namespace.string,
            messageTemplate: t__namespace.string,
        }),
    }),
    Result: t__namespace.type({
        id: t__namespace.string,
    }),
});
/* DeleteNotificationsWebhook */
var DeleteNotificationsWebhookSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.deleteNotificationsWebhook),
        payload: t__namespace.type({
            id: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
});

/* RDS Clusters */
var DescribeRDSClustersSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.describeRDSClusters),
        payload: t__namespace.UnknownRecord,
    }),
    Result: t__namespace.type({
        eventStoreClusterArn: t__namespace.union([t__namespace.string, t__namespace.null]),
        eventStoreClusterEndpoint: t__namespace.union([t__namespace.string, t__namespace.null]),
        eventStoreClusterPort: t__namespace.union([t__namespace.number, t__namespace.null]),
        readModelsClusterArn: t__namespace.union([t__namespace.string, t__namespace.null]),
        readModelsClusterEndpoint: t__namespace.union([t__namespace.string, t__namespace.null]),
        readModelsClusterPort: t__namespace.union([t__namespace.number, t__namespace.null]),
        systemClusterArn: t__namespace.union([t__namespace.string, t__namespace.null]),
        postgresAdminUsername: t__namespace.string,
        postgresAdminPassword: t__namespace.string,
        postgresAdminSecretName: t__namespace.string,
        postgresAdminSecretArn: t__namespace.string,
        systemDatabaseName: t__namespace.string,
    }),
});
/* EnsureRdsUser */
var EnsureRdsUserSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.ensureRdsUser),
        payload: t__namespace.type({
            userId: t__namespace.string,
        }),
    }),
    Result: t__namespace.type({
        user: RDSUserSchema,
        eventStoreClusterArn: t__namespace.string,
        eventStoreClusterEndpoint: t__namespace.string,
        eventStoreClusterPort: t__namespace.number,
        readModelsClusterArn: t__namespace.string,
        readModelsClusterEndpoint: t__namespace.string,
        readModelsClusterPort: t__namespace.number,
        postgresAdminPassword: t__namespace.string,
        postgresAdminSecretArn: t__namespace.string,
        postgresAdminSecretName: t__namespace.string,
        postgresAdminUsername: t__namespace.string,
    }),
});

/* InstallStageResources */
var InstallStageResourcesSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.installStageResources),
        payload: t__namespace.UnknownRecord,
    }),
    Result: t__namespace.void,
});
/* UninstallStageResources */
var UninstallStageResourcesSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.uninstallStageResources),
        payload: t__namespace.type({
            skipS3: t__namespace.boolean,
        }),
    }),
    Result: t__namespace.void,
});

/* GetAssetsStageBucketUploadSignedUrls */
var GetAssetsStageBucketUploadSignedUrlsSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.getAssetsStageBucketUploadSignedUrls),
        payload: t__namespace.type({
            assets: t__namespace.array(t__namespace.string),
        }),
    }),
    Result: t__namespace.record(t__namespace.string, t__namespace.string),
});
/* GetAssetsVersionBucketUploadSignedUrls */
var GetAssetsVersionBucketUploadSignedUrlsSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.getAssetsVersionBucketUploadSignedUrls),
        payload: t__namespace.type({
            version: t__namespace.string,
            assets: t__namespace.array(t__namespace.string),
        }),
    }),
    Result: t__namespace.record(t__namespace.string, t__namespace.string),
});
/* InstallAssetsBucket */
var InstallAssetsBucketSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.installAssetsBucket),
        payload: t__namespace.UnknownRecord,
    }),
    Result: t__namespace.void,
});
/* InstallVersionResources */
var InstallVersionResourcesSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.installVersionResources),
        payload: t__namespace.type({
            version: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
});
/* UninstallAssetsBucket */
var UninstallAssetsBucketSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.uninstallAssetsBucket),
        payload: t__namespace.type({
            skipS3: t__namespace.boolean,
        }),
    }),
    Result: t__namespace.void,
});
/* UninstallVersionAssetsFolder */
var UninstallVersionAssetsFolderSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.uninstallVersionAssetsFolder),
        payload: t__namespace.type({
            version: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
});
/* UninstallVersionResources */
var UninstallVersionResourcesSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.uninstallVersionResources),
        payload: t__namespace.type({
            version: t__namespace.string,
        }),
    }),
    Result: t__namespace.void,
});

/* EnsureRuntime */
var EnsureRuntimeSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.ensureRuntime),
        payload: t__namespace.type({
            version: t__namespace.string,
        }),
    }),
    Result: t__namespace.type({
        layerVersionArn: t__namespace.string,
    }),
});
/* SwitchApplicationsRuntime */
var SwitchApplicationsRuntimeSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.switchApplicationsRuntime),
        payload: t__namespace.intersection([
            t__namespace.type({
                version: t__namespace.string,
            }),
            t__namespace.partial({
                layerVersionArn: t__namespace.string,
            }),
        ]),
    }),
    Result: t__namespace.type({
        updatedFunctions: t__namespace.array(t__namespace.string),
    }),
});
/* FindRuntime */
var FindRuntimeSchema = defineSchema({
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.findRuntime),
        payload: t__namespace.intersection([
            t__namespace.type({
                version: t__namespace.string,
            }),
            t__namespace.partial({
                layerVersionArn: t__namespace.string,
            }),
        ]),
    }),
    Result: t__namespace.type({
        layerVersionArn: t__namespace.union([t__namespace.string, t__namespace.null]),
    }),
});

var Namespace = 'Auth';
/* AuthLogin */
var AuthLoginSchema = defineSchema({
    Namespace: Namespace,
    Description: 'Log in to reSolve Cloud.',
    Path: '/v0/auth/login',
    Method: 'POST',
    Mode: 'SYNC',
    Params: t__namespace.type({}),
    Body: t__namespace.type({
        userName: t__namespace.string,
        password: t__namespace.string,
    }),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.authLogin),
        payload: t__namespace.UnknownRecord,
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (args) { return ({
        params: {},
        body: { userName: args.userName, password: args.password },
        query: {},
    }); },
});
/* AuthLogout */
var AuthLogoutSchema = defineSchema({
    Namespace: Namespace,
    Description: 'Log out of reSolve Cloud.',
    Path: '/v0/auth/logout',
    Method: 'POST',
    Mode: 'SYNC',
    Params: t__namespace.type({}),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.authLogout),
        payload: t__namespace.UnknownRecord,
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});
/* AuthRefreshToken */
var AuthRefreshTokenSchema = defineSchema({
    Namespace: Namespace,
    Description: 'Refresh your authentication token on reSolve Cloud.',
    Path: '/v0/auth/refreshToken',
    Method: 'POST',
    Mode: 'SYNC',
    Params: t__namespace.type({}),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.authRefreshToken),
        payload: t__namespace.UnknownRecord,
    }),
    Result: t__namespace.void,
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});
/* AuthWhoAmI */
var AuthAuthWhoAmISchema = defineSchema({
    Namespace: Namespace,
    Description: "Get the current user's profile information.",
    Path: '/v0/auth/whoami',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t__namespace.type({}),
    Body: t__namespace.type({}),
    Query: t__namespace.type({}),
    Event: t__namespace.type({
        name: t__namespace.literal(exports.InstallerEventNames.authWhoAmI),
        payload: t__namespace.type({
            userId: t__namespace.string,
            userName: t__namespace.string,
            isAdmin: t__namespace.boolean,
        }),
    }),
    Result: t__namespace.type({
        userId: t__namespace.string,
        userName: t__namespace.string,
        isAdmin: t__namespace.boolean,
    }),
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});

exports.APPLICATION_NAME_TAG_NAME = APPLICATION_NAME_TAG_NAME;
exports.AddDomainUserSchema = AddDomainUserSchema;
exports.AddNotificationsWebhookSchema = AddNotificationsWebhookSchema;
exports.AttachClientAppUrlsSchema = AttachClientAppUrlsSchema;
exports.AuthAuthWhoAmISchema = AuthAuthWhoAmISchema;
exports.AuthLoginSchema = AuthLoginSchema;
exports.AuthLogoutSchema = AuthLogoutSchema;
exports.AuthRefreshTokenSchema = AuthRefreshTokenSchema;
exports.BATCHES_TABLE_NAME = BATCHES_TABLE_NAME;
exports.BootstrapDeploymentSchema = BootstrapDeploymentSchema;
exports.BuildCodeSchema = BuildCodeSchema;
exports.BuildDeploymentSchema = BuildDeploymentSchema;
exports.CERTIFICATE_ID_TAG_NAME = CERTIFICATE_ID_TAG_NAME;
exports.CONNECTIONS_TABLE_NAME = CONNECTIONS_TABLE_NAME;
exports.CREATED_AT_TAG_NAME = CREATED_AT_TAG_NAME;
exports.CertificateSchema = CertificateSchema;
exports.ClearEventStoreSchema = ClearEventStoreSchema;
exports.ClientApiEventSchema = ClientApiEventSchema;
exports.ClientApiResultSchema = ClientApiResultSchema;
exports.CloneEventStoreSchema = CloneEventStoreSchema;
exports.CognitoJWTHeaderSchema = CognitoJWTHeaderSchema;
exports.CognitoJWTPayloadSchema = CognitoJWTPayloadSchema;
exports.CognitoUserSchema = CognitoUserSchema;
exports.CreateDeploymentSchema = CreateDeploymentSchema;
exports.CreateDnsRecordSchema = CreateDnsRecordSchema;
exports.CreateDomainSchema = CreateDomainSchema;
exports.CreateEventStoreSchema = CreateEventStoreSchema;
exports.CreateReadModelSchema = CreateReadModelSchema;
exports.CreateUserSchema = CreateUserSchema;
exports.DEPLOYMENT_ID_TAG_NAME = DEPLOYMENT_ID_TAG_NAME;
exports.DEPLOYMENT_TAG_TAG_NAME = DEPLOYMENT_TAG_TAG_NAME;
exports.DOMAIN_CUSTOM_NAME_TAG_NAME = DOMAIN_CUSTOM_NAME_TAG_NAME;
exports.DOMAIN_NAME_TAG_NAME = DOMAIN_NAME_TAG_NAME;
exports.DOMAIN_TYPE_TAG_NAME = DOMAIN_TYPE_TAG_NAME;
exports.DOMAIN_USERS_TAG_NAME = DOMAIN_USERS_TAG_NAME;
exports.DeleteDnsRecordSchema = DeleteDnsRecordSchema;
exports.DeleteNotificationsWebhookSchema = DeleteNotificationsWebhookSchema;
exports.DeleteSagaPropertySchema = DeleteSagaPropertySchema;
exports.DeployStaticSchema = DeployStaticSchema;
exports.DeploymentSchema = DeploymentSchema;
exports.DescribeDeploymentSchema = DescribeDeploymentSchema;
exports.DescribeEventStoreSchema = DescribeEventStoreSchema;
exports.DescribeExecutionSchema = DescribeExecutionSchema;
exports.DescribeRDSClustersSchema = DescribeRDSClustersSchema;
exports.DetachClientAppUrlsSchema = DetachClientAppUrlsSchema;
exports.DisableLogsSchema = DisableLogsSchema;
exports.DisableTracingSchema = DisableTracingSchema;
exports.DomainSchema = DomainSchema;
exports.DomainTypeSchema = DomainTypeSchema;
exports.DomainUsersSchema = DomainUsersSchema;
exports.DomainsSchema = DomainsSchema;
exports.DropCertificateSchema = DropCertificateSchema;
exports.DropDeploymentSchema = DropDeploymentSchema;
exports.DropDomainSchema = DropDomainSchema;
exports.DropEventStoreSchema = DropEventStoreSchema;
exports.DropEventSubscribersSchema = DropEventSubscribersSchema;
exports.DropReadModelSchema = DropReadModelSchema;
exports.DropUserSchema = DropUserSchema;
exports.EDGE_REGION = EDGE_REGION;
exports.EVENT_STORE_DATABASE_NAME = EVENT_STORE_DATABASE_NAME;
exports.EVENT_STORE_ID_TAG_NAME = EVENT_STORE_ID_TAG_NAME;
exports.EnableLogsSchema = EnableLogsSchema;
exports.EnableTracingSchema = EnableTracingSchema;
exports.EnsureCertificateSchema = EnsureCertificateSchema;
exports.EnsureRdsUserSchema = EnsureRdsUserSchema;
exports.EnsureRuntimeSchema = EnsureRuntimeSchema;
exports.ExportEventStoreSchema = ExportEventStoreSchema;
exports.FatalError = FatalError;
exports.FindRuntimeSchema = FindRuntimeSchema;
exports.FreezeEventStoreSchema = FreezeEventStoreSchema;
exports.GetAssetsStageBucketUploadSignedUrlsSchema = GetAssetsStageBucketUploadSignedUrlsSchema;
exports.GetAssetsVersionBucketUploadSignedUrlsSchema = GetAssetsVersionBucketUploadSignedUrlsSchema;
exports.GetCertificateByDomainNameSchema = GetCertificateByDomainNameSchema;
exports.GetCertificateByIdSchema = GetCertificateByIdSchema;
exports.GetClientAppConfigSchema = GetClientAppConfigSchema;
exports.GetDeploymentUploadSignedUrlSchema = GetDeploymentUploadSignedUrlSchema;
exports.GetDomainSchema = GetDomainSchema;
exports.GetEventStoreSchema = GetEventStoreSchema;
exports.GetExportUrlsSchema = GetExportUrlsSchema;
exports.GetImportUrlsSchema = GetImportUrlsSchema;
exports.GetLogsSchema = GetLogsSchema;
exports.GetSagaPropertySchema = GetSagaPropertySchema;
exports.GetSummariesSchema = GetSummariesSchema;
exports.GetTracingDetailsSchema = GetTracingDetailsSchema;
exports.GetTracingStatusSchema = GetTracingStatusSchema;
exports.GetUserIdByEmailSchema = GetUserIdByEmailSchema;
exports.GetUserSchema = GetUserSchema;
exports.GetVerificationCodeSchema = GetVerificationCodeSchema;
exports.HEADER_EXECUTION_MODE = HEADER_EXECUTION_MODE;
exports.HeartbeatSchema = HeartbeatSchema;
exports.IS_RESOLVE_CLOUD_SDK_SCHEMA = IS_RESOLVE_CLOUD_SDK_SCHEMA;
exports.ImportEventStoreSchema = ImportEventStoreSchema;
exports.InstallAssetsBucketSchema = InstallAssetsBucketSchema;
exports.InstallStageResourcesSchema = InstallStageResourcesSchema;
exports.InstallVersionResourcesSchema = InstallVersionResourcesSchema;
exports.JSON_SQL_TYPE = JSON_SQL_TYPE;
exports.LINKED_DEPLOYMENTS_TAG_NAME = LINKED_DEPLOYMENTS_TAG_NAME;
exports.LONG_INTEGER_SQL_TYPE = LONG_INTEGER_SQL_TYPE;
exports.LinkDeploymentSchema = LinkDeploymentSchema;
exports.ListCertificatesSchema = ListCertificatesSchema;
exports.ListDeploymentsSchema = ListDeploymentsSchema;
exports.ListDnsRecordsSchema = ListDnsRecordsSchema;
exports.ListDomainsSchema = ListDomainsSchema;
exports.ListEnvironmentVariablesSchema = ListEnvironmentVariablesSchema;
exports.ListEventStoresSchema = ListEventStoresSchema;
exports.ListReadModelsSchema = ListReadModelsSchema;
exports.ListSagaPropertiesSchema = ListSagaPropertiesSchema;
exports.ListSagasSchema = ListSagasSchema;
exports.ListUsersSchema = ListUsersSchema;
exports.ListVersionsSchema = ListVersionsSchema;
exports.ListVirtualHostsSchema = ListVirtualHostsSchema;
exports.MANAGER_TAG_NAME = MANAGER_TAG_NAME;
exports.NOTIFICATIONS_TABLE_NAME = NOTIFICATIONS_TABLE_NAME;
exports.PATTERNS_TABLE_NAME = PATTERNS_TABLE_NAME;
exports.PauseReadModelSchema = PauseReadModelSchema;
exports.PauseSagaSchema = PauseSagaSchema;
exports.RDSUserSchema = RDSUserSchema;
exports.RDS_CLUSTER_NAME_TAG_NAME = RDS_CLUSTER_NAME_TAG_NAME;
exports.READ_MODELS_DATABASE_NAME = READ_MODELS_DATABASE_NAME;
exports.RESOURCE_TAG_NAME = RESOURCE_TAG_NAME;
exports.ReleaseDomainSchema = ReleaseDomainSchema;
exports.RemoveDomainUserSchema = RemoveDomainUserSchema;
exports.RemoveEnvironmentVariablesSchema = RemoveEnvironmentVariablesSchema;
exports.RemoveLogsSchema = RemoveLogsSchema;
exports.ResetReadModelSchema = ResetReadModelSchema;
exports.ResetSagaSchema = ResetSagaSchema;
exports.ResumeReadModelSchema = ResumeReadModelSchema;
exports.ResumeSagaSchema = ResumeSagaSchema;
exports.SERIAL_SQL_TYPE = SERIAL_SQL_TYPE;
exports.STAGE_TAG_NAME = STAGE_TAG_NAME;
exports.STRING_SQL_TYPE = STRING_SQL_TYPE;
exports.SUBSCRIBERS_TABLE_NAME = SUBSCRIBERS_TABLE_NAME;
exports.SUBSCRIPTIONS_TABLE_NAME = SUBSCRIPTIONS_TABLE_NAME;
exports.SYSTEM_DATABASE_NAME = SYSTEM_DATABASE_NAME;
exports.SetDeploymentDomainSchema = SetDeploymentDomainSchema;
exports.SetDomainUsersSchema = SetDomainUsersSchema;
exports.SetEnvironmentVariablesSchema = SetEnvironmentVariablesSchema;
exports.SetSagaPropertySchema = SetSagaPropertySchema;
exports.SetVirtualHostSchema = SetVirtualHostSchema;
exports.ShutdownDeploymentSchema = ShutdownDeploymentSchema;
exports.SwitchApplicationsRuntimeSchema = SwitchApplicationsRuntimeSchema;
exports.TEXT_SQL_TYPE = TEXT_SQL_TYPE;
exports.USER_ID_TAG_NAME = USER_ID_TAG_NAME;
exports.UnfreezeEventStoreSchema = UnfreezeEventStoreSchema;
exports.UninstallAssetsBucketSchema = UninstallAssetsBucketSchema;
exports.UninstallStageResourcesSchema = UninstallStageResourcesSchema;
exports.UninstallVersionAssetsFolderSchema = UninstallVersionAssetsFolderSchema;
exports.UninstallVersionResourcesSchema = UninstallVersionResourcesSchema;
exports.UnlinkDeploymentSchema = UnlinkDeploymentSchema;
exports.UnsetDeploymentDomainSchema = UnsetDeploymentDomainSchema;
exports.UnsetVirtualHostSchema = UnsetVirtualHostSchema;
exports.UpdateEnvironmentVariablesSchema = UpdateEnvironmentVariablesSchema;
exports.UploadEventsToS3Schema = UploadEventsToS3Schema;
exports.VERSION_TAG_NAME = VERSION_TAG_NAME;
exports.VerifyDomainSchema = VerifyDomainSchema;
exports.VirtualHostsSchema = VirtualHostsSchema;
exports.coerceVersion = coerceVersion;
exports.createCloudSdk = createCloudSdk;
exports.defineSchema = defineSchema;
exports.generateDeploymentId = generateDeploymentId;
exports.generateEventStoreId = generateEventStoreId;
exports.generateExecutionId = generateExecutionId;
exports.getXRangeVersion = getXRangeVersion;
exports.intersectsVersions = intersectsVersions;
exports.isHeartbeat = isHeartbeat;
exports.isLambdaError = isLambdaError;
exports.isNetworkError = isNetworkError;
exports.isRetryable = isRetryable;
exports.isUrlContainIp = isUrlContainIp;
exports.validate = validate;
//# sourceMappingURL=index.cjs.js.map
