import { customAlphabet } from 'nanoid';
import { PathReporter } from 'io-ts/lib/PathReporter';
import { isRight } from 'fp-ts/lib/Either';
import * as t from 'io-ts';
import semver from 'semver';
import { stringify } from 'query-string';

var STAGE_TAG_NAME = 'resolve-stage';
var VERSION_TAG_NAME = 'resolve-version';
var RESOURCE_TAG_NAME = 'resolve-resource';
var MANAGER_TAG_NAME = 'resolve-manager';
var DOMAIN_TYPE_TAG_NAME = 'resolve-domain-type';
var DOMAIN_CUSTOM_NAME_TAG_NAME = 'resolve-domain-custom-name';
var DOMAIN_NAME_TAG_NAME = 'resolve-domain-name';
var CERTIFICATE_ID_TAG_NAME = 'resolve-certificate-id';
var USER_ID_TAG_NAME = 'resolve-user-id';
var DOMAIN_USERS_TAG_NAME = 'resolve-users';
var EVENT_STORE_ID_TAG_NAME = 'resolve-event-store-id';
var LINKED_DEPLOYMENTS_TAG_NAME = 'resolve-linked-deployments';
var DEPLOYMENT_ID_TAG_NAME = 'resolve-deployment-id';
var APPLICATION_NAME_TAG_NAME = 'resolve-application-name';
var RDS_CLUSTER_NAME_TAG_NAME = 'resolve-rds-cluster-name';
var DEPLOYMENT_TAG_TAG_NAME = 'resolve-deployment-tag';
var CREATED_AT_TAG_NAME = 'resolve-created-at';
var EDGE_REGION = 'us-east-1';
var EVENT_STORE_DATABASE_NAME = 'event-store';
var READ_MODELS_DATABASE_NAME = 'read-models';
var SYSTEM_DATABASE_NAME = 'system';
var CONNECTIONS_TABLE_NAME = 'connections';
var SUBSCRIPTIONS_TABLE_NAME = 'subscriptions';
var PATTERNS_TABLE_NAME = 'patterns';
var NOTIFICATIONS_TABLE_NAME = 'notifications';
var SUBSCRIBERS_TABLE_NAME = 'subscribers';
var BATCHES_TABLE_NAME = 'batches';
var SERIAL_SQL_TYPE = 'serial';
var LONG_INTEGER_SQL_TYPE = 'bigint';
var JSON_SQL_TYPE = 'jsonb';
var STRING_SQL_TYPE = 'VARCHAR(100)';
var TEXT_SQL_TYPE = 'TEXT';
var HEADER_EXECUTION_MODE = 'x-resolve-execution-mode';
var DomainCustomNames;
(function (DomainCustomNames) {
    DomainCustomNames["DEPLOYMENTS"] = "deployments";
    DomainCustomNames["SYSTEM"] = "system";
    DomainCustomNames["STATIC"] = "static";
    DomainCustomNames["UPLOADER"] = "uploader";
})(DomainCustomNames || (DomainCustomNames = {}));
var FactoryEventNames;
(function (FactoryEventNames) {
    /* EventStore */
    FactoryEventNames["createEventStore"] = "createEventStore";
    FactoryEventNames["dropEventStore"] = "dropEventStore";
    FactoryEventNames["describeEventStore"] = "describeEventStore";
    FactoryEventNames["cloneEventStore"] = "cloneEventStore";
    FactoryEventNames["linkDeployment"] = "linkDeployment";
    FactoryEventNames["unlinkDeployment"] = "unlinkDeployment";
    FactoryEventNames["clearEventStore"] = "clearEventStore";
    FactoryEventNames["freezeEventStore"] = "freezeEventStore";
    FactoryEventNames["unfreezeEventStore"] = "unfreezeEventStore";
    FactoryEventNames["importEventStore"] = "importEventStore";
    FactoryEventNames["exportEventStore"] = "exportEventStore";
    FactoryEventNames["getImportUrls"] = "getImportUrls";
    FactoryEventNames["getExportUrls"] = "getExportUrls";
    FactoryEventNames["uploadEventsToS3"] = "uploadEventsToS3";
    /* ReadModel */
    FactoryEventNames["createReadModel"] = "createReadModel";
    FactoryEventNames["dropReadModel"] = "dropReadModel";
    FactoryEventNames["listReadModels"] = "listReadModels";
    FactoryEventNames["pauseReadModel"] = "pauseReadModel";
    FactoryEventNames["resetReadModel"] = "resetReadModel";
    FactoryEventNames["resumeReadModel"] = "resumeReadModel";
    /* Saga */
    FactoryEventNames["listSagas"] = "listSagas";
    FactoryEventNames["pauseSaga"] = "pauseSaga";
    FactoryEventNames["resetSaga"] = "resetSaga";
    FactoryEventNames["resumeSaga"] = "resumeSaga";
    FactoryEventNames["listSagaProperties"] = "listSagaProperties";
    FactoryEventNames["setSagaProperty"] = "setSagaProperty";
    FactoryEventNames["deleteSagaProperty"] = "deleteSagaProperty";
    FactoryEventNames["getSagaProperty"] = "getSagaProperty";
    /* Lifecycle */
    FactoryEventNames["bootstrapDeployment"] = "bootstrapDeployment";
    FactoryEventNames["shutdownDeployment"] = "shutdownDeployment";
    FactoryEventNames["dropEventSubscribers"] = "dropEventSubscribers";
})(FactoryEventNames || (FactoryEventNames = {}));
var BuilderEventNames;
(function (BuilderEventNames) {
    BuilderEventNames["buildCode"] = "buildCode";
    BuilderEventNames["deployStatic"] = "deployStatic";
})(BuilderEventNames || (BuilderEventNames = {}));
var InstallerEventNames;
(function (InstallerEventNames) {
    InstallerEventNames["heartbeat"] = "heartbeat";
    InstallerEventNames["authLogin"] = "authLogin";
    InstallerEventNames["authLogout"] = "authLogout";
    InstallerEventNames["authRefreshToken"] = "authRefreshToken";
    InstallerEventNames["authWhoAmI"] = "authWhoAmI";
    InstallerEventNames["installStageResources"] = "installStageResources";
    InstallerEventNames["uninstallStageResources"] = "uninstallStageResources";
    InstallerEventNames["installVersionResources"] = "installVersionResources";
    InstallerEventNames["uninstallVersionResources"] = "uninstallVersionResources";
    InstallerEventNames["uninstallVersionAssetsFolder"] = "uninstallVersionAssetsFolder";
    InstallerEventNames["installAssetsBucket"] = "installAssetsBucket";
    InstallerEventNames["uninstallAssetsBucket"] = "uninstallAssetsBucket";
    InstallerEventNames["getAssetsStageBucketUploadSignedUrls"] = "getAssetsStageBucketUploadSignedUrls";
    InstallerEventNames["getAssetsVersionBucketUploadSignedUrls"] = "getAssetsVersionBucketUploadSignedUrls";
    InstallerEventNames["describe"] = "describe";
    InstallerEventNames["describeExecution"] = "describeExecution";
    InstallerEventNames["ensureCertificate"] = "ensureCertificate";
    InstallerEventNames["dropCertificate"] = "dropCertificate";
    InstallerEventNames["getCertificateById"] = "getCertificateById";
    InstallerEventNames["listCertificates"] = "listCertificates";
    InstallerEventNames["getCertificateByDomainName"] = "getCertificateByDomainName";
    InstallerEventNames["createStaticDomain"] = "createStaticDomain";
    InstallerEventNames["createProxyDomain"] = "createProxyDomain";
    InstallerEventNames["createUploaderDomain"] = "createUploaderDomain";
    InstallerEventNames["dropDomain"] = "dropDomain";
    InstallerEventNames["setDomainUsers"] = "setDomainUsers";
    InstallerEventNames["addDomainUser"] = "addDomainUser";
    InstallerEventNames["removeDomainUser"] = "removeDomainUser";
    InstallerEventNames["releaseDomain"] = "releaseDomain";
    InstallerEventNames["getDomain"] = "getDomain";
    InstallerEventNames["listDomains"] = "listDomains";
    InstallerEventNames["verifyDomain"] = "verifyDomain";
    InstallerEventNames["getVerificationCode"] = "getVerificationCode";
    InstallerEventNames["createUser"] = "createUser";
    InstallerEventNames["dropUser"] = "dropUser";
    InstallerEventNames["getUser"] = "getUser";
    InstallerEventNames["getUserIdByEmail"] = "getUserIdByEmail";
    InstallerEventNames["listUsers"] = "listUsers";
    InstallerEventNames["attachClientAppUrls"] = "attachClientAppUrls";
    InstallerEventNames["detachClientAppUrls"] = "detachClientAppUrls";
    InstallerEventNames["executeFactory"] = "executeFactory";
    InstallerEventNames["setVirtualHost"] = "setVirtualHost";
    InstallerEventNames["unsetVirtualHost"] = "unsetVirtualHost";
    InstallerEventNames["listVirtualHosts"] = "listVirtualHosts";
    InstallerEventNames["getClientAppConfig"] = "getClientAppConfig";
    InstallerEventNames["enableLogs"] = "enableLogs";
    InstallerEventNames["disableLogs"] = "disableLogs";
    InstallerEventNames["getLogs"] = "getLogs";
    InstallerEventNames["removeLogs"] = "removeLogs";
    InstallerEventNames["updateEnvironmentVariables"] = "updateEnvironmentVariables";
    InstallerEventNames["listEnvironmentVariables"] = "listEnvironmentVariables";
    InstallerEventNames["enableTracing"] = "enableTracing";
    InstallerEventNames["disableTracing"] = "disableTracing";
    InstallerEventNames["getTracingDetails"] = "getTracingDetails";
    InstallerEventNames["getSummaries"] = "getSummaries";
    InstallerEventNames["getTracingStatus"] = "getTracingStatus";
    InstallerEventNames["describeDeployment"] = "describeDeployment";
    InstallerEventNames["listDeployments"] = "listDeployments";
    InstallerEventNames["createDeployment"] = "createDeployment";
    InstallerEventNames["getDeploymentUploadSignedUrl"] = "getDeploymentUploadSignedUrl";
    InstallerEventNames["buildDeployment"] = "buildDeployment";
    InstallerEventNames["dropDeployment"] = "dropDeployment";
    InstallerEventNames["getDeploymentByApplicationName"] = "getDeploymentByApplicationName";
    InstallerEventNames["getDeploymentByTag"] = "getDeploymentByTag";
    InstallerEventNames["setDeploymentDomain"] = "setDeploymentDomain";
    InstallerEventNames["unsetDeploymentDomain"] = "unsetDeploymentDomain";
    InstallerEventNames["listEventStores"] = "listEventStores";
    InstallerEventNames["ensureRdsUser"] = "ensureRdsUser";
    InstallerEventNames["listVersions"] = "listVersions";
    InstallerEventNames["createDnsRecord"] = "createDnsRecord";
    InstallerEventNames["deleteDnsRecord"] = "deleteDnsRecord";
    InstallerEventNames["listDnsRecords"] = "listDnsRecords";
    InstallerEventNames["listHostedZones"] = "listHostedZones";
    InstallerEventNames["getEventStore"] = "getEventStore";
    InstallerEventNames["setDeploymentTag"] = "setDeploymentTag";
    InstallerEventNames["unsetDeploymentTag"] = "unsetDeploymentTag";
    InstallerEventNames["describeRDSClusters"] = "describeRDSClusters";
    InstallerEventNames["addNotificationsWebhook"] = "addNotificationsWebhook";
    InstallerEventNames["deleteNotificationsWebhook"] = "deleteNotificationsWebhook";
    InstallerEventNames["listNotificationsWebhooks"] = "listNotificationsWebhooks";
    InstallerEventNames["ensureRuntime"] = "ensureRuntime";
    InstallerEventNames["switchApplicationsRuntime"] = "switchApplicationsRuntime";
    InstallerEventNames["findRuntime"] = "findRuntime";
})(InstallerEventNames || (InstallerEventNames = {}));

var generateExecutionId = customAlphabet('0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz-_', 16);
var getFirstCharacter = customAlphabet('abcdefghijklmnopqrstuvwxyz', 1);
var getRandomCharacters = customAlphabet('0123456789abcdefghijklmnopqrstuvwxyz', 5);
var generateEventStoreId = function () { return [getFirstCharacter(), getRandomCharacters()].join(''); };
var generateDeploymentId = function () { return [getFirstCharacter(), getRandomCharacters()].join(''); };

function validate(schema, params, errorName) {
    var validationResult = schema.decode(params);
    if (!isRight(validationResult)) {
        var messages = PathReporter.report(validationResult);
        var error = new Error(messages.join('\r\n'));
        if (errorName != null) {
            error.name = errorName;
        }
        throw error;
    }
    return params;
}

var VirtualHostsSchema = t.array(t.type({
    virtualHost: t.string,
    functionArn: t.string,
}));
var DomainUsersSchema = t.union([t.literal('*'), t.array(t.string)]);
var DomainTypeSchema = t.union([
    t.literal('proxy'),
    t.literal('static'),
    t.literal('uploader'),
]);
var DomainSchema = t.type({
    domainId: t.string,
    domainType: DomainTypeSchema,
    domainName: t.string,
    resourceARN: t.string,
    aliases: t.array(t.string),
    verified: t.boolean,
    owner: t.string,
    users: DomainUsersSchema,
    verificationCode: t.string,
    certificateId: t.string,
});
var DomainsSchema = t.array(DomainSchema);
var DeploymentSchema = t.intersection([
    t.type({
        deploymentId: t.string,
        applicationName: t.string,
        version: t.string,
        domains: t.array(t.string),
    }),
    t.partial({
        eventStoreId: t.string,
    }),
]);
var CognitoUserSchema = t.type({
    userId: t.string,
    email: t.string,
    enabled: t.boolean,
    userStatus: t.string,
    isAdmin: t.boolean,
});
var CognitoJWTPayloadSchema = t.intersection([
    t.type({
        sub: t.string,
        aud: t.string,
        event_id: t.string,
        token_use: t.literal('id'),
        auth_time: t.number,
        iss: t.string,
        'cognito:username': t.string,
        exp: t.number,
        iat: t.number,
        email: t.string,
    }),
    t.partial({
        'cognito:groups': t.array(t.string),
        email_verified: t.boolean,
    }),
]);
var CognitoJWTHeaderSchema = t.type({
    kid: t.string,
    alg: t.literal('RS256'),
});
var ClientApiEventSchema = t.type({
    httpMethod: t.string,
    headers: t.array(t.type({ key: t.string, value: t.string })),
    uri: t.string,
    querystring: t.string,
    body: t.string, // Base64
});
var ClientApiResultSchema = t.type({
    httpStatus: t.number,
    httpStatusText: t.string,
    headers: t.array(t.type({ key: t.string, value: t.string })),
    body: t.string, // Base64
});
var CertificateSchema = t.intersection([
    t.type({
        certificateId: t.string,
        additionalNames: t.array(t.string),
        resourceARN: t.string,
    }),
    t.partial({
        domainName: t.string,
        importedAt: t.string,
        issuer: t.string,
        notBefore: t.string,
        notAfter: t.string,
    }),
]);
var RDSUserSchema = t.type({
    userId: t.string,
    password: t.string,
    secretName: t.string,
    secretArn: t.string,
});
var IS_RESOLVE_CLOUD_SDK_SCHEMA = Symbol('IS_RESOLVE_CLOUD_SDK_SCHEMA');
var defineSchema = function (route) {
    var _a;
    Object.assign(route, (_a = {}, _a[IS_RESOLVE_CLOUD_SDK_SCHEMA] = true, _a));
    return route;
};

var getXRangeVersion = function (version) {
    var parsedVersion = semver.parse(version);
    if (parsedVersion == null) {
        throw new Error("Parse version \"".concat(version, "\" failed"));
    }
    var major = parsedVersion.major, minor = parsedVersion.minor;
    return "".concat(major, ".").concat(minor, ".x");
};
var coerceVersion = function (version) { return semver.valid(semver.coerce(version)); };
var intersectsVersions = function (range, version) {
    var parsedRange = "".concat(semver.major(range), ".").concat(semver.minor(range), ".x");
    var parsedVersion = "".concat(semver.major(version), ".").concat(semver.minor(version), ".").concat(semver.patch(version));
    return semver.intersects(parsedRange, parsedVersion);
};

var ipV4RegExp = /[0-9]+.[0-9]+.[0-9]+.[0-9]+/;
var rateExceededRegExp = /Rate exceeded/;
var socketHangUpRegExp = /socket hang up/;
var throttledRegExp = /The Lambda function associated with the CloudFront distribution was throttled/;
var requiredPermissionsRegExp = /The Lambda function associated with the CloudFront distribution is invalid or doesn't have the required permissions/;
var eTimedOutRegExp = /ETIMEDOUT/;
var eConnectionResetRegExp = /ECONNRESET/;
var eNotFoundRegExp = /ENOTFOUND/;
var eProtoRegExp = /EPROTO/;
var eHostUnreach = /EHOSTUNREACH/;
var eConnRefused = /ECONNREFUSED/;
var cloudFrontError = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>";
var lambdaEdgeTimeout = 'lambda@edge timeout';
var failedToSetupAuthentication = 'Failed to setup authentication';
var isNetworkError = function (_a) {
    var errorText = _a.errorText;
    return eTimedOutRegExp.test(errorText) ||
        eConnectionResetRegExp.test(errorText) ||
        eNotFoundRegExp.test(errorText) ||
        eProtoRegExp.test(errorText) ||
        eHostUnreach.test(errorText) ||
        eConnRefused.test(errorText) ||
        socketHangUpRegExp.test(errorText) ||
        errorText.includes(lambdaEdgeTimeout) ||
        errorText.includes(failedToSetupAuthentication) ||
        errorText.includes(cloudFrontError);
};
var isLambdaError = function (_a) {
    var errorText = _a.errorText;
    return rateExceededRegExp.test(errorText) ||
        throttledRegExp.test(errorText) ||
        requiredPermissionsRegExp.test(errorText);
};
var isHeartbeat = function (_a) {
    var method = _a.method;
    return method === 'HEAD';
};
var isUrlContainIp = function (_a) {
    var baseUrl = _a.baseUrl;
    return ipV4RegExp.test(baseUrl);
};
var isRetryable = function (params) {
    return !isHeartbeat(params) && (isLambdaError(params) || isNetworkError(params));
};

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */
/* global Reflect, Promise */

var extendStatics = function(d, b) {
    extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
    return extendStatics(d, b);
};

function __extends(d, b) {
    if (typeof b !== "function" && b !== null)
        throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
    extendStatics(d, b);
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
}

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

var FATAL_ERROR_MESSAGE = 'Please contact the ReSolve team by e-mail: reimagined@devexpress.com';
var FatalError = /** @class */ (function (_super) {
    __extends(FatalError, _super);
    function FatalError(message) {
        return _super.call(this, message == null || message.trim() === ''
            ? FATAL_ERROR_MESSAGE
            : "".concat(message, ". ").concat(FATAL_ERROR_MESSAGE)) || this;
    }
    return FatalError;
}(Error));

var Namespace$c = 'System';
/* Heartbeat */
var HeartbeatSchema = defineSchema({
    Namespace: Namespace$c,
    Description: 'Check if the service is available.',
    Path: '/v0',
    Method: 'HEAD',
    Mode: 'SYNC',
    Params: t.type({}),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.heartbeat),
        payload: t.void,
    }),
    Result: t.void,
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});
/* ListVersions */
var ListVersionsSchema = defineSchema({
    Namespace: Namespace$c,
    Description: 'Get a list of the available reSolve versions.',
    Path: '/v0/runtimes',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({}),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.listVersions),
        payload: t.UnknownRecord,
    }),
    Result: t.array(t.string),
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});
/* DescribeExecution */
var DescribeExecutionSchema = defineSchema({
    Namespace: Namespace$c,
    Description: 'Get the status of a long-running operation specified by its ID.',
    Path: '/v0/describe-execution/:executionId',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({
        executionId: t.string,
    }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.describeExecution),
        payload: t.type({
            executionId: t.string,
            userId: t.string,
        }),
    }),
    Result: t.type({
        status: t.union([
            t.literal('RUNNING'),
            t.literal('SUCCEEDED'),
            t.literal('FAILED'),
            t.literal('TIMED_OUT'),
            t.literal('ABORTED'),
        ]),
        output: t.any,
    }),
    ArgumentsTransformer: function (args) { return ({
        params: { executionId: args.executionId },
        body: {},
        query: {},
    }); },
});
/* GetClientAppConfig */
var GetClientAppConfigSchema = defineSchema({
    Namespace: Namespace$c,
    Description: "Get reSolve Cloud's app client ID and user pool ID on Amazon Cognito.",
    Path: '/v0/client-app-config',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({}),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.getClientAppConfig),
        payload: t.type({}),
    }),
    Result: t.type({
        clientId: t.string,
        userPoolId: t.string,
    }),
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});

var Namespace$b = 'Deployments';
/* CreateDeployment */
var CreateDeploymentSchema = defineSchema({
    Namespace: Namespace$b,
    Description: 'Create a new deployment.',
    Path: '/v0/deployments',
    Method: 'POST',
    Mode: 'ASYNC',
    Params: t.type({}),
    Body: t.intersection([
        t.type({
            applicationName: t.string,
            version: t.string,
            eventStoreId: t.string,
        }),
        t.partial({
            domain: t.string,
        }),
    ]),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.createDeployment),
        payload: t.intersection([
            t.type({
                userId: t.string,
                applicationName: t.string,
                version: t.string,
                eventStoreId: t.string,
            }),
            t.partial({
                domain: t.string,
                deploymentTag: t.string,
            }),
        ]),
    }),
    Result: DeploymentSchema,
    ArgumentsTransformer: function (args) { return ({
        params: {},
        body: args,
        query: {},
    }); },
});
/* DropDeployment */
var DropDeploymentSchema = defineSchema({
    Namespace: Namespace$b,
    Description: 'Remove an existing deployment.',
    Path: '/v0/deployments/:deploymentId',
    Method: 'DELETE',
    Mode: 'ASYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.partial({ withEventStore: t.boolean }),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.dropDeployment),
        payload: t.intersection([
            t.type({
                userId: t.string,
                deploymentId: t.string,
            }),
            t.partial({
                withEventStore: t.boolean,
            }),
        ]),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, withEventStore = _a.withEventStore;
        return ({
            params: { deploymentId: deploymentId },
            body: { withEventStore: withEventStore },
            query: {},
        });
    },
});
/* ListDeployments */
var ListDeploymentsSchema = defineSchema({
    Namespace: Namespace$b,
    Description: 'Get a list of existing deployments.',
    Path: '/v0/deployments',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({}),
    Body: t.type({}),
    Query: t.partial({ applicationName: t.string }),
    Event: t.type({
        name: t.literal(InstallerEventNames.listDeployments),
        payload: t.intersection([
            t.type({
                userId: t.string,
            }),
            t.partial({
                applicationName: t.string,
            }),
        ]),
    }),
    Result: t.array(DeploymentSchema),
    ArgumentsTransformer: function (_a) {
        var _b = _a === void 0 ? {} : _a, applicationName = _b.applicationName;
        return ({
            params: {},
            body: {},
            query: { applicationName: applicationName },
        });
    },
});
/* DescribeDeployment */
var DescribeDeploymentSchema = defineSchema({
    Namespace: Namespace$b,
    Description: 'Obtain information about a deployment.',
    Path: '/v0/deployments/:deploymentId',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.describeDeployment),
        payload: t.type({
            userId: t.string,
            deploymentId: t.string,
        }),
    }),
    Result: DeploymentSchema,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});
/* BootstrapDeployment */
var BootstrapDeploymentSchema = defineSchema({
    Namespace: Namespace$b,
    Description: 'Run the specified deployment.',
    Path: '/v0/deployments/:deploymentId/bootstrap',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.bootstrapDeployment),
        payload: t.type({
            version: t.string,
            userId: t.string,
            deploymentId: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});
/* ShutdownDeployment */
var ShutdownDeploymentSchema = defineSchema({
    Namespace: Namespace$b,
    Description: 'Shut down a deployment.',
    Path: '/v0/deployments/:deploymentId/shutdown',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.shutdownDeployment),
        payload: t.type({
            version: t.string,
            userId: t.string,
            deploymentId: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});
/* Build Deployment */
var BuildDeploymentSchema = defineSchema({
    Namespace: Namespace$b,
    Description: 'Build an uploaded application on the cloud.',
    Path: '/v0/deployments/:deploymentId/upload',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.partial({
        npmRegistry: t.string,
    }),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.buildDeployment),
        payload: t.intersection([
            t.type({
                userId: t.string,
                deploymentId: t.string,
            }),
            t.partial({
                npmRegistry: t.string,
            }),
        ]),
    }),
    Result: t.type({
        installLog: t.string,
        files: t.array(t.string),
    }),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, npmRegistry = _a.npmRegistry;
        return ({
            params: { deploymentId: deploymentId },
            body: { npmRegistry: npmRegistry },
            query: {},
        });
    },
});
/* GetDeploymentUploadSignedUrl */
var GetDeploymentUploadSignedUrlSchema = defineSchema({
    Namespace: Namespace$b,
    Description: "Get URLs used to upload an application's source code and static resources.",
    Path: '/v0/deployments/:deploymentId/upload',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.getDeploymentUploadSignedUrl),
        payload: t.type({
            userId: t.string,
            deploymentId: t.string,
        }),
    }),
    Result: t.type({
        codeUploadUrl: t.string,
        staticUploadUrl: t.string,
    }),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});

var Namespace$a = 'Deployments / Domains';
/* SetDeploymentDomain */
var SetDeploymentDomainSchema = defineSchema({
    Namespace: Namespace$a,
    Description: 'Assigns a domain to a deployment.',
    Path: '/v0/deployments/:deploymentId/domain',
    Method: 'PUT',
    Mode: 'ASYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({ domain: t.string }),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.setDeploymentDomain),
        payload: t.type({
            userId: t.string,
            deploymentId: t.string,
            domain: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, domain = _a.domain;
        return ({
            params: { deploymentId: deploymentId },
            body: { domain: domain },
            query: {},
        });
    },
});
/* UnsetDeploymentDomain */
var UnsetDeploymentDomainSchema = defineSchema({
    Namespace: Namespace$a,
    Description: 'Detach a domain from a deployment.',
    Path: '/v0/deployments/:deploymentId/domain',
    Method: 'DELETE',
    Mode: 'ASYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({ domain: t.string }),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.unsetDeploymentDomain),
        payload: t.type({
            userId: t.string,
            deploymentId: t.string,
            domain: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, domain = _a.domain;
        return ({
            params: { deploymentId: deploymentId },
            body: { domain: domain },
            query: {},
        });
    },
});

/* UpdateEnvironmentVariables */
var UpdateEnvironmentVariablesSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.updateEnvironmentVariables),
        payload: t.type({
            deploymentId: t.string,
            userId: t.string,
            variables: t.record(t.string, t.union([t.string, t.null])),
        }),
    }),
    Result: t.void,
});

var Namespace$9 = 'Deployments / Environment variables';
/* SetEnvironmentVariables */
var SetEnvironmentVariablesSchema = defineSchema({
    Namespace: Namespace$9,
    Description: 'Set environment variables for a deployment.',
    Path: '/v0/deployments/:deploymentId/environment',
    Method: 'PUT',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({
        variables: t.record(t.string, t.string),
    }),
    Query: t.type({}),
    Event: UpdateEnvironmentVariablesSchema.Event,
    Result: UpdateEnvironmentVariablesSchema.Result,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, variables = _a.variables;
        return ({
            params: { deploymentId: deploymentId },
            body: { variables: variables },
            query: {},
        });
    },
});
/* RemoveEnvironmentVariables */
var RemoveEnvironmentVariablesSchema = defineSchema({
    Namespace: Namespace$9,
    Description: 'Remove environment variables.',
    Path: '/v0/deployments/:deploymentId/environment',
    Method: 'DELETE',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({
        variables: t.array(t.string),
    }),
    Query: t.type({}),
    Event: UpdateEnvironmentVariablesSchema.Event,
    Result: UpdateEnvironmentVariablesSchema.Result,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, variables = _a.variables;
        return ({
            params: { deploymentId: deploymentId },
            body: { variables: variables },
            query: {},
        });
    },
});
/* ListEnvironmentVariables */
var ListEnvironmentVariablesSchema = defineSchema({
    Namespace: Namespace$9,
    Description: "Get a list of a deployment's environment variables.",
    Path: '/v0/deployments/:deploymentId/environment',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.listEnvironmentVariables),
        payload: t.type({
            deploymentId: t.string,
            userId: t.string,
        }),
    }),
    Result: t.record(t.string, t.string),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});

var Namespace$8 = 'Deployments / Logs';
var LogLevelSchema = t.union([
    t.literal('log'),
    t.literal('error'),
    t.literal('warn'),
    t.literal('debug'),
    t.literal('info'),
    t.literal('verbose'),
]);
/* EnableLogs */
var EnableLogsSchema = defineSchema({
    Namespace: Namespace$8,
    Description: 'Enable logs for a deployment.',
    Path: '/v0/deployments/:deploymentId/logs/enable',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.partial({
        logLevel: LogLevelSchema,
        scope: t.string,
    }),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.enableLogs),
        payload: t.intersection([
            t.type({
                deploymentId: t.string,
                userId: t.string,
            }),
            t.partial({
                logLevel: LogLevelSchema,
                scope: t.string,
            }),
        ]),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, scope = _a.scope, logLevel = _a.logLevel;
        return ({
            params: { deploymentId: deploymentId },
            body: { scope: scope, logLevel: logLevel },
            query: {},
        });
    },
});
/* DisableLogs */
var DisableLogsSchema = defineSchema({
    Namespace: Namespace$8,
    Description: 'Disable logs for a deployment.',
    Path: '/v0/deployments/:deploymentId/logs/disable',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.disableLogs),
        payload: t.type({
            deploymentId: t.string,
            userId: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});
/* GetLogs */
var GetLogsSchema = defineSchema({
    Namespace: Namespace$8,
    Description: 'Get logs for a time interval.',
    Path: '/v0/deployments/:deploymentId/logs',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({}),
    Query: t.partial({
        startTime: t.string,
        endTime: t.string,
        filterPattern: t.string,
        streamLimit: t.string,
    }),
    Event: t.type({
        name: t.literal(InstallerEventNames.getLogs),
        payload: t.intersection([
            t.type({
                deploymentId: t.string,
                userId: t.string,
            }),
            t.partial({
                streamLimit: t.number,
                startTime: t.number,
                endTime: t.number,
                filterPattern: t.string,
            }),
        ]),
    }),
    Result: t.string,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, streamLimit = _a.streamLimit, startTime = _a.startTime, endTime = _a.endTime, filterPattern = _a.filterPattern;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {
                streamLimit: streamLimit,
                startTime: startTime,
                endTime: endTime,
                filterPattern: filterPattern,
            },
        });
    },
});
/* RemoveLogs */
var RemoveLogsSchema = defineSchema({
    Namespace: Namespace$8,
    Description: "Remove a deployment's logs.",
    Path: '/v0/deployments/:deploymentId/logs',
    Method: 'DELETE',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.removeLogs),
        payload: t.type({
            deploymentId: t.string,
            userId: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});

var Namespace$7 = 'Deployments / Sagas';
/* PauseSaga */
var PauseSagaSchema = defineSchema({
    Namespace: Namespace$7,
    Description: 'Pause saga updates.',
    Path: '/v0/deployments/:deploymentId/sagas/:sagaName/pause',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string, sagaName: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.pauseSaga),
        payload: t.type({
            version: t.string,
            deploymentId: t.string,
            userId: t.string,
            eventListener: t.string,
        }),
    }),
    Result: t.any,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, sagaName = _a.sagaName;
        return ({
            params: { deploymentId: deploymentId, sagaName: sagaName },
            body: {},
            query: {},
        });
    },
});
/* ResetSaga */
var ResetSagaSchema = defineSchema({
    Namespace: Namespace$7,
    Description: "Reset a saga's persistent state.",
    Path: '/v0/deployments/:deploymentId/sagas/:sagaName/reset',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string, sagaName: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.resetSaga),
        payload: t.type({
            version: t.string,
            deploymentId: t.string,
            userId: t.string,
            eventListener: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, sagaName = _a.sagaName;
        return ({
            params: { deploymentId: deploymentId, sagaName: sagaName },
            body: {},
            query: {},
        });
    },
});
/* ResumeSaga */
var ResumeSagaSchema = defineSchema({
    Namespace: Namespace$7,
    Description: 'Resume saga updates.',
    Path: '/v0/deployments/:deploymentId/sagas/:sagaName/resume',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string, sagaName: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.resumeSaga),
        payload: t.type({
            version: t.string,
            deploymentId: t.string,
            userId: t.string,
            eventListener: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, sagaName = _a.sagaName;
        return ({
            params: { deploymentId: deploymentId, sagaName: sagaName },
            body: {},
            query: {},
        });
    },
});
/* ListSagas */
var ListSagasSchema = defineSchema({
    Namespace: Namespace$7,
    Description: "Get the list of a deployment's sagas.",
    Path: '/v0/deployments/:deploymentId/sagas',
    Method: 'GET',
    Mode: 'ASYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.listSagas),
        payload: t.type({
            version: t.string,
            deploymentId: t.string,
            userId: t.string,
        }),
    }),
    Result: t.array(t.type({
        name: t.string,
        status: t.union([t.string, t.null]),
        successEvent: t.union([t.record(t.string, t.any), t.null]),
        failedEvent: t.union([t.record(t.string, t.any), t.null]),
        errors: t.array(t.type({
            name: t.string,
            message: t.string,
            stack: t.string,
        })),
    })),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});

var Namespace$6 = 'Deployments / Sagas / Properties';
/* SetSagaProperty */
var SetSagaPropertySchema = defineSchema({
    Namespace: Namespace$6,
    Description: 'Assign a value to a saga property.',
    Path: '/v0/deployments/:deploymentId/sagas/:sagaName/properties',
    Method: 'PUT',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string, sagaName: t.string }),
    Body: t.type({
        key: t.string,
        value: t.string,
    }),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.setSagaProperty),
        payload: t.type({
            version: t.string,
            deploymentId: t.string,
            userId: t.string,
            eventListener: t.string,
            key: t.string,
            value: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, sagaName = _a.sagaName, key = _a.key, value = _a.value;
        return ({
            params: { deploymentId: deploymentId, sagaName: sagaName },
            body: { key: key, value: value },
            query: {},
        });
    },
});
/* DeleteSagaProperty */
var DeleteSagaPropertySchema = defineSchema({
    Namespace: Namespace$6,
    Description: 'Delete a saga property.',
    Path: '/v0/deployments/:deploymentId/sagas/:sagaName/properties/:key',
    Method: 'DELETE',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string, sagaName: t.string, key: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.deleteSagaProperty),
        payload: t.type({
            version: t.string,
            deploymentId: t.string,
            userId: t.string,
            eventListener: t.string,
            key: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, sagaName = _a.sagaName, key = _a.key;
        return ({
            params: { deploymentId: deploymentId, sagaName: sagaName, key: key },
            body: {},
            query: {},
        });
    },
});
/* GetSagaProperty */
var GetSagaPropertySchema = defineSchema({
    Namespace: Namespace$6,
    Description: "Get a saga property's value.",
    Path: '/v0/deployments/:deploymentId/sagas/:sagaName/properties/:key',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string, sagaName: t.string, key: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.getSagaProperty),
        payload: t.type({
            version: t.string,
            deploymentId: t.string,
            userId: t.string,
            eventListener: t.string,
            key: t.string,
        }),
    }),
    Result: t.record(t.string, t.any),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, sagaName = _a.sagaName, key = _a.key;
        return ({
            params: { deploymentId: deploymentId, sagaName: sagaName, key: key },
            body: {},
            query: {},
        });
    },
});
/* ListSagaProperties */
var ListSagaPropertiesSchema = defineSchema({
    Namespace: Namespace$6,
    Description: 'Get the list of assigned saga properties.',
    Path: '/v0/deployments/:deploymentId/sagas/:sagaName/properties',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string, sagaName: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.listSagaProperties),
        payload: t.type({
            version: t.string,
            deploymentId: t.string,
            userId: t.string,
            eventListener: t.string,
        }),
    }),
    Result: t.any,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, sagaName = _a.sagaName;
        return ({
            params: { deploymentId: deploymentId, sagaName: sagaName },
            body: {},
            query: {},
        });
    },
});

var Namespace$5 = 'Deployments / Read models';
/* PauseReadModel */
var PauseReadModelSchema = defineSchema({
    Namespace: Namespace$5,
    Description: 'Pause read model updates.',
    Path: '/v0/deployments/:deploymentId/read-models/:readModelName/pause',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string, readModelName: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.pauseReadModel),
        payload: t.type({
            version: t.string,
            deploymentId: t.string,
            userId: t.string,
            eventListener: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, readModelName = _a.readModelName;
        return ({
            params: { deploymentId: deploymentId, readModelName: readModelName },
            body: {},
            query: {},
        });
    },
});
/* ResetReadModel */
var ResetReadModelSchema = defineSchema({
    Namespace: Namespace$5,
    Description: "Reset a read model's persistent state.",
    Path: '/v0/deployments/:deploymentId/read-models/:readModelName/reset',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string, readModelName: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.resetReadModel),
        payload: t.type({
            version: t.string,
            deploymentId: t.string,
            userId: t.string,
            eventListener: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, readModelName = _a.readModelName;
        return ({
            params: { deploymentId: deploymentId, readModelName: readModelName },
            body: {},
            query: {},
        });
    },
});
/* ResumeReadModel */
var ResumeReadModelSchema = defineSchema({
    Namespace: Namespace$5,
    Description: 'Resume read model updates.',
    Path: '/v0/deployments/:deploymentId/read-models/:readModelName/resume',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string, readModelName: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.resumeReadModel),
        payload: t.type({
            version: t.string,
            deploymentId: t.string,
            userId: t.string,
            eventListener: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, readModelName = _a.readModelName;
        return ({
            params: { deploymentId: deploymentId, readModelName: readModelName },
            body: {},
            query: {},
        });
    },
});
/* ListReadModels */
var ListReadModelsSchema = defineSchema({
    Namespace: Namespace$5,
    Description: "Obtain the list of a deployment's read models.",
    Path: '/v0/deployments/:deploymentId/read-models',
    Method: 'GET',
    Mode: 'ASYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.listReadModels),
        payload: t.type({
            version: t.string,
            deploymentId: t.string,
            userId: t.string,
        }),
    }),
    Result: t.array(t.type({
        name: t.string,
        status: t.union([t.string, t.null]),
        successEvent: t.union([t.record(t.string, t.any), t.null]),
        failedEvent: t.union([t.record(t.string, t.any), t.null]),
        errors: t.array(t.type({
            name: t.string,
            message: t.string,
            stack: t.string,
        })),
    })),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});
/* CreateReadModel */
var CreateReadModelSchema = defineSchema({
    Event: t.type({
        name: t.literal(FactoryEventNames.createReadModel),
        payload: t.type({
            version: t.string,
            deploymentId: t.string,
            user: RDSUserSchema,
            readModelsClusterArn: t.string,
            postgresAdminSecretArn: t.string,
            readModelsClusterEndpoint: t.string,
            readModelsClusterPort: t.number,
            postgresAdminUsername: t.string,
            postgresAdminPassword: t.string,
        }),
    }),
    Result: t.type({
        readModelDatabaseName: t.string,
    }),
});
/* DropReadModel */
var DropReadModelSchema = defineSchema({
    Event: t.type({
        name: t.literal(FactoryEventNames.dropReadModel),
        payload: t.type({
            version: t.string,
            deploymentId: t.string,
            user: RDSUserSchema,
            readModelsClusterArn: t.string,
            postgresAdminSecretArn: t.string,
            readModelsClusterEndpoint: t.string,
            readModelsClusterPort: t.number,
            postgresAdminUsername: t.string,
            postgresAdminPassword: t.string,
        }),
    }),
    Result: t.void,
});

var Namespace$4 = 'Deployments / Tracing';
/* DisableTracing */
var DisableTracingSchema = defineSchema({
    Namespace: Namespace$4,
    Description: 'Disable performance tracing for a deployment.',
    Path: '/v0/deployments/:deploymentId/tracing/disable',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.disableTracing),
        payload: t.type({
            deploymentId: t.string,
            userId: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});
/* EnableTracing */
var EnableTracingSchema = defineSchema({
    Namespace: Namespace$4,
    Description: 'Enable performance tracing for a deployment.',
    Path: '/v0/deployments/:deploymentId/tracing/enable',
    Method: 'PATCH',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.enableTracing),
        payload: t.type({
            deploymentId: t.string,
            userId: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});
/* GetSummaries */
var GetSummariesSchema = defineSchema({
    Namespace: Namespace$4,
    Description: "Get the list of a deployment's performance tracing summaries for the specified time interval.",
    Path: '/v0/deployments/:deploymentId/tracing/summary',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({}),
    Query: t.intersection([
        t.type({ startTime: t.string, endTime: t.string }),
        t.partial({ filterExpression: t.string }),
    ]),
    Event: t.type({
        name: t.literal(InstallerEventNames.getSummaries),
        payload: t.intersection([
            t.type({
                deploymentId: t.string,
                userId: t.string,
                startTime: t.number,
                endTime: t.number,
            }),
            t.partial({
                filterExpression: t.string,
            }),
        ]),
    }),
    Result: t.array(t.intersection([
        t.partial({
            id: t.string,
            responseTime: t.number,
            http: t.partial({
                httpURL: t.string,
                httpStatus: t.number,
                httpMethod: t.string,
                userAgent: t.string,
                clientIp: t.string,
            }),
        }),
        t.record(t.string, t.any),
    ])),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, startTime = _a.startTime, endTime = _a.endTime, filterExpression = _a.filterExpression;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: { startTime: startTime, endTime: endTime, filterExpression: filterExpression },
        });
    },
});
/* GetTrace */
var GetTracingDetailsSchema = defineSchema({
    Namespace: Namespace$4,
    Description: 'Get details on the specified performance trace.',
    Path: '/v0/deployments/:deploymentId/tracing/details',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({}),
    Query: t.type({
        traceIds: t.array(t.string),
    }),
    Event: t.type({
        name: t.literal(InstallerEventNames.getTracingDetails),
        payload: t.type({
            deploymentId: t.string,
            userId: t.string,
            traceIds: t.array(t.string),
        }),
    }),
    Result: t.array(t.record(t.string, t.any)),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId, traceIds = _a.traceIds;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: { traceIds: traceIds },
        });
    },
});
/* GetTracing */
var GetTracingStatusSchema = defineSchema({
    Namespace: Namespace$4,
    Description: 'Check whether performance tracing is enabled for a deployment.',
    Path: '/v0/deployments/:deploymentId/tracing/status',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({ deploymentId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.getTracingStatus),
        payload: t.type({
            deploymentId: t.string,
            userId: t.string,
        }),
    }),
    Result: t.union([t.literal('enabled'), t.literal('disabled')]),
    ArgumentsTransformer: function (_a) {
        var deploymentId = _a.deploymentId;
        return ({
            params: { deploymentId: deploymentId },
            body: {},
            query: {},
        });
    },
});

var Namespace$3 = 'Event stores';
/* CreateEventStore */
var CreateEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Create a new event store.',
    Path: '/v0/event-stores',
    Method: 'POST',
    Mode: 'ASYNC',
    Params: t.type({}),
    Body: t.type({
        version: t.string,
    }),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.createEventStore),
        payload: t.type({
            version: t.string,
            user: RDSUserSchema,
            eventStoreClusterArn: t.string,
            postgresAdminSecretArn: t.string,
            eventStoreClusterEndpoint: t.string,
            eventStoreClusterPort: t.number,
            postgresAdminUsername: t.string,
            postgresAdminPassword: t.string,
        }),
    }),
    Result: t.type({
        eventStoreId: t.string,
    }),
    ArgumentsTransformer: function (_a) {
        var version = _a.version;
        return ({
            params: {},
            body: { version: version },
            query: {},
        });
    },
});
/* DropEventStore */
var DropEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Remove an existing event store.',
    Path: '/v0/event-stores/:eventStoreId',
    Method: 'DELETE',
    Mode: 'ASYNC',
    Params: t.type({ eventStoreId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.dropEventStore),
        payload: t.type({
            version: t.string,
            user: RDSUserSchema,
            eventStoreId: t.string,
            eventStoreClusterArn: t.string,
            postgresAdminSecretArn: t.string,
            eventStoreClusterEndpoint: t.string,
            eventStoreClusterPort: t.number,
            postgresAdminUsername: t.string,
            postgresAdminPassword: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: {},
            query: {},
        });
    },
});
/* GetEventStore */
var GetEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Get information about the specified event store.',
    Path: '/v0/event-stores/:eventStoreId',
    Method: 'GET',
    Mode: 'ASYNC',
    Params: t.type({ eventStoreId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.getEventStore),
        payload: t.type({
            user: RDSUserSchema,
            eventStoreId: t.string,
            eventStoreClusterArn: t.string,
            postgresAdminSecretArn: t.string,
            eventStoreClusterEndpoint: t.string,
            eventStoreClusterPort: t.number,
            postgresAdminUsername: t.string,
            postgresAdminPassword: t.string,
        }),
    }),
    Result: t.type({
        eventStoreClusterArn: t.string,
        eventStoreSecretArn: t.string,
        eventStoreDatabaseName: t.string,
        version: t.string,
        eventStoreId: t.string,
        linkedDeployments: t.array(t.string),
        region: t.string,
        accessKeyId: t.string,
        secretAccessKey: t.string,
        sessionToken: t.string,
    }),
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: {},
            query: {},
        });
    },
});
/* ListEventStores */
var ListEventStoresSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Get a list of objects that describe available event stores.',
    Path: '/v0/event-stores',
    Method: 'GET',
    Mode: 'ASYNC',
    Params: t.type({}),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.listEventStores),
        payload: t.type({
            user: RDSUserSchema,
            eventStoreClusterArn: t.string,
            postgresAdminSecretArn: t.string,
            eventStoreClusterEndpoint: t.string,
            eventStoreClusterPort: t.number,
            postgresAdminUsername: t.string,
            postgresAdminPassword: t.string,
        }),
    }),
    Result: t.array(t.type({
        version: t.string,
        eventStoreId: t.string,
        linkedDeployments: t.array(t.string),
        eventStoreDatabaseName: t.string,
        events: t.union([t.number, t.null]),
        secrets: t.union([t.number, t.null]),
        modifiedAt: t.union([t.number, t.null]),
        createdAt: t.union([t.number, t.null]),
        isFrozen: t.union([t.boolean, t.null]),
    })),
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});
/* CloneEventStore */
var CloneEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Create a new event store based on the specified event store.',
    Path: '/v0/event-stores/:eventStoreId/clone',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t.type({ eventStoreId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.cloneEventStore),
        payload: t.type({
            version: t.string,
            user: RDSUserSchema,
            eventStoreClusterArn: t.string,
            postgresAdminSecretArn: t.string,
            eventStoreId: t.string,
            eventStoreClusterEndpoint: t.string,
            eventStoreClusterPort: t.number,
            postgresAdminUsername: t.string,
            postgresAdminPassword: t.string,
        }),
    }),
    Result: t.type({
        eventStoreId: t.string,
        eventStoreDatabaseName: t.string,
    }),
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: {},
            query: {},
        });
    },
});
/* ClearEventStore */
var ClearEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Remove all events from an event store.',
    Path: '/v0/event-stores/:eventStoreId/clear',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t.type({ eventStoreId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.clearEventStore),
        payload: t.type({
            version: t.string,
            user: RDSUserSchema,
            eventStoreId: t.string,
            eventStoreClusterArn: t.string,
            postgresAdminSecretArn: t.string,
            eventStoreClusterEndpoint: t.string,
            eventStoreClusterPort: t.number,
            postgresAdminUsername: t.string,
            postgresAdminPassword: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: {},
            query: {},
        });
    },
});
/* FreezeEventStore */
var FreezeEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Disable event store updates.',
    Path: '/v0/event-stores/:eventStoreId/freeze',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t.type({ eventStoreId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.freezeEventStore),
        payload: t.type({
            version: t.string,
            user: RDSUserSchema,
            eventStoreId: t.string,
            eventStoreClusterArn: t.string,
            postgresAdminSecretArn: t.string,
            eventStoreClusterEndpoint: t.string,
            eventStoreClusterPort: t.number,
            postgresAdminUsername: t.string,
            postgresAdminPassword: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: {},
            query: {},
        });
    },
});
/* UnfreezeEventStore */
var UnfreezeEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Resume event store updates.',
    Path: '/v0/event-stores/:eventStoreId/unfreeze',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t.type({ eventStoreId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.unfreezeEventStore),
        payload: t.type({
            version: t.string,
            user: RDSUserSchema,
            eventStoreId: t.string,
            eventStoreClusterArn: t.string,
            postgresAdminSecretArn: t.string,
            eventStoreClusterEndpoint: t.string,
            eventStoreClusterPort: t.number,
            postgresAdminUsername: t.string,
            postgresAdminPassword: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: {},
            query: {},
        });
    },
});
/* LinkDeployment */
var LinkDeploymentSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Connect an existing application deployment to the specified event store.',
    Path: '/v0/event-stores/:eventStoreId/link',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t.type({ eventStoreId: t.string }),
    Body: t.type({ deploymentId: t.string }),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.linkDeployment),
        payload: t.type({
            version: t.string,
            user: RDSUserSchema,
            eventStoreClusterArn: t.string,
            postgresAdminSecretArn: t.string,
            eventStoreId: t.string,
            deploymentId: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId, deploymentId = _a.deploymentId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: { deploymentId: deploymentId },
            query: {},
        });
    },
});
/* UnlinkDeployment */
var UnlinkDeploymentSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Disconnect an application deployment from the specified event store.',
    Path: '/v0/event-stores/:eventStoreId/unlink',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t.type({ eventStoreId: t.string }),
    Body: t.type({ deploymentId: t.string }),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.unlinkDeployment),
        payload: t.type({
            version: t.string,
            user: RDSUserSchema,
            eventStoreClusterArn: t.string,
            postgresAdminSecretArn: t.string,
            eventStoreId: t.string,
            deploymentId: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId, deploymentId = _a.deploymentId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: { deploymentId: deploymentId },
            query: {},
        });
    },
});
/* ImportEventStore */
var ImportEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Import events into the specified event store.',
    Path: '/v0/event-stores/:eventStoreId/import',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t.type({ eventStoreId: t.string }),
    Body: t.type({ partIndex: t.number }),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.importEventStore),
        payload: t.type({
            version: t.string,
            user: RDSUserSchema,
            eventStoreId: t.string,
            eventStoreDatabaseName: t.string,
            eventStoreClusterEndpoint: t.string,
            eventStoreClusterPort: t.number,
            bucketName: t.string,
            partIndex: t.number,
            accessKeyId: t.string,
            secretAccessKey: t.string,
            sessionToken: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId, partIndex = _a.partIndex;
        return ({
            params: { eventStoreId: eventStoreId },
            body: { partIndex: partIndex },
            query: {},
        });
    },
});
/* ExportEventStore */
var ExportEventStoreSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Export events from the specified event store.',
    Path: '/v0/event-stores/:eventStoreId/export',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t.type({ eventStoreId: t.string }),
    Body: t.type({}),
    Query: t.partial({ cursor: t.string }),
    Event: t.type({
        name: t.literal(FactoryEventNames.exportEventStore),
        payload: t.intersection([
            t.type({
                version: t.string,
                user: RDSUserSchema,
                eventStoreId: t.string,
                eventStoreDatabaseName: t.string,
                eventStoreClusterEndpoint: t.string,
                eventStoreClusterPort: t.number,
                bucketName: t.string,
                importExportStepFunctionArn: t.string,
            }),
            t.partial({
                cursor: t.string,
            }),
        ]),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId, cursor = _a.cursor;
        return ({
            params: { eventStoreId: eventStoreId },
            body: {},
            query: { cursor: cursor },
        });
    },
});
/* GetImportUrls */
var GetImportUrlsSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Get URLs used to upload files that contain events and secrets to import.',
    Path: '/v0/event-stores/:eventStoreId/import',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({ eventStoreId: t.string }),
    Body: t.type({}),
    Query: t.type({ eventsPartCount: t.string, secretsPartCount: t.string }),
    Event: t.type({
        name: t.literal(FactoryEventNames.getImportUrls),
        payload: t.type({
            version: t.string,
            userId: t.string,
            eventStoreId: t.string,
            bucketName: t.string,
            eventsPartCount: t.number,
            secretsPartCount: t.number,
        }),
    }),
    Result: t.type({
        eventsImportUrls: t.array(t.string),
        secretsImportUrls: t.array(t.string),
    }),
    ArgumentsTransformer: (function (args) { return ({
        params: { eventStoreId: args.eventStoreId },
        body: {},
        query: {
            eventsPartCount: "".concat(args.eventsPartCount),
            secretsPartCount: "".concat(args.secretsPartCount),
        },
    }); }),
});
/* GetExportUrls */
var GetExportUrlsSchema = defineSchema({
    Namespace: Namespace$3,
    Description: 'Get URLs used to download files that contain events and secrets to import as well as a file that contains information about the status of the export process.',
    Path: '/v0/event-stores/:eventStoreId/export',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({ eventStoreId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(FactoryEventNames.getExportUrls),
        payload: t.type({
            version: t.string,
            userId: t.string,
            eventStoreId: t.string,
            bucketName: t.string,
        }),
    }),
    Result: t.type({
        eventsExportUrl: t.string,
        secretsExportUrl: t.string,
        statusFileUrl: t.string,
    }),
    ArgumentsTransformer: function (_a) {
        var eventStoreId = _a.eventStoreId;
        return ({
            params: { eventStoreId: eventStoreId },
            body: {},
            query: {},
        });
    },
});

var Namespace$2 = 'Certificates';
/* EnsureCertificate */
var EnsureCertificateSchema = defineSchema({
    Namespace: Namespace$2,
    Description: "Check an SSL certificate's validity.",
    Path: '/v0/certificates',
    Method: 'PUT',
    Mode: 'ASYNC',
    Params: t.type({}),
    Body: t.intersection([
        t.type({
            certificate: t.string,
            key: t.string,
        }),
        t.partial({
            certificateId: t.string,
            chain: t.string,
        }),
    ]),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.ensureCertificate),
        payload: t.intersection([
            t.type({
                userId: t.string,
                certificate: t.string,
                key: t.string,
            }),
            t.partial({
                certificateId: t.string,
                chain: t.string,
            }),
        ]),
    }),
    Result: t.string,
    ArgumentsTransformer: function (_a) {
        var certificateId = _a.certificateId, certificate = _a.certificate, key = _a.key, chain = _a.chain;
        return ({
            params: {},
            body: { certificateId: certificateId, certificate: certificate, key: key, chain: chain },
            query: {},
        });
    },
});
/* DropCertificate */
var DropCertificateSchema = defineSchema({
    Namespace: Namespace$2,
    Description: 'Remove the specified certificate.',
    Path: '/v0/certificates/:certificateId',
    Method: 'DELETE',
    Mode: 'ASYNC',
    Params: t.type({ certificateId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.dropCertificate),
        payload: t.type({
            userId: t.string,
            certificateId: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var certificateId = _a.certificateId;
        return ({
            params: { certificateId: certificateId },
            body: {},
            query: {},
        });
    },
});
/* ListCertificates */
var ListCertificatesSchema = defineSchema({
    Namespace: Namespace$2,
    Description: 'Get a list of the available SSL certificates.',
    Path: '/v0/certificates',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({}),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.listCertificates),
        payload: t.type({
            userId: t.string,
        }),
    }),
    Result: t.array(CertificateSchema),
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});

var Namespace$1 = 'Domains';
/* CreateDomain */
var CreateDomainSchema = defineSchema({
    Namespace: Namespace$1,
    Description: 'Create a new domain with the specified certificate based on a list of aliases.',
    Path: '/v0/domains',
    Method: 'POST',
    Mode: 'ASYNC',
    Params: t.type({}),
    Body: t.intersection([
        t.type({
            certificateId: t.string,
            aliases: t.array(t.string),
        }),
        t.partial({
            domainId: t.string,
        }),
    ]),
    Query: t.type({}),
    Event: t.type({
        name: t.union([
            t.literal(InstallerEventNames.createStaticDomain),
            t.literal(InstallerEventNames.createProxyDomain),
            t.literal(InstallerEventNames.createUploaderDomain),
        ]),
        payload: t.intersection([
            t.type({
                userId: t.string,
                certificateId: t.string,
            }),
            t.partial({
                aliases: t.array(t.string),
                domainId: t.string,
                customName: t.string,
                users: t.union([t.literal('*'), t.array(t.string)]),
                verification: t.boolean,
            }),
        ]),
    }),
    Result: DomainSchema,
    ArgumentsTransformer: function (_a) {
        var certificateId = _a.certificateId, aliases = _a.aliases, domainId = _a.domainId;
        return ({
            params: {},
            body: { certificateId: certificateId, aliases: aliases, domainId: domainId },
            query: {},
        });
    },
});
/* DropDomain */
var DropDomainSchema = defineSchema({
    Namespace: Namespace$1,
    Description: 'Remove the specified domain.',
    Path: '/v0/domains/:domainId',
    Method: 'DELETE',
    Mode: 'ASYNC',
    Params: t.type({ domainId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.dropDomain),
        payload: t.type({
            userId: t.string,
            domainId: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var domainId = _a.domainId;
        return ({
            params: { domainId: domainId },
            body: {},
            query: {},
        });
    },
});
/* ReleaseDomain */
var ReleaseDomainSchema = defineSchema({
    Namespace: Namespace$1,
    Description: 'Release a domain from the associated application deployments.',
    Path: '/v0/domains',
    Method: 'DELETE',
    Mode: 'ASYNC',
    Params: t.type({}),
    Body: t.type({ domain: t.string }),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.releaseDomain),
        payload: t.type({
            userId: t.string,
            domain: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var domain = _a.domain;
        return ({
            params: {},
            body: { domain: domain },
            query: {},
        });
    },
});
/* ListDomains */
var ListDomainsSchema = defineSchema({
    Namespace: Namespace$1,
    Description: 'Get a list of the available domains.',
    Path: '/v0/domains',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({}),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.listDomains),
        payload: t.intersection([
            t.type({
                userId: t.string,
            }),
            t.partial({
                domain: t.string,
            }),
        ]),
    }),
    Result: t.array(DomainSchema),
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});
/* VerifyDomain */
var VerifyDomainSchema = defineSchema({
    Namespace: Namespace$1,
    Description: 'Verify a domain after a verification record was added to the domain zone.',
    Path: '/v0/domains/:domainId/verify',
    Method: 'PATCH',
    Mode: 'ASYNC',
    Params: t.type({
        domainId: t.string,
    }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.verifyDomain),
        payload: t.type({
            userId: t.string,
            domainId: t.string,
        }),
    }),
    Result: t.void,
    ArgumentsTransformer: function (_a) {
        var domainId = _a.domainId;
        return ({
            params: { domainId: domainId },
            body: {},
            query: {},
        });
    },
});
/* GetVerificationCode */
var GetVerificationCodeSchema = defineSchema({
    Namespace: Namespace$1,
    Description: 'Get a code to add to a verification record within your domain zone.',
    Path: '/v0/domains/:domainId/verification-code',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({ domainId: t.string }),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.getVerificationCode),
        payload: t.type({
            userId: t.string,
            domainId: t.string,
        }),
    }),
    Result: t.type({
        verificationCode: t.string,
    }),
    ArgumentsTransformer: function (_a) {
        var domainId = _a.domainId;
        return ({
            params: { domainId: domainId },
            body: {},
            query: {},
        });
    },
});

var getApiRouteUrl = function (baseUrl, pathname) {
    var url = baseUrl;
    if (/\/$/.test(url)) {
        url = url.substr(0, url.length - 1);
    }
    if (/^\//.test(pathname)) {
        url += pathname;
    }
    else {
        url += "/".concat(pathname);
    }
    return url;
};

var getResponseMethod = function (contentType) {
    var responseMethod = contentType != null &&
        contentType
            .split(';')
            .map(function (item) { return item.trim(); })
            .find(function (item) { return item === 'application/json'; })
        ? 'json'
        : 'text';
    return responseMethod;
};

var request = function (params) { return __awaiter(void 0, void 0, void 0, function () {
    var baseHeaders, baseUrl, fetch, _a, logger, path, query, body, method, token, _b, customHeaders, _c, retryTimeout, _d, mode, headers, startTime, executeRequest, describeRequest, apiRequest;
    return __generator(this, function (_e) {
        switch (_e.label) {
            case 0:
                baseHeaders = params.baseHeaders, baseUrl = params.baseUrl, fetch = params.fetch, _a = params.logger, logger = _a === void 0 ? {
                    debug: function () { },
                    trace: function () { },
                    log: function () { },
                } : _a, path = params.path, query = params.query, body = params.body, method = params.method, token = params.token, _b = params.headers, customHeaders = _b === void 0 ? {} : _b, _c = params.retryTimeout, retryTimeout = _c === void 0 ? 15 * 60 * 1000 : _c, _d = params.mode, mode = _d === void 0 ? 'SYNC' : _d;
                headers = __assign(__assign({}, baseHeaders), customHeaders);
                if (token != null) {
                    headers.Authorization = "Bearer ".concat(token);
                }
                headers[HEADER_EXECUTION_MODE] = mode === 'ASYNC' ? 'async' : 'sync';
                if (fetch == null) {
                    throw new Error('Fetch is not defined');
                }
                if (baseUrl == null) {
                    throw new Error('BaseUrl is not defined');
                }
                startTime = Date.now();
                executeRequest = function (req, options) { return __awaiter(void 0, void 0, void 0, function () {
                    var result, error_1, errorText, timeLeft;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                _a.trys.push([0, 2, , 7]);
                                return [4 /*yield*/, req(options)];
                            case 1:
                                result = _a.sent();
                                if (mode === 'SYNC' || result !== 'running') {
                                    return [2 /*return*/, result];
                                }
                                return [3 /*break*/, 7];
                            case 2:
                                error_1 = _a.sent();
                                errorText = "".concat(error_1);
                                timeLeft = retryTimeout - (Date.now() - startTime);
                                if (!(timeLeft <= 0)) return [3 /*break*/, 3];
                                logger.debug("Task timed out");
                                throw error_1;
                            case 3:
                                if (!isRetryable({ baseUrl: baseUrl, method: method, errorText: errorText })) return [3 /*break*/, 5];
                                logger.debug("Retrying... ".concat(Math.round(timeLeft / 1000), " seconds left"));
                                return [4 /*yield*/, new Promise(function (resolve) { return setTimeout(resolve, 1000); })];
                            case 4:
                                _a.sent();
                                return [3 /*break*/, 6];
                            case 5: throw error_1;
                            case 6: return [3 /*break*/, 7];
                            case 7: return [3 /*break*/, 0];
                            case 8: return [2 /*return*/];
                        }
                    });
                }); };
                describeRequest = function (data) { return __awaiter(void 0, void 0, void 0, function () {
                    var executionId, describePath, _a, _b, describeHeaders, describeExecutionResponse, describeExecutionResponseMethod, describeExecutionData, executionStatus, Output, error, _c;
                    var _d, _e;
                    return __generator(this, function (_f) {
                        switch (_f.label) {
                            case 0:
                                executionId = data.executionId;
                                describePath = "/v0/describe-execution/".concat(executionId);
                                _a = headers, _b = HEADER_EXECUTION_MODE, describeHeaders = __rest(_a, [typeof _b === "symbol" ? _b : _b + ""]);
                                return [4 /*yield*/, fetch(getApiRouteUrl(baseUrl, describePath), __assign({ method: 'GET', credentials: 'same-origin' }, (describeHeaders == null || Object.keys(describeHeaders).length === 0
                                        ? {}
                                        : { headers: describeHeaders })))];
                            case 1:
                                describeExecutionResponse = _f.sent();
                                describeExecutionResponseMethod = getResponseMethod(describeExecutionResponse.headers.get('Content-Type'));
                                return [4 /*yield*/, describeExecutionResponse[describeExecutionResponseMethod]()];
                            case 2:
                                describeExecutionData = _f.sent();
                                if (!(describeExecutionResponse.status >= 200 && describeExecutionResponse.status < 300)) {
                                    throw new Error(describeExecutionData);
                                }
                                if ("".concat(describeExecutionData).includes("<?xml version=\"1.0\" encoding=\"UTF-8\"?>")) {
                                    throw new Error(data);
                                }
                                executionStatus = (_d = describeExecutionData === null || describeExecutionData === void 0 ? void 0 : describeExecutionData.result) === null || _d === void 0 ? void 0 : _d.status;
                                Output = (_e = describeExecutionData === null || describeExecutionData === void 0 ? void 0 : describeExecutionData.result) === null || _e === void 0 ? void 0 : _e.output;
                                logger.trace(">> [".concat(executionStatus, "] ").concat(method, ": https://").concat(headers.Host).concat(describePath));
                                if ((Output === null || Output === void 0 ? void 0 : Output.errorType) != null && (Output === null || Output === void 0 ? void 0 : Output.errorMessage) != null && (Output === null || Output === void 0 ? void 0 : Output.trace) != null) {
                                    error = new Error();
                                    error.name = Output.errorType;
                                    error.message = Output.errorMessage;
                                    error.stack = Output.trace.join('\n');
                                    throw error;
                                }
                                _c = executionStatus;
                                switch (_c) {
                                    case 'SUCCEEDED': return [3 /*break*/, 3];
                                    case 'RUNNING': return [3 /*break*/, 4];
                                }
                                return [3 /*break*/, 6];
                            case 3:
                                {
                                    return [2 /*return*/, Output];
                                }
                            case 4:
                                logger.debug('Execution status "RUNNING". Retrying...');
                                return [4 /*yield*/, new Promise(function (resolve) { return setTimeout(resolve, 3000); })];
                            case 5:
                                _f.sent();
                                return [2 /*return*/, 'running'];
                            case 6:
                                {
                                    return [2 /*return*/, Promise.reject(new Error("Command has been completed with status \"".concat(executionStatus, "\"")))];
                                }
                            case 7: return [2 /*return*/];
                        }
                    });
                }); };
                apiRequest = function () { return __awaiter(void 0, void 0, void 0, function () {
                    var response, responseMethod, data, result, describeResult;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0:
                                logger.trace("< [".concat(mode, "] ").concat(method, ": https://").concat(headers.Host).concat(path));
                                return [4 /*yield*/, fetch("".concat(getApiRouteUrl(baseUrl, path)).concat(query == null || Object.keys(query).length === 0
                                        ? ''
                                        : "?".concat(stringify(query, { arrayFormat: 'bracket' }))), __assign(__assign({ method: method, credentials: 'same-origin' }, (body == null || Object.keys(body).length === 0 ? {} : { body: JSON.stringify(body) })), (headers == null || Object.keys(headers).length === 0 ? {} : { headers: headers })))];
                            case 1:
                                response = _a.sent();
                                responseMethod = getResponseMethod(response.headers.get('Content-Type'));
                                return [4 /*yield*/, response[responseMethod]()];
                            case 2:
                                data = _a.sent();
                                if (!(response.status >= 200 && response.status < 300)) {
                                    logger.trace("> [".concat(response.status, "] ").concat(method, ": https://").concat(headers.Host).concat(path));
                                    throw new Error(data);
                                }
                                if (!(responseMethod === 'json')) return [3 /*break*/, 6];
                                result = data.result;
                                if (!(mode === 'SYNC')) return [3 /*break*/, 3];
                                logger.trace("> [".concat(response.status, "] ").concat(method, ": https://").concat(headers.Host).concat(path));
                                return [2 /*return*/, result];
                            case 3: return [4 /*yield*/, executeRequest(describeRequest, data)];
                            case 4:
                                describeResult = _a.sent();
                                logger.trace("> [".concat(response.status, "] ").concat(method, ": https://").concat(headers.Host).concat(path));
                                return [2 /*return*/, describeResult];
                            case 5: return [3 /*break*/, 7];
                            case 6:
                                logger.trace("> [".concat(response.status, "] ").concat(method, ": https://").concat(headers.Host).concat(path));
                                if ("".concat(data).includes("<?xml version=\"1.0\" encoding=\"UTF-8\"?>")) {
                                    throw new Error(data);
                                }
                                return [2 /*return*/, data];
                            case 7: return [2 /*return*/];
                        }
                    });
                }); };
                return [4 /*yield*/, executeRequest(apiRequest)];
            case 1: return [2 /*return*/, _e.sent()];
        }
    });
}); };

var formatPath = function (urlPattern, params) {
    var _a;
    var result = urlPattern;
    var urlKeys = (_a = urlPattern.match(/:[a-z0-9-]+/gi)) !== null && _a !== void 0 ? _a : [];
    if (urlKeys.length !== Object.keys(params).length) {
        throw new Error("The params \"".concat(JSON.stringify(params), "\" does not match a pattern \"").concat(urlPattern, "\""));
    }
    for (var _i = 0, urlKeys_1 = urlKeys; _i < urlKeys_1.length; _i++) {
        var urlKey = urlKeys_1[_i];
        var paramKey = urlKey.replace(/^:/, '');
        var paramValue = params[paramKey];
        if (paramValue == null) {
            throw new Error("The parameter \"".concat(paramKey, " is required\""));
        }
        result = result.replace(urlKey, paramValue);
    }
    return result;
};

var createCloudSdk = function () {
    var options = {};
    var createCloudSDKMethod = function (schema) {
        return function (args) { return __awaiter(void 0, void 0, void 0, function () {
            var transformedArgs, params, query, body, result;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        transformedArgs = schema.ArgumentsTransformer(args !== null && args !== void 0 ? args : {});
                        params = validate(schema.Params, transformedArgs.params);
                        query = validate(schema.Query, transformedArgs.query);
                        body = validate(schema.Body, transformedArgs.body);
                        return [4 /*yield*/, request(__assign({ mode: schema.Mode, method: schema.Method, path: formatPath(schema.Path, params), body: body, query: query }, options))];
                    case 1:
                        result = _a.sent();
                        return [2 /*return*/, result];
                }
            });
        }); };
    };
    return {
        /* Setup */
        setup: function (params) {
            options = params;
        },
        /* System */
        heartbeat: function (args) {
            return __awaiter(this, void 0, void 0, function () {
                var params, query, body;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            params = validate(HeartbeatSchema.Params, {});
                            query = validate(HeartbeatSchema.Query, {});
                            body = validate(HeartbeatSchema.Body, {});
                            return [4 /*yield*/, request(__assign({ mode: HeartbeatSchema.Mode, method: HeartbeatSchema.Method, path: formatPath(HeartbeatSchema.Path, params), body: body, query: query }, options))];
                        case 1:
                            _a.sent();
                            return [2 /*return*/];
                    }
                });
            });
        },
        getDeploymentByApplicationName: function (args) {
            return __awaiter(this, void 0, void 0, function () {
                var params, query, body, deployments, deployment;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            params = validate(ListDeploymentsSchema.Params, {});
                            query = validate(ListDeploymentsSchema.Query, {
                                applicationName: args.applicationName,
                            });
                            body = validate(ListDeploymentsSchema.Body, {});
                            return [4 /*yield*/, request(__assign({ mode: ListDeploymentsSchema.Mode, method: ListDeploymentsSchema.Method, path: formatPath(ListDeploymentsSchema.Path, params), body: body, query: query }, options))];
                        case 1:
                            deployments = _a.sent();
                            if (deployments.length > 1) {
                                throw new FatalError("Duplicate applicationName = \"".concat(args.applicationName, "\""));
                            }
                            deployment = deployments[0];
                            return [2 /*return*/, deployment !== null && deployment !== void 0 ? deployment : null];
                    }
                });
            });
        },
        getClientAppConfig: createCloudSDKMethod(GetClientAppConfigSchema),
        listVersions: createCloudSDKMethod(ListVersionsSchema),
        /* Deployments */
        createDeployment: createCloudSDKMethod(CreateDeploymentSchema),
        dropDeployment: createCloudSDKMethod(DropDeploymentSchema),
        describeDeployment: createCloudSDKMethod(DescribeDeploymentSchema),
        // listDeployments: createCloudSDKMethod(ListDeploymentsSchema),
        listDeployments: function (args) {
            return __awaiter(this, void 0, void 0, function () {
                var params, query, body, result;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            params = validate(ListDeploymentsSchema.Params, {});
                            query = validate(ListDeploymentsSchema.Query, {});
                            body = validate(ListDeploymentsSchema.Body, {});
                            return [4 /*yield*/, request(__assign({ mode: ListDeploymentsSchema.Mode, method: ListDeploymentsSchema.Method, path: formatPath(ListDeploymentsSchema.Path, params), body: body, query: query }, options))];
                        case 1:
                            result = _a.sent();
                            return [2 /*return*/, result];
                    }
                });
            });
        },
        bootstrapDeployment: createCloudSDKMethod(BootstrapDeploymentSchema),
        shutdownDeployment: createCloudSDKMethod(ShutdownDeploymentSchema),
        buildDeployment: createCloudSDKMethod(BuildDeploymentSchema),
        getDeploymentUploadSignedUrl: createCloudSDKMethod(GetDeploymentUploadSignedUrlSchema),
        setDeploymentDomain: createCloudSDKMethod(SetDeploymentDomainSchema),
        unsetDeploymentDomain: createCloudSDKMethod(UnsetDeploymentDomainSchema),
        /* Link/unlink EventStore <-> Deployment */
        linkDeployment: createCloudSDKMethod(LinkDeploymentSchema),
        unlinkDeployment: createCloudSDKMethod(UnlinkDeploymentSchema),
        /* EnvironmentVariables */
        listEnvironmentVariables: createCloudSDKMethod(ListEnvironmentVariablesSchema),
        removeEnvironmentVariables: createCloudSDKMethod(RemoveEnvironmentVariablesSchema),
        setEnvironmentVariables: createCloudSDKMethod(SetEnvironmentVariablesSchema),
        /* Logs */
        disableLogs: createCloudSDKMethod(DisableLogsSchema),
        enableLogs: createCloudSDKMethod(EnableLogsSchema),
        // getLogs: createCloudSDKMethod(GetLogsSchema),
        getLogs: function (args) {
            return __awaiter(this, void 0, void 0, function () {
                var params, query, body, result;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            params = validate(GetLogsSchema.Params, {
                                deploymentId: args.deploymentId,
                            });
                            query = validate(GetLogsSchema.Query, {
                                streamLimit: args.streamLimit == null ? args.streamLimit : undefined,
                                startTime: args.startTime == null ? args.startTime : undefined,
                                endTime: args.endTime == null ? args.endTime : undefined,
                                filterPattern: args.filterPattern == null ? args.filterPattern : undefined,
                            });
                            body = validate(GetLogsSchema.Body, {});
                            return [4 /*yield*/, request(__assign({ mode: GetLogsSchema.Mode, method: GetLogsSchema.Method, path: formatPath(GetLogsSchema.Path, params), body: body, query: query }, options))];
                        case 1:
                            result = _a.sent();
                            return [2 /*return*/, result];
                    }
                });
            });
        },
        removeLogs: createCloudSDKMethod(RemoveLogsSchema),
        /* Sagas */
        listSagas: createCloudSDKMethod(ListSagasSchema),
        pauseSaga: createCloudSDKMethod(PauseSagaSchema),
        resetSaga: createCloudSDKMethod(ResetSagaSchema),
        resumeSaga: createCloudSDKMethod(ResumeSagaSchema),
        listSagaProperties: createCloudSDKMethod(ListSagaPropertiesSchema),
        setSagaProperty: createCloudSDKMethod(SetSagaPropertySchema),
        getSagaProperty: createCloudSDKMethod(GetSagaPropertySchema),
        deleteSagaProperty: createCloudSDKMethod(DeleteSagaPropertySchema),
        /* ReadModels */
        listReadModels: createCloudSDKMethod(ListReadModelsSchema),
        pauseReadModel: createCloudSDKMethod(PauseReadModelSchema),
        resetReadModel: createCloudSDKMethod(ResetReadModelSchema),
        resumeReadModel: createCloudSDKMethod(ResumeReadModelSchema),
        /* Tracing */
        getTracingDetails: createCloudSDKMethod(GetTracingDetailsSchema),
        getTracingStatus: createCloudSDKMethod(GetTracingStatusSchema),
        getSummaries: createCloudSDKMethod(GetSummariesSchema),
        enableTracing: createCloudSDKMethod(EnableTracingSchema),
        disableTracing: createCloudSDKMethod(DisableTracingSchema),
        /* EventStores */
        listEventStores: createCloudSDKMethod(ListEventStoresSchema),
        cloneEventStore: createCloudSDKMethod(CloneEventStoreSchema),
        createEventStore: createCloudSDKMethod(CreateEventStoreSchema),
        dropEventStore: createCloudSDKMethod(DropEventStoreSchema),
        getEventStore: createCloudSDKMethod(GetEventStoreSchema),
        clearEventStore: createCloudSDKMethod(ClearEventStoreSchema),
        freezeEventStore: createCloudSDKMethod(FreezeEventStoreSchema),
        unfreezeEventStore: createCloudSDKMethod(UnfreezeEventStoreSchema),
        exportEvents: createCloudSDKMethod(ExportEventStoreSchema),
        importEvents: createCloudSDKMethod(ImportEventStoreSchema),
        getExportUrls: createCloudSDKMethod(GetExportUrlsSchema),
        // getImportUrls: createCloudSDKMethod(GetImportUrlsSchema),
        getImportUrls: function (args) {
            return __awaiter(this, void 0, void 0, function () {
                var params, query, body, result;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            params = validate(GetImportUrlsSchema.Params, {
                                eventStoreId: args.eventStoreId,
                            });
                            query = validate(GetImportUrlsSchema.Query, {
                                eventsPartCount: "".concat(args.eventsPartCount),
                                secretsPartCount: "".concat(args.secretsPartCount),
                            });
                            body = validate(GetImportUrlsSchema.Body, {});
                            return [4 /*yield*/, request(__assign({ mode: GetImportUrlsSchema.Mode, method: GetImportUrlsSchema.Method, path: formatPath(GetImportUrlsSchema.Path, params), body: body, query: query }, options))];
                        case 1:
                            result = _a.sent();
                            return [2 /*return*/, result];
                    }
                });
            });
        },
        /* Certificates */
        listCertificates: createCloudSDKMethod(ListCertificatesSchema),
        dropCertificate: createCloudSDKMethod(DropCertificateSchema),
        ensureCertificate: createCloudSDKMethod(EnsureCertificateSchema),
        /* Domains */
        createDomain: createCloudSDKMethod(CreateDomainSchema),
        dropDomain: createCloudSDKMethod(DropDomainSchema),
        getVerificationCode: createCloudSDKMethod(GetVerificationCodeSchema),
        listDomains: createCloudSDKMethod(ListDomainsSchema),
        verifyDomain: createCloudSDKMethod(VerifyDomainSchema),
        releaseDomain: createCloudSDKMethod(ReleaseDomainSchema),
    };
};

/* BuildCode */
var BuildCodeSchema = defineSchema({
    Event: t.type({
        name: t.literal(BuilderEventNames.buildCode),
        payload: t.intersection([
            t.type({
                region: t.string,
                bucketName: t.string,
                userId: t.string,
                inputFileKey: t.string,
                outputFileKey: t.string,
            }),
            t.partial({
                npmRegistry: t.string,
            }),
        ]),
    }),
    Result: t.intersection([
        t.type({
            installLog: t.string,
            version: t.string,
        }),
        t.partial({
            routesManifest: t.string,
        }),
    ]),
});
/* DeployStatic */
var DeployStaticSchema = defineSchema({
    Event: t.type({
        name: t.literal(BuilderEventNames.deployStatic),
        payload: t.type({
            region: t.string,
            inputBucketName: t.string,
            outputBucketName: t.string,
            userId: t.string,
            fileKey: t.string,
            deploymentId: t.string,
        }),
    }),
    Result: t.type({
        files: t.array(t.string),
    }),
});

/* GetCertificateById */
var GetCertificateByIdSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.getCertificateById),
        payload: t.type({
            userId: t.string,
            certificateId: t.string,
        }),
    }),
    Result: CertificateSchema,
});
/* GetCertificateByDomainName */
var GetCertificateByDomainNameSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.getCertificateByDomainName),
        payload: t.type({
            userId: t.string,
            domainName: t.string,
        }),
    }),
    Result: CertificateSchema,
});

/* AttachClientAppUrls */
var AttachClientAppUrlsSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.attachClientAppUrls),
        payload: t.type({
            callbackUrl: t.string,
            logoutUrl: t.string,
        }),
    }),
    Result: t.void,
});
/* CreateUser */
var CreateUserSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.createUser),
        payload: t.intersection([
            t.type({
                email: t.string,
                temporaryPassword: t.string,
            }),
            t.partial({
                forceAliasCreation: t.boolean,
                messageAction: t.union([t.literal('RESEND'), t.literal('SUPPRESS')]),
                clientMetadata: t.record(t.string, t.string),
                userAttributes: t.array(t.type({ Name: t.string, Value: t.string })),
                validationData: t.array(t.type({ Name: t.string, Value: t.string })),
                isAdmin: t.boolean,
            }),
        ]),
    }),
    Result: CognitoUserSchema,
});
/* DetachClientAppUrls */
var DetachClientAppUrlsSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.detachClientAppUrls),
        payload: t.type({
            callbackUrl: t.string,
            logoutUrl: t.string,
        }),
    }),
    Result: t.void,
});
/* DropUser */
var DropUserSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.dropUser),
        payload: t.type({
            userId: t.string,
        }),
    }),
    Result: t.void,
});
/* GetUser */
var GetUserSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.getUser),
        payload: t.type({
            userId: t.string,
        }),
    }),
    Result: CognitoUserSchema,
});
/* GetUserIdByEmail */
var GetUserIdByEmailSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.getUserIdByEmail),
        payload: t.type({
            email: t.string,
        }),
    }),
    Result: t.string,
});
/* ListUsers */
var ListUsersSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.listUsers),
        payload: t.UnknownRecord,
    }),
    Result: t.array(CognitoUserSchema),
});

/* CreateDnsRecord */
var CreateDnsRecordSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.createDnsRecord),
        payload: t.type({
            userId: t.string,
            records: t.array(t.type({
                alias: t.string,
                domainId: t.string,
            })),
        }),
    }),
    Result: t.void,
});
/* DeleteDnsRecord */
var DeleteDnsRecordSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.deleteDnsRecord),
        payload: t.type({
            userId: t.string,
            records: t.array(t.type({
                alias: t.string,
            })),
        }),
    }),
    Result: t.void,
});
/* ListDnsRecords */
var ListDnsRecordsSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.listDnsRecords),
        payload: t.UnknownRecord,
    }),
    Result: t.any,
});

/* AddDomainUser */
var AddDomainUserSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.addDomainUser),
        payload: t.type({
            userId: t.string,
            domainId: t.string,
            user: t.string,
        }),
    }),
    Result: t.void,
});
/* RemoveDomainUser */
var RemoveDomainUserSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.removeDomainUser),
        payload: t.type({
            userId: t.string,
            domainId: t.string,
            user: t.string,
        }),
    }),
    Result: t.void,
});
/* SetDomainUsers */
var SetDomainUsersSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.setDomainUsers),
        payload: t.type({
            userId: t.string,
            domainId: t.string,
            users: DomainUsersSchema,
        }),
    }),
    Result: t.void,
});

/* SetVirtualHost */
var SetVirtualHostSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.setVirtualHost),
        payload: t.intersection([
            t.type({
                userId: t.string,
                domainId: t.string,
                virtualHost: t.string,
                functionArn: t.string,
            }),
            t.partial({
                routesManifest: t.string,
            }),
        ]),
    }),
    Result: t.void,
});
/* UnsetVirtualHost */
var UnsetVirtualHostSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.unsetVirtualHost),
        payload: t.intersection([
            t.type({
                userId: t.string,
                domainId: t.string,
            }),
            t.partial({ virtualHost: t.string, functionArn: t.string }),
        ]),
    }),
    Result: t.void,
});
/* ListVirtualHosts */
var ListVirtualHostsSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.listVirtualHosts),
        payload: t.type({
            userId: t.string,
            domainId: t.string,
        }),
    }),
    Result: VirtualHostsSchema,
});

/* GetDomain */
var GetDomainSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.getDomain),
        payload: t.type({
            userId: t.string,
            domainId: t.string,
        }),
    }),
    Result: DomainSchema,
});

/* DescribeEventStore */
var DescribeEventStoreSchema = defineSchema({
    Event: t.type({
        name: t.literal(FactoryEventNames.describeEventStore),
        payload: t.type({
            version: t.string,
            user: RDSUserSchema,
            eventStoreId: t.string,
            eventStoreClusterArn: t.string,
            postgresAdminSecretArn: t.string,
            eventStoreClusterEndpoint: t.string,
            eventStoreClusterPort: t.number,
            postgresAdminUsername: t.string,
            postgresAdminPassword: t.string,
        }),
    }),
    Result: t.type({
        events: t.union([t.number, t.null]),
        secrets: t.union([t.number, t.null]),
        modifiedAt: t.union([t.number, t.null]),
        createdAt: t.union([t.number, t.null]),
        isFrozen: t.union([t.boolean, t.null]),
    }),
});
/* UploadEventsToS3 */
var UploadEventsToS3EventSchema = t.type({
    name: t.literal(FactoryEventNames.uploadEventsToS3),
    payload: t.intersection([
        t.type({
            version: t.string,
            user: RDSUserSchema,
            eventStoreId: t.string,
            eventStoreClusterEndpoint: t.string,
            eventStoreClusterPort: t.number,
            bucketName: t.string,
            databaseName: t.string,
        }),
        t.partial({
            cursor: t.union([t.string, t.null]),
            uploadId: t.union([t.string, t.null]),
            parts: t.array(t.any),
            partNumber: t.number,
            done: t.boolean,
        }),
    ]),
});
var UploadEventsToS3Schema = defineSchema({
    Event: UploadEventsToS3EventSchema,
    Result: UploadEventsToS3EventSchema,
});

/* DropEventSubscribers */
var DropEventSubscribersSchema = defineSchema({
    Event: t.type({
        name: t.literal(FactoryEventNames.dropEventSubscribers),
        payload: t.type({
            userId: t.string,
            deploymentId: t.string,
        }),
    }),
    Result: t.void,
});

/* AddNotificationsWebhook */
var AddNotificationsWebhookSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.addNotificationsWebhook),
        payload: t.type({
            alarmName: t.string,
            url: t.string,
            messageTemplate: t.string,
        }),
    }),
    Result: t.type({
        id: t.string,
    }),
});
/* DeleteNotificationsWebhook */
var DeleteNotificationsWebhookSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.deleteNotificationsWebhook),
        payload: t.type({
            id: t.string,
        }),
    }),
    Result: t.void,
});

/* RDS Clusters */
var DescribeRDSClustersSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.describeRDSClusters),
        payload: t.UnknownRecord,
    }),
    Result: t.type({
        eventStoreClusterArn: t.union([t.string, t.null]),
        eventStoreClusterEndpoint: t.union([t.string, t.null]),
        eventStoreClusterPort: t.union([t.number, t.null]),
        readModelsClusterArn: t.union([t.string, t.null]),
        readModelsClusterEndpoint: t.union([t.string, t.null]),
        readModelsClusterPort: t.union([t.number, t.null]),
        systemClusterArn: t.union([t.string, t.null]),
        postgresAdminUsername: t.string,
        postgresAdminPassword: t.string,
        postgresAdminSecretName: t.string,
        postgresAdminSecretArn: t.string,
        systemDatabaseName: t.string,
    }),
});
/* EnsureRdsUser */
var EnsureRdsUserSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.ensureRdsUser),
        payload: t.type({
            userId: t.string,
        }),
    }),
    Result: t.type({
        user: RDSUserSchema,
        eventStoreClusterArn: t.string,
        eventStoreClusterEndpoint: t.string,
        eventStoreClusterPort: t.number,
        readModelsClusterArn: t.string,
        readModelsClusterEndpoint: t.string,
        readModelsClusterPort: t.number,
        postgresAdminPassword: t.string,
        postgresAdminSecretArn: t.string,
        postgresAdminSecretName: t.string,
        postgresAdminUsername: t.string,
    }),
});

/* InstallStageResources */
var InstallStageResourcesSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.installStageResources),
        payload: t.UnknownRecord,
    }),
    Result: t.void,
});
/* UninstallStageResources */
var UninstallStageResourcesSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.uninstallStageResources),
        payload: t.type({
            skipS3: t.boolean,
        }),
    }),
    Result: t.void,
});

/* GetAssetsStageBucketUploadSignedUrls */
var GetAssetsStageBucketUploadSignedUrlsSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.getAssetsStageBucketUploadSignedUrls),
        payload: t.type({
            assets: t.array(t.string),
        }),
    }),
    Result: t.record(t.string, t.string),
});
/* GetAssetsVersionBucketUploadSignedUrls */
var GetAssetsVersionBucketUploadSignedUrlsSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.getAssetsVersionBucketUploadSignedUrls),
        payload: t.type({
            version: t.string,
            assets: t.array(t.string),
        }),
    }),
    Result: t.record(t.string, t.string),
});
/* InstallAssetsBucket */
var InstallAssetsBucketSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.installAssetsBucket),
        payload: t.UnknownRecord,
    }),
    Result: t.void,
});
/* InstallVersionResources */
var InstallVersionResourcesSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.installVersionResources),
        payload: t.type({
            version: t.string,
        }),
    }),
    Result: t.void,
});
/* UninstallAssetsBucket */
var UninstallAssetsBucketSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.uninstallAssetsBucket),
        payload: t.type({
            skipS3: t.boolean,
        }),
    }),
    Result: t.void,
});
/* UninstallVersionAssetsFolder */
var UninstallVersionAssetsFolderSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.uninstallVersionAssetsFolder),
        payload: t.type({
            version: t.string,
        }),
    }),
    Result: t.void,
});
/* UninstallVersionResources */
var UninstallVersionResourcesSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.uninstallVersionResources),
        payload: t.type({
            version: t.string,
        }),
    }),
    Result: t.void,
});

/* EnsureRuntime */
var EnsureRuntimeSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.ensureRuntime),
        payload: t.type({
            version: t.string,
        }),
    }),
    Result: t.type({
        layerVersionArn: t.string,
    }),
});
/* SwitchApplicationsRuntime */
var SwitchApplicationsRuntimeSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.switchApplicationsRuntime),
        payload: t.intersection([
            t.type({
                version: t.string,
            }),
            t.partial({
                layerVersionArn: t.string,
            }),
        ]),
    }),
    Result: t.type({
        updatedFunctions: t.array(t.string),
    }),
});
/* FindRuntime */
var FindRuntimeSchema = defineSchema({
    Event: t.type({
        name: t.literal(InstallerEventNames.findRuntime),
        payload: t.intersection([
            t.type({
                version: t.string,
            }),
            t.partial({
                layerVersionArn: t.string,
            }),
        ]),
    }),
    Result: t.type({
        layerVersionArn: t.union([t.string, t.null]),
    }),
});

var Namespace = 'Auth';
/* AuthLogin */
var AuthLoginSchema = defineSchema({
    Namespace: Namespace,
    Description: 'Log in to reSolve Cloud.',
    Path: '/v0/auth/login',
    Method: 'POST',
    Mode: 'SYNC',
    Params: t.type({}),
    Body: t.type({
        userName: t.string,
        password: t.string,
    }),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.authLogin),
        payload: t.UnknownRecord,
    }),
    Result: t.void,
    ArgumentsTransformer: function (args) { return ({
        params: {},
        body: { userName: args.userName, password: args.password },
        query: {},
    }); },
});
/* AuthLogout */
var AuthLogoutSchema = defineSchema({
    Namespace: Namespace,
    Description: 'Log out of reSolve Cloud.',
    Path: '/v0/auth/logout',
    Method: 'POST',
    Mode: 'SYNC',
    Params: t.type({}),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.authLogout),
        payload: t.UnknownRecord,
    }),
    Result: t.void,
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});
/* AuthRefreshToken */
var AuthRefreshTokenSchema = defineSchema({
    Namespace: Namespace,
    Description: 'Refresh your authentication token on reSolve Cloud.',
    Path: '/v0/auth/refreshToken',
    Method: 'POST',
    Mode: 'SYNC',
    Params: t.type({}),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.authRefreshToken),
        payload: t.UnknownRecord,
    }),
    Result: t.void,
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});
/* AuthWhoAmI */
var AuthAuthWhoAmISchema = defineSchema({
    Namespace: Namespace,
    Description: "Get the current user's profile information.",
    Path: '/v0/auth/whoami',
    Method: 'GET',
    Mode: 'SYNC',
    Params: t.type({}),
    Body: t.type({}),
    Query: t.type({}),
    Event: t.type({
        name: t.literal(InstallerEventNames.authWhoAmI),
        payload: t.type({
            userId: t.string,
            userName: t.string,
            isAdmin: t.boolean,
        }),
    }),
    Result: t.type({
        userId: t.string,
        userName: t.string,
        isAdmin: t.boolean,
    }),
    ArgumentsTransformer: function (args) {
        return ({
            params: {},
            body: {},
            query: {},
        });
    },
});

export { APPLICATION_NAME_TAG_NAME, AddDomainUserSchema, AddNotificationsWebhookSchema, AttachClientAppUrlsSchema, AuthAuthWhoAmISchema, AuthLoginSchema, AuthLogoutSchema, AuthRefreshTokenSchema, BATCHES_TABLE_NAME, BootstrapDeploymentSchema, BuildCodeSchema, BuildDeploymentSchema, BuilderEventNames, CERTIFICATE_ID_TAG_NAME, CONNECTIONS_TABLE_NAME, CREATED_AT_TAG_NAME, CertificateSchema, ClearEventStoreSchema, ClientApiEventSchema, ClientApiResultSchema, CloneEventStoreSchema, CognitoJWTHeaderSchema, CognitoJWTPayloadSchema, CognitoUserSchema, CreateDeploymentSchema, CreateDnsRecordSchema, CreateDomainSchema, CreateEventStoreSchema, CreateReadModelSchema, CreateUserSchema, DEPLOYMENT_ID_TAG_NAME, DEPLOYMENT_TAG_TAG_NAME, DOMAIN_CUSTOM_NAME_TAG_NAME, DOMAIN_NAME_TAG_NAME, DOMAIN_TYPE_TAG_NAME, DOMAIN_USERS_TAG_NAME, DeleteDnsRecordSchema, DeleteNotificationsWebhookSchema, DeleteSagaPropertySchema, DeployStaticSchema, DeploymentSchema, DescribeDeploymentSchema, DescribeEventStoreSchema, DescribeExecutionSchema, DescribeRDSClustersSchema, DetachClientAppUrlsSchema, DisableLogsSchema, DisableTracingSchema, DomainCustomNames, DomainSchema, DomainTypeSchema, DomainUsersSchema, DomainsSchema, DropCertificateSchema, DropDeploymentSchema, DropDomainSchema, DropEventStoreSchema, DropEventSubscribersSchema, DropReadModelSchema, DropUserSchema, EDGE_REGION, EVENT_STORE_DATABASE_NAME, EVENT_STORE_ID_TAG_NAME, EnableLogsSchema, EnableTracingSchema, EnsureCertificateSchema, EnsureRdsUserSchema, EnsureRuntimeSchema, ExportEventStoreSchema, FactoryEventNames, FatalError, FindRuntimeSchema, FreezeEventStoreSchema, GetAssetsStageBucketUploadSignedUrlsSchema, GetAssetsVersionBucketUploadSignedUrlsSchema, GetCertificateByDomainNameSchema, GetCertificateByIdSchema, GetClientAppConfigSchema, GetDeploymentUploadSignedUrlSchema, GetDomainSchema, GetEventStoreSchema, GetExportUrlsSchema, GetImportUrlsSchema, GetLogsSchema, GetSagaPropertySchema, GetSummariesSchema, GetTracingDetailsSchema, GetTracingStatusSchema, GetUserIdByEmailSchema, GetUserSchema, GetVerificationCodeSchema, HEADER_EXECUTION_MODE, HeartbeatSchema, IS_RESOLVE_CLOUD_SDK_SCHEMA, ImportEventStoreSchema, InstallAssetsBucketSchema, InstallStageResourcesSchema, InstallVersionResourcesSchema, InstallerEventNames, JSON_SQL_TYPE, LINKED_DEPLOYMENTS_TAG_NAME, LONG_INTEGER_SQL_TYPE, LinkDeploymentSchema, ListCertificatesSchema, ListDeploymentsSchema, ListDnsRecordsSchema, ListDomainsSchema, ListEnvironmentVariablesSchema, ListEventStoresSchema, ListReadModelsSchema, ListSagaPropertiesSchema, ListSagasSchema, ListUsersSchema, ListVersionsSchema, ListVirtualHostsSchema, MANAGER_TAG_NAME, NOTIFICATIONS_TABLE_NAME, PATTERNS_TABLE_NAME, PauseReadModelSchema, PauseSagaSchema, RDSUserSchema, RDS_CLUSTER_NAME_TAG_NAME, READ_MODELS_DATABASE_NAME, RESOURCE_TAG_NAME, ReleaseDomainSchema, RemoveDomainUserSchema, RemoveEnvironmentVariablesSchema, RemoveLogsSchema, ResetReadModelSchema, ResetSagaSchema, ResumeReadModelSchema, ResumeSagaSchema, SERIAL_SQL_TYPE, STAGE_TAG_NAME, STRING_SQL_TYPE, SUBSCRIBERS_TABLE_NAME, SUBSCRIPTIONS_TABLE_NAME, SYSTEM_DATABASE_NAME, SetDeploymentDomainSchema, SetDomainUsersSchema, SetEnvironmentVariablesSchema, SetSagaPropertySchema, SetVirtualHostSchema, ShutdownDeploymentSchema, SwitchApplicationsRuntimeSchema, TEXT_SQL_TYPE, USER_ID_TAG_NAME, UnfreezeEventStoreSchema, UninstallAssetsBucketSchema, UninstallStageResourcesSchema, UninstallVersionAssetsFolderSchema, UninstallVersionResourcesSchema, UnlinkDeploymentSchema, UnsetDeploymentDomainSchema, UnsetVirtualHostSchema, UpdateEnvironmentVariablesSchema, UploadEventsToS3Schema, VERSION_TAG_NAME, VerifyDomainSchema, VirtualHostsSchema, coerceVersion, createCloudSdk, defineSchema, generateDeploymentId, generateEventStoreId, generateExecutionId, getXRangeVersion, intersectsVersions, isHeartbeat, isLambdaError, isNetworkError, isRetryable, isUrlContainIp, validate };
//# sourceMappingURL=index.es.js.map
