import * as t from 'io-ts';
import { RequestMethod, RequestMode } from './constants';
import { BuildCode, DeployStatic } from './api/builder';
export declare type LambdaContext = {
    functionName: string;
    invokedFunctionArn: string;
    callbackWaitsForEmptyEventLoop: boolean;
    getRemainingTimeInMillis: () => number;
};
export declare const VirtualHostsSchema: t.ArrayC<t.TypeC<{
    virtualHost: t.StringC;
    functionArn: t.StringC;
}>>;
export declare type VirtualHosts = t.TypeOf<typeof VirtualHostsSchema>;
export declare const DomainUsersSchema: t.UnionC<[t.LiteralC<"*">, t.ArrayC<t.StringC>]>;
export declare type DomainUsers = t.TypeOf<typeof DomainUsersSchema>;
export declare const DomainTypeSchema: t.UnionC<[t.LiteralC<"proxy">, t.LiteralC<"static">, t.LiteralC<"uploader">]>;
export declare type DomainType = t.TypeOf<typeof DomainTypeSchema>;
export declare const DomainSchema: t.TypeC<{
    domainId: t.StringC;
    domainType: t.UnionC<[t.LiteralC<"proxy">, t.LiteralC<"static">, t.LiteralC<"uploader">]>;
    domainName: t.StringC;
    resourceARN: t.StringC;
    aliases: t.ArrayC<t.StringC>;
    verified: t.BooleanC;
    owner: t.StringC;
    users: t.UnionC<[t.LiteralC<"*">, t.ArrayC<t.StringC>]>;
    verificationCode: t.StringC;
    certificateId: t.StringC;
}>;
export declare type Domain = t.TypeOf<typeof DomainSchema>;
export declare const DomainsSchema: t.ArrayC<t.TypeC<{
    domainId: t.StringC;
    domainType: t.UnionC<[t.LiteralC<"proxy">, t.LiteralC<"static">, t.LiteralC<"uploader">]>;
    domainName: t.StringC;
    resourceARN: t.StringC;
    aliases: t.ArrayC<t.StringC>;
    verified: t.BooleanC;
    owner: t.StringC;
    users: t.UnionC<[t.LiteralC<"*">, t.ArrayC<t.StringC>]>;
    verificationCode: t.StringC;
    certificateId: t.StringC;
}>>;
export declare type Domains = t.TypeOf<typeof DomainsSchema>;
export declare const DeploymentSchema: t.IntersectionC<[t.TypeC<{
    deploymentId: t.StringC;
    applicationName: t.StringC;
    version: t.StringC;
    domains: t.ArrayC<t.StringC>;
}>, t.PartialC<{
    eventStoreId: t.StringC;
}>]>;
export declare type Deployment = t.TypeOf<typeof DeploymentSchema>;
export declare const CognitoUserSchema: t.TypeC<{
    userId: t.StringC;
    email: t.StringC;
    enabled: t.BooleanC;
    userStatus: t.StringC;
    isAdmin: t.BooleanC;
}>;
export declare type CognitoUser = t.TypeOf<typeof CognitoUserSchema>;
export declare const CognitoJWTPayloadSchema: t.IntersectionC<[t.TypeC<{
    sub: t.StringC;
    aud: t.StringC;
    event_id: t.StringC;
    token_use: t.LiteralC<"id">;
    auth_time: t.NumberC;
    iss: t.StringC;
    'cognito:username': t.StringC;
    exp: t.NumberC;
    iat: t.NumberC;
    email: t.StringC;
}>, t.PartialC<{
    'cognito:groups': t.ArrayC<t.StringC>;
    email_verified: t.BooleanC;
}>]>;
export declare type CognitoJWTPayload = t.TypeOf<typeof CognitoJWTPayloadSchema>;
export declare const CognitoJWTHeaderSchema: t.TypeC<{
    kid: t.StringC;
    alg: t.LiteralC<"RS256">;
}>;
export declare type CognitoJWTHeader = t.TypeOf<typeof CognitoJWTHeaderSchema>;
export declare const ClientApiEventSchema: t.TypeC<{
    httpMethod: t.StringC;
    headers: t.ArrayC<t.TypeC<{
        key: t.StringC;
        value: t.StringC;
    }>>;
    uri: t.StringC;
    querystring: t.StringC;
    body: t.StringC;
}>;
export declare type ClientApiEvent = t.TypeOf<typeof ClientApiEventSchema>;
export declare const ClientApiResultSchema: t.TypeC<{
    httpStatus: t.NumberC;
    httpStatusText: t.StringC;
    headers: t.ArrayC<t.TypeC<{
        key: t.StringC;
        value: t.StringC;
    }>>;
    body: t.StringC;
}>;
export declare type ClientApiResult = t.TypeOf<typeof ClientApiResultSchema>;
export declare const CertificateSchema: t.IntersectionC<[t.TypeC<{
    certificateId: t.StringC;
    additionalNames: t.ArrayC<t.StringC>;
    resourceARN: t.StringC;
}>, t.PartialC<{
    domainName: t.StringC;
    importedAt: t.StringC;
    issuer: t.StringC;
    notBefore: t.StringC;
    notAfter: t.StringC;
}>]>;
export declare type Certificate = t.TypeOf<typeof CertificateSchema>;
export declare type BuilderLambdaEvent = BuildCode['Event'] | DeployStatic['Event'];
export declare const RDSUserSchema: t.TypeC<{
    userId: t.StringC;
    password: t.StringC;
    secretName: t.StringC;
    secretArn: t.StringC;
}>;
export declare const IS_RESOLVE_CLOUD_SDK_SCHEMA: unique symbol;
export declare type RDSUser = t.TypeOf<typeof RDSUserSchema>;
export declare const defineSchema: <EventSchema extends t.Any, ResultSchema extends t.Any, Namespace extends unknown = unknown, Description extends unknown = unknown, Path extends unknown = unknown, Method extends RequestMethod = never, Mode extends RequestMode = never, ParamsSchema extends unknown = unknown, BodySchema extends unknown = unknown, QuerySchema extends unknown = unknown, ArgumentsTransformerSchema = ParamsSchema extends t.Any ? BodySchema extends t.Any ? QuerySchema extends t.Any ? (args: t.TypeOf<ParamsSchema> & t.TypeOf<BodySchema> & t.TypeOf<QuerySchema>) => {
    params: t.TypeOf<ParamsSchema>;
    body: t.TypeOf<BodySchema>;
    query: t.TypeOf<QuerySchema>;
} : unknown : unknown : unknown>(route: {
    Event: EventSchema;
    Result: ResultSchema;
} | {
    Event: EventSchema;
    Result: ResultSchema;
    Namespace: Namespace;
    Description: Description;
    Path: Path;
    Method: Method;
    Mode: Mode;
    Params: ParamsSchema;
    Body: BodySchema;
    Query: QuerySchema;
    ArgumentsTransformer: ArgumentsTransformerSchema;
}) => {
    Namespace: Namespace;
    Description: Description;
    Path: Path;
    Method: Method;
    Mode: Mode;
    Params: ParamsSchema;
    Body: BodySchema;
    Query: QuerySchema;
    Event: EventSchema;
    Result: ResultSchema;
    ArgumentsTransformer: ArgumentsTransformerSchema;
};
export declare type ExtractSchemaTypes<T extends {
    Event: t.Any;
    Result: t.Any;
    Namespace: string | unknown;
    Description: string | unknown;
    Path: string | unknown;
    Method: RequestMethod | never;
    Mode: RequestMode | never;
    Params: t.Any | unknown;
    Body: t.Any | unknown;
    Query: t.Any | unknown;
    ArgumentsTransformer: ((args: any) => any) | unknown;
}> = {
    Namespace: T['Namespace'];
    Description: T['Description'];
    Path: T['Path'];
    Method: T['Method'] extends RequestMethod ? T['Method'] : unknown;
    Mode: T['Mode'] extends RequestMode ? T['Mode'] : unknown;
    Params: T['Params'] extends t.Any ? t.TypeOf<T['Params']> : unknown;
    Body: T['Body'] extends t.Any ? t.TypeOf<T['Body']> : unknown;
    Query: T['Query'] extends t.Any ? t.TypeOf<T['Query']> : unknown;
    Event: t.TypeOf<T['Event']>;
    Result: t.TypeOf<T['Result']>;
};
